@@ -128,17 +128,17 @@ protected:
     virtual int weapon_damage() = 0;
     virtual int get_weapon_plus();
     virtual int calc_base_unarmed_damage();
-    int calc_stat_to_hit_base();
-    int calc_stat_to_dam_base();
     virtual int calc_mon_to_hit_base() = 0;
     virtual int apply_damage_modifiers(int damage, int damage_max) = 0;
     virtual int calc_damage();
     int test_hit(int to_hit, int ev, bool randomise_ev);
     int apply_defender_ac(int damage, int damage_max = 0) const;
-    bool attack_warded_off();
     // Determine if we're blocking (partially or entirely)
     virtual bool attack_shield_blocked(bool verbose);
-    virtual bool attack_ignores_shield(bool verbose) = 0;
+    virtual bool ignores_shield(bool verbose)
+    {
+        return false;
+    }
     virtual bool apply_damage_brand(const char *what = nullptr);
     void calc_elemental_brand_damage(beam_type flavour,
                                      const char *verb,
@@ -184,6 +184,7 @@ protected:
     string defender_name(bool allow_reflexive);
 
     attack_flavour random_chaos_attack_flavour();
+    bool apply_poison_damage_brand();
 
     virtual int  player_stat_modify_damage(int damage);
     virtual int  player_apply_weapon_skill(int damage);
