@@ -549,11 +549,6 @@ bool CLua::calltopfn(lua_State *ls, const char *params, va_list args,
     return !err;
 }
 
-static maybe_bool _frombool(bool b)
-{
-    return b ? MB_TRUE : MB_FALSE;
-}
-
 maybe_bool CLua::callmbooleanfn(const char *fn, const char *params,
                                 va_list args)
 {
@@ -575,7 +570,7 @@ maybe_bool CLua::callmbooleanfn(const char *fn, const char *params,
     if (!ret)
         CL_RESETSTACK_RETURN(ls, stacktop, MB_MAYBE);
 
-    maybe_bool r = _frombool(lua_toboolean(ls, -1));
+    maybe_bool r = frombool(lua_toboolean(ls, -1));
     CL_RESETSTACK_RETURN(ls, stacktop, r);
 }
 
@@ -583,7 +578,9 @@ maybe_bool CLua::callmbooleanfn(const char *fn, const char *params, ...)
 {
     va_list args;
     va_start(args, params);
-    return callmbooleanfn(fn, params, args);
+    maybe_bool r = callmbooleanfn(fn, params, args);
+    va_end(args);
+    return r;
 }
 
 maybe_bool CLua::callmaybefn(const char *fn, const char *params, va_list args)
@@ -606,7 +603,7 @@ maybe_bool CLua::callmaybefn(const char *fn, const char *params, va_list args)
     if (!ret)
         CL_RESETSTACK_RETURN(ls, stacktop, MB_MAYBE);
 
-    maybe_bool r = lua_isboolean(ls, -1) ? _frombool(lua_toboolean(ls, -1))
+    maybe_bool r = lua_isboolean(ls, -1) ? frombool(lua_toboolean(ls, -1))
                                          : MB_MAYBE;
     CL_RESETSTACK_RETURN(ls, stacktop, r);
 }
@@ -615,7 +612,9 @@ maybe_bool CLua::callmaybefn(const char *fn, const char *params, ...)
 {
     va_list args;
     va_start(args, params);
-    return callmaybefn(fn, params, args);
+    maybe_bool r = callmaybefn(fn, params, args);
+    va_end(args);
+    return r;
 }
 
 bool CLua::callbooleanfn(bool def, const char *fn, const char *params, ...)
@@ -623,6 +622,7 @@ bool CLua::callbooleanfn(bool def, const char *fn, const char *params, ...)
     va_list args;
     va_start(args, params);
     maybe_bool r = callmbooleanfn(fn, params, args);
+    va_end(args);
     return tobool(r, def);
 }
 
@@ -907,9 +907,9 @@ bool lua_text_pattern::is_lua_pattern(const string &s)
 }
 
 lua_text_pattern::lua_text_pattern(const string &_pattern)
-    : translated(false), isvalid(true), pattern(_pattern), lua_fn_name()
+    : translated(false), isvalid(true), pattern(_pattern),
+      lua_fn_name(new_fn_name())
 {
-    lua_fn_name = new_fn_name();
 }
 
 lua_text_pattern::~lua_text_pattern()
@@ -941,6 +941,17 @@ bool lua_text_pattern::matches(const string &s) const
     return clua.callbooleanfn(false, lua_fn_name.c_str(), "s", s.c_str());
 }
 
+pattern_match lua_text_pattern::match_location(const string &s) const
+{
+    // lua_text_pattern is only used if a special non-regex op is detected (^F
+    // for "armour && ego", for instance), and in those situations, it's
+    // unclear what exactly to use for the matched text here (especially in
+    // more complicated expressions that include things like <<>>, !!, etc).
+    return matches(s)
+        ? pattern_match::succeeded(s)
+        : pattern_match::failed(s);
+}
+
 void lua_text_pattern::pre_pattern(string &pat, string &fn) const
 {
     // Trim trailing spaces
