@@ -98,8 +98,8 @@
 {':', CMD_MAKE_NOTE},
 #ifndef USE_TILE_LOCAL
 {'_', CMD_READ_MESSAGES},
-{'|', CMD_SHOW_TERRAIN},
 #endif
+{'|', CMD_SHOW_TERRAIN},
 {';', CMD_INSPECT_FLOOR},
 {'^', CMD_DISPLAY_RELIGION},
 {'#', CMD_CHARACTER_DUMP},
@@ -118,8 +118,6 @@
 {'[', CMD_LIST_ARMOUR},
 {'(', CMD_CYCLE_QUIVER_BACKWARD},
 {')', CMD_CYCLE_QUIVER_FORWARD},
-{CONTROL('V'), CMD_TOGGLE_VIEWPORT_MONSTER_HP},
-{CONTROL('T'), CMD_TOGGLE_VIEWPORT_WEAPONS},
 {'\\', CMD_DISPLAY_KNOWN_OBJECTS},
 {'}', CMD_DISPLAY_RUNES},
 {'\'', CMD_WEAPON_SWAP},
