@@ -566,13 +566,6 @@ void init_element_colours()
                             15,  LIGHTRED,
                             15,  RED,
                         0));
-    add_element_colour(_create_random_element_colour_calc(
-                            ETC_KRAKEN, "kraken",
-                            30,  LIGHTGREEN,
-                            30,  LIGHTBLUE,
-                            30,  RED,
-                            30,  LIGHTMAGENTA,
-                        0));
     add_element_colour(new element_colour_calc(
                             ETC_FLOOR, "floor", _etc_floor
                        ));
@@ -654,6 +647,12 @@ void init_element_colours()
                             60,  MAGENTA,
                             60,  RED,
                         0));
+    add_element_colour(_create_random_element_colour_calc(
+                            ETC_PAKELLAS, "pakellas",
+                            40,  LIGHTGREEN,
+                            40,  LIGHTMAGENTA,
+                            40,  LIGHTCYAN,
+                        0));
     // redefined by Lua later
     add_element_colour(new element_colour_calc(
                             ETC_DISCO, "disco", _etc_random
