@@ -158,14 +158,13 @@ void dgn_build_chaotic_city_level(dungeon_feature_type force_wall)
     env.level_build_method += make_stringf(" [%s]",
         force_wall == NUM_FEATURES ? "any" : dungeon_feature_name(force_wall));
 
-    int number_boxes = 5000;
     dungeon_feature_type drawing = DNGN_ROCK_WALL;
 
-    number_boxes = random_choose_weighted(32, 4000,
-                                          24, 3000,
-                                          16, 5000,
-                                          8, 2000,
-                                          1, 1000, 0);
+    int number_boxes = random_choose_weighted(32, 4000,
+                                              24, 3000,
+                                              16, 5000,
+                                              8, 2000,
+                                              1, 1000, 0);
 
     if (force_wall != NUM_FEATURES)
         drawing = force_wall;
@@ -1110,7 +1109,7 @@ static void _build_river(dungeon_feature_type river_type) //mv
             if (j >= 5 && j <= GYM - 5)
             {
                 // Note that vaults might have been created in this area!
-                // So we'll avoid the silliness of orcs/royal jelly on
+                // So we'll avoid the silliness of orcs/Royal Jelly on
                 // lava and deep water grids. -- bwr
                 if (!one_chance_in(200) && _may_overwrite_pos(coord_def(i, j)))
                 {
