@@ -13,18 +13,18 @@ void get_all_manual_charges(vector<int> &charges);
 void set_all_manual_charges(const vector<int> &charges);
 string manual_skill_names(bool short_text=false);
 
-int recharge_wand(bool known = true, const string &pre_msg = "");
+int recharge_wand(bool known = true, const string &pre_msg = "",
+                  int charge_num = 0, int charge_den = 0);
 
 void wind_blast(actor* agent, int pow, coord_def target, bool card = false);
 
-bool can_flood_feature(dungeon_feature_type feat);
+void expend_xp_evoker(item_def &item);
 
+bool evoke_check(int slot, bool quiet = false);
 bool evoke_item(int slot = -1, bool check_range = false);
 int wand_mp_cost();
 void zap_wand(int slot = -1);
 
-void shadow_lantern_effect();
-void expire_lantern_shadows();
 bool disc_of_storms();
 void black_drac_breath();
 
