@@ -40,9 +40,8 @@ static bool _mon_needs_auto_exclude(const monster* mon, bool sleepy = false)
     if (mon->is_stationary())
         return !sleepy;
 
-    // Auto exclusion only makes sense if the monster is still asleep or if it
-    // is lurking (discovered mimics).
-    return mon->asleep() || mons_is_lurking(mon);
+    // Auto exclusion only makes sense if the monster is still asleep.
+    return mon->asleep();
 }
 
 // Check whether a given monster is listed in the auto_exclude option.
@@ -506,9 +505,8 @@ void set_exclude(const coord_def &p, int radius, bool autoexcl, bool vaultexcl,
     {
         if (exc->desc.empty() && defer_updates)
         {
-            const int cl = env.cgrid(p);
-            if (env.cgrid(p) != EMPTY_CLOUD)
-                exc->desc = cloud_name_at_index(cl) + " cloud";
+            if (cloud_struct* cloud = cloud_at(p))
+                exc->desc = cloud->cloud_name(true) + " cloud";
         }
         else if (exc->radius == radius)
             return;
@@ -547,12 +545,8 @@ void set_exclude(const coord_def &p, int radius, bool autoexcl, bool vaultexcl,
                 }
             }
         }
-        else
-        {
-            const int cl = env.cgrid(p);
-            if (env.cgrid(p) != EMPTY_CLOUD)
-                desc = cloud_name_at_index(cl) + " cloud";
-        }
+        else if (cloud_struct* cloud = cloud_at(p))
+            desc = cloud->cloud_name(true) + " cloud";
 
         curr_excludes.add_exclude(p, radius, autoexcl, desc, vaultexcl);
     }
