@@ -109,7 +109,7 @@ protected:
     }
 };
 
-class distortion_tele_fineff : public final_effect
+class teleport_fineff : public final_effect
 {
 public:
     bool mergeable(const final_effect &a) const override;
@@ -117,10 +117,10 @@ public:
 
     static void schedule(const actor *defend)
     {
-        final_effect::schedule(new distortion_tele_fineff(defend));
+        final_effect::schedule(new teleport_fineff(defend));
     }
 protected:
-    distortion_tele_fineff(const actor *defend)
+    teleport_fineff(const actor *defend)
         : final_effect(0, defend, coord_def())
     {
     }
@@ -218,17 +218,22 @@ public:
     void merge(const final_effect &a) override;
     void fire() override;
 
-    static void schedule(const actor *serpent, coord_def pos, int pow)
+    static void schedule(const actor *serpent, const actor &oppressor,
+                         coord_def pos, int pow)
     {
         final_effect::schedule(new shock_serpent_discharge_fineff(serpent,
+                                                                  oppressor,
                                                                   pos, pow));
     }
 protected:
-    shock_serpent_discharge_fineff(const actor *serpent, coord_def pos, int pow)
-        : final_effect(0, serpent, coord_def()), position(pos), power(pow),
-          attitude(mons_attitude(serpent->as_monster()))
+    shock_serpent_discharge_fineff(const actor *serpent, const actor &rudedude,
+                                   coord_def pos, int pow)
+        : final_effect(0, serpent, coord_def()), oppressor(rudedude),
+          position(pos), power(pow),
+        attitude(mons_attitude(serpent->as_monster()))
     {
     }
+    const actor &oppressor;
     coord_def position;
     int power;
     mon_attitude_type attitude;
@@ -298,19 +303,19 @@ public:
     bool mergeable(const final_effect &a) const override { return false; }
     void fire() override;
 
-    static void schedule(coord_def pos, int revives, beh_type att,
+    static void schedule(coord_def pos, int revives, beh_type attitude,
                          unsigned short foe)
     {
-        final_effect::schedule(new bennu_revive_fineff(pos, revives, att, foe));
+        final_effect::schedule(new bennu_revive_fineff(pos, revives, attitude, foe));
     }
 protected:
     bennu_revive_fineff(coord_def pos, int _revives, beh_type _att,
                         unsigned short _foe)
-        : final_effect(0, 0, pos), revives(_revives), att(_att), foe(_foe)
+        : final_effect(0, 0, pos), revives(_revives), attitude(_att), foe(_foe)
     {
     }
     int revives;
-    beh_type att;
+    beh_type attitude;
     unsigned short foe;
 };
 
