@@ -207,14 +207,14 @@ void FTFontWrapper::load_glyph(unsigned int c, ucs_t uchar)
 
     // Was int prior to freetype 2.5.4, then became unsigned.
     typedef decltype(bmp->width) ftint;
-    ftint bmp_width  = bmp->width;
+    ftint bmp_width = bmp->width;
     if (outl)
-        bmp_width  += 2;
+        bmp_width += 2;
 
-    m_glyphs[c].offset  = face->glyph->bitmap_left;
+    m_glyphs[c].offset = face->glyph->bitmap_left;
     m_glyphs[c].advance = advance;
     m_glyphs[c].ascender = face->glyph->bitmap_top;
-    m_glyphs[c].width   = bmp_width;
+    m_glyphs[c].width = bmp_width;
 
     // Some glyphs (e.g. ' ') don't get a buffer.
     if (bmp->buffer)
@@ -228,9 +228,14 @@ void FTFontWrapper::load_glyph(unsigned int c, ucs_t uchar)
         const unsigned int offset_x = 0;
         const unsigned int offset_y = 0;
         memset(pixels, 0, sizeof(unsigned char) * 4 * charsz.x * charsz.y);
+
+        // Some fonts have wrong size info
+        const ftint charw = bmp->width;
+        bmp->width = min(bmp->width, ftint(charsz.x));
+        bmp->rows = min(bmp->rows, ftint(charsz.y));
+
         if (outl)
         {
-            const ftint charw = bmp->width;
             for (ftint x = 0; x < bmp->width; x++)
                 for (ftint y = 0; y < bmp->rows; y++)
                 {
@@ -264,7 +269,7 @@ void FTFontWrapper::load_glyph(unsigned int c, ucs_t uchar)
                     idx *= 4;
                     if (x < bmp->width && y < bmp->rows)
                     {
-                        unsigned char alpha = bmp->buffer[x + bmp->width * y];
+                        unsigned char alpha = bmp->buffer[x + charw * y];
                         pixels[idx] = 255;
                         pixels[idx + 1] = 255;
                         pixels[idx + 2] = 255;
