@@ -30,95 +30,86 @@
 
 vector<ghost_demon> ghosts;
 
+// Pan lord AOE conjuration spell list.
+static spell_type search_order_aoe_conj[] =
+{
+    SPELL_SYMBOL_OF_TORMENT,
+    SPELL_FIRE_STORM,
+    SPELL_GLACIATE,
+    SPELL_CHAIN_LIGHTNING,
+    SPELL_SHATTER,
+    SPELL_FREEZING_CLOUD,
+    SPELL_STEAM_BALL,
+    SPELL_DAZZLING_SPRAY,
+    SPELL_OLGREBS_TOXIC_RADIANCE,
+    SPELL_POISONOUS_CLOUD,
+    SPELL_MEPHITIC_CLOUD,
+    SPELL_METAL_SPLINTERS,
+    SPELL_ENERGY_BOLT,
+    SPELL_ORB_OF_ELECTRICITY,
+    SPELL_NO_SPELL, // end of list
+};
+
 // Pan lord conjuration spell list.
 static spell_type search_order_conj[] =
 {
-    SPELL_FIRE_STORM,
-    SPELL_GLACIATE,
+    SPELL_CALL_DOWN_DAMNATION,
     SPELL_LEHUDIBS_CRYSTAL_SPEAR,
-    SPELL_CHAIN_LIGHTNING,
-    SPELL_IOOD,
     SPELL_CORROSIVE_BOLT,
+    SPELL_QUICKSILVER_BOLT,
+    SPELL_IOOD,
+    SPELL_ENERGY_BOLT,
     SPELL_DISINTEGRATE,
     SPELL_BOLT_OF_FIRE,
     SPELL_BOLT_OF_COLD,
     SPELL_IRON_SHOT,
     SPELL_POISON_ARROW,
     SPELL_BOLT_OF_DRAINING,
-    SPELL_QUICKSILVER_BOLT,
-    SPELL_FORCE_LANCE,
-    SPELL_FIREBALL,
-    SPELL_BOLT_OF_MAGMA,
     SPELL_LRD,
     SPELL_LIGHTNING_BOLT,
-    SPELL_BLINKBOLT,
-    SPELL_VENOM_BOLT,
-    SPELL_AGONY,
-    SPELL_DRAIN_MAGIC,
-    SPELL_SLEEP,
-    SPELL_ISKENDERUNS_MYSTIC_BLAST,
-    SPELL_STICKY_FLAME_RANGE,
-    SPELL_STEAM_BALL,
-    SPELL_THROW_ICICLE,
-    SPELL_AIRSTRIKE,
-    SPELL_SMITING,
-    SPELL_DAZZLING_SPRAY,
-    SPELL_STONE_ARROW,
-    SPELL_DISCHARGE,
-    SPELL_VAMPIRIC_DRAINING,
-    SPELL_THROW_FLAME,
-    SPELL_THROW_FROST,
-    SPELL_NO_SPELL,                        // end search
+    SPELL_NO_SPELL, // end of list
 };
 
-// Pan lord self-enchantment / summoning spell list.
+// Pan lord self-enchantment spell list.
 static spell_type search_order_selfench[] =
 {
+    SPELL_HASTE,
+    SPELL_SILENCE,
+    SPELL_BATTLESPHERE,
+    SPELL_SPELLFORGED_SERVITOR,
+    SPELL_INVISIBILITY,
+    SPELL_BLINK,
+    SPELL_BLINKBOLT,
+    SPELL_NO_SPELL, // end of list
+};
+
+// Pan lord summoning spell list.
+static spell_type search_order_summon[] =
+{
+    SPELL_HAUNT,
+    SPELL_MALIGN_GATEWAY,
     SPELL_SUMMON_DRAGON,
     SPELL_SUMMON_HORRIBLE_THINGS,
-    SPELL_SUMMON_GREATER_DEMON,
-    SPELL_HAUNT,
-    SPELL_SUMMON_HYDRA,
-    SPELL_MALIGN_GATEWAY,
-    SPELL_HASTE,
-    SPELL_INVISIBILITY,
-    SPELL_SYMBOL_OF_TORMENT,
-    SPELL_MONSTROUS_MENAGERIE,
-    SPELL_SILENCE,
     SPELL_SHADOW_CREATURES,
-    SPELL_SUMMON_DEMON,
-    SPELL_SUMMON_VERMIN,
-    SPELL_SUMMON_SWARM,
-    SPELL_BATTLESPHERE,
-    SPELL_FULMINANT_PRISM,
-    SPELL_SUMMON_ICE_BEAST,
-    SPELL_SWIFTNESS,
-    SPELL_BLINK,
-    SPELL_SUMMON_BUTTERFLIES,
-    SPELL_NO_SPELL,                        // end search
+    SPELL_SUMMON_EYEBALLS,
+    SPELL_SUMMON_VERMIN, // funny
+    SPELL_SUMMON_BUTTERFLIES, // funny
+    SPELL_NO_SPELL, // end of list
 };
 
 // Pan lord misc spell list.
 static spell_type search_order_misc[] =
 {
-    SPELL_SHATTER,
-    SPELL_SYMBOL_OF_TORMENT,
-    SPELL_BANISHMENT,
-    SPELL_FREEZING_CLOUD,
-    SPELL_POISONOUS_CLOUD,
-    SPELL_MASS_CONFUSION,
-    SPELL_ENGLACIATION,
     SPELL_DISPEL_UNDEAD,
-    SPELL_DIG,
-    SPELL_PETRIFY,
-    SPELL_OLGREBS_TOXIC_RADIANCE,
     SPELL_PARALYSE,
+    SPELL_SLEEP,
+    SPELL_MASS_CONFUSION,
+    SPELL_DRAIN_MAGIC,
+    SPELL_PETRIFY,
     SPELL_POLYMORPH,
-    SPELL_MEPHITIC_CLOUD,
-    SPELL_CONFUSE,
-    SPELL_TELEPORT_OTHER,
+    SPELL_FORCE_LANCE,
     SPELL_SLOW,
-    SPELL_NO_SPELL,                        // end search
+    SPELL_NO_SPELL, // end of list
 };
 
 // Last slot (emergency) can only be Teleport Self or Blink.
@@ -159,25 +150,26 @@ void ghost_demon::reset()
  */
 static brand_type _random_special_pan_lord_brand()
 {
-    return random_choose(SPWPN_FLAMING,
-                         SPWPN_FREEZING,
-                         SPWPN_ELECTROCUTION,
-                         SPWPN_VENOM,
-                         SPWPN_DRAINING,
-                         SPWPN_SPEED,
-                         SPWPN_VORPAL,
-                         SPWPN_VAMPIRISM,
-                         SPWPN_PAIN,
-                         SPWPN_ANTIMAGIC,
-                         SPWPN_DISTORTION,
-                         SPWPN_CHAOS);
+    return random_choose_weighted(10, SPWPN_FLAMING,
+                                  10, SPWPN_FREEZING,
+                                  10, SPWPN_ELECTROCUTION,
+                                  10, SPWPN_VENOM,
+                                  // Lower chance
+                                  5, SPWPN_DRAINING,
+                                  // Higher chance
+                                  20, SPWPN_VAMPIRISM,
+                                  20, SPWPN_PAIN,
+                                  20, SPWPN_ANTIMAGIC,
+                                  20, SPWPN_DISTORTION,
+                                  20, SPWPN_CHAOS,
+                                  0);
 }
 
 #define ADD_SPELL(which_spell) \
     do { \
         const auto spell = (which_spell); \
         if (spell != SPELL_NO_SPELL) \
-            spells.emplace_back(spell, 0, MON_SPELL_DEMONIC); \
+            spells.emplace_back(spell, 0, MON_SPELL_MAGICAL); \
     } while (0)
 
 static int _panlord_random_resist_level()
@@ -185,7 +177,16 @@ static int _panlord_random_resist_level()
     return random_choose_weighted(1, -1,
                                   3,  0,
                                   3,  1,
-                                  3,  2,
+                                  2,  2,
+                                  1,  3,
+                                  0);
+}
+
+static int _panlord_random_elec_resist_level()
+{
+    return random_choose_weighted(3, 0,
+                                  6, 1,
+                                  1, 3,
                                   0);
 }
 
@@ -197,23 +198,28 @@ void ghost_demon::init_pandemonium_lord()
     }
     while (!getLongDescription(name).empty());
 
-    // hp - could be defined below (as could ev, AC, etc.). Oh well, too late:
+    // Is demon a spellcaster?
+    // Non-spellcasters always have branded melee and faster/tougher.
+    const bool spellcaster = x_chance_in_y(3,4);
+
     max_hp = 100 + roll_dice(3, 50);
 
-    ev = 5 + random2(20);
-    ac = 5 + random2(20);
+    // Panlord AC/EV should tend to be weighted towards one or the other.
+    int total_def = 10 + random2avg(40, 3);
+    int split = biased_random2(5, 2);
+    ac = div_rand_round(total_def * split, 10);
+    ev = total_def - ev;
+    if (coinflip())
+        swap(ac, ev);
 
     see_invis = true;
 
     resists = 0;
     resists |= mrd(MR_RES_FIRE, _panlord_random_resist_level());
     resists |= mrd(MR_RES_COLD, _panlord_random_resist_level());
+    resists |= mrd(MR_RES_ELEC, _panlord_random_elec_resist_level());
     // Demons, like ghosts, automatically get poison res. and life prot.
 
-    // resist electricity:
-    if (one_chance_in(3))
-        resists |= MR_RES_ELEC; // no rElec++ for Pan lords, because of witches
-
     // HTH damage:
     damage = 20 + roll_dice(2, 20);
 
@@ -223,9 +229,15 @@ void ghost_demon::init_pandemonium_lord()
     // hit dice:
     xl = 10 + roll_dice(2, 10);
 
-    // Is demon a spellcaster?
-    // Non-spellcasters always have branded melee and are faster instead.
-    const bool spellcaster = x_chance_in_y(3,4);
+    // Non-spellcasters get upgrades to HD, HP, AC, EV and damage
+    if (!spellcaster)
+    {
+        max_hp = max_hp * 3 / 2;
+        ac += 5;
+        ev += 5;
+        damage += 10;
+        xl += 5;
+    }
 
     if (one_chance_in(3) || !spellcaster)
         brand = _random_special_pan_lord_brand();
@@ -248,61 +260,22 @@ void ghost_demon::init_pandemonium_lord()
         // spells for the demon, then converts those spells to the monster
         // spell indices. Some special monster-only spells are at the end.
 
-        if (coinflip())
-            ADD_SPELL(RANDOM_ELEMENT(search_order_conj));
+        ADD_SPELL(RANDOM_ELEMENT(search_order_conj));
 
-        // Might duplicate the first spell, but that isn't a problem.
         if (coinflip())
-            ADD_SPELL(RANDOM_ELEMENT(search_order_conj));
+            ADD_SPELL(RANDOM_ELEMENT(search_order_summon));
+        else
+            ADD_SPELL(RANDOM_ELEMENT(search_order_aoe_conj));
 
-        ADD_SPELL(one_chance_in(4) ? SPELL_SUMMON_DEMON
-                                   : RANDOM_ELEMENT(search_order_selfench));
+        if (coinflip())
+            ADD_SPELL(RANDOM_ELEMENT(search_order_selfench));
 
         if (coinflip())
             ADD_SPELL(RANDOM_ELEMENT(search_order_misc));
 
-        if (coinflip())
-            ADD_SPELL(RANDOM_ELEMENT(search_order_misc));
-
-        // Give demon a chance for some nasty spells.
         // Demon-summoning should be fairly common.
-        if (one_chance_in(4))
-        {
-            ADD_SPELL(random_choose(SPELL_HELLFIRE_BURST,
-                                    SPELL_FIRE_STORM,
-                                    SPELL_GLACIATE,
-                                    SPELL_METAL_SPLINTERS,
-           /* eye of devastation */ SPELL_ENERGY_BOLT,
-                                    SPELL_ORB_OF_ELECTRICITY));
-        }
-
-        if (one_chance_in(25))
-            ADD_SPELL(SPELL_HELLFIRE);
-        if (one_chance_in(25))
-            ADD_SPELL(SPELL_HELLFIRE_BURST);
-        if (one_chance_in(25))
-            ADD_SPELL(SPELL_IOOD);
-
-        if (one_chance_in(22))
-            ADD_SPELL(SPELL_SUMMON_HYDRA);
-        if (one_chance_in(20))
-            ADD_SPELL(SPELL_SUMMON_DRAGON);
-        if (one_chance_in(12))
-            ADD_SPELL(SPELL_SUMMON_GREATER_DEMON);
-        if (one_chance_in(12))
-            ADD_SPELL(SPELL_SUMMON_DEMON);
-        if (one_chance_in(10))
-            ADD_SPELL(SPELL_SUMMON_EYEBALLS);
-
-        if (one_chance_in(20))
-            ADD_SPELL(SPELL_SUMMON_GREATER_DEMON);
-        if (one_chance_in(20))
-            ADD_SPELL(SPELL_SUMMON_DEMON);
-        if (one_chance_in(20))
-            ADD_SPELL(SPELL_MALIGN_GATEWAY);
-
-        if (one_chance_in(15))
-            ADD_SPELL(SPELL_DIG);
+        if (coinflip())
+            ADD_SPELL(coinflip() ? SPELL_SUMMON_DEMON : SPELL_SUMMON_GREATER_DEMON);
 
         normalize_spell_freq(spells, xl);
     }
@@ -536,8 +509,8 @@ void ghost_demon::init_ugly_thing(bool very_ugly, bool only_mutate,
     // dice and maximum hit points as they are.
     if (!only_mutate)
     {
-        xl = stats->hpdice[0];
-        max_hp = hit_points(xl, stats->hpdice[1], stats->hpdice[2]);
+        xl = stats->HD;
+        max_hp = hit_points(stats->avg_hp_10x);
     }
 
     const attack_type att_types[] =
@@ -652,59 +625,27 @@ void ghost_demon::init_dancing_weapon(const item_def& weapon, int power)
     damage = max(1, damage * power / 100);
 }
 
-void ghost_demon::init_spectral_weapon(const item_def& weapon,
-                                       int power, int wpn_skill)
+void ghost_demon::init_spectral_weapon(const item_def& weapon, int power)
 {
-    int damg  = property(weapon, PWPN_DAMAGE);
+    int damg = property(weapon, PWPN_DAMAGE);
 
     if (power > 100)
         power = 100;
 
-    // skill is on a 10 scale
-    if (wpn_skill > 270)
-        wpn_skill = 270;
-
     colour = weapon.get_colour();
     flies = true;
 
-    // Hit dice (to hit) scales with weapon skill alone.
-    // Damage scales with weapon skill, but how well depends on spell power.
-    // Defenses scale with spell power alone.
-    // Appropriate investment is rewarded with a stronger spectral weapon.
-
-    xl = max(wpn_skill / 10, 1);
-
-    // At 0 power, weapon skill is 1/3 as effective as on the player
-    // At max power, weapon skill is as effective as on the player.
-    // Power has a linear effect between those endpoints.
-    // It's possible this ends up too strong,
-    // but 100 power on Hexes/Charms will take significant investment
-    // most players wouldn't otherwise get.
-    //
-    // Damage multiplier table:
-    //     |            weapon skill
-    // pow |   3       9       15      21      27
-    // --- |   -----   ----    ----    ----    ----
-    // 0   |   1.04    1.12    1.20    1.28    1.36
-    // 10  |   1.05    1.14    1.24    1.34    1.43
-    // 20  |   1.06    1.17    1.28    1.39    1.50
-    // 30  |   1.06    1.19    1.32    1.45    1.58
-    // 40  |   1.07    1.22    1.36    1.50    1.65
-    // 50  |   1.08    1.24    1.40    1.56    1.72
-    // 60  |   1.09    1.26    1.44    1.62    1.79
-    // 70  |   1.10    1.29    1.48    1.67    1.87
-    // 80  |   1.10    1.31    1.52    1.73    1.94
-    // 90  |   1.11    1.34    1.56    1.79    2.01
-    // 100 |   1.12    1.36    1.60    1.84    2.08
-    damage  = damg;
+    // Offense and defenses all scale with power.
+    xl        = 2 + div_rand_round(power, 4);
+    damage    = damg;
     int scale = 250 * 150 / (50 + power);
-    damage *= scale + wpn_skill;
-    damage /= scale;
+    damage   *= scale + 125;
+    damage   /= scale;
 
-    speed   = 30;
-    ev      = 10 + div_rand_round(power,10);
-    ac      = 2 + div_rand_round(power,10);
-    max_hp  = 10 + div_rand_round(power,3);
+    speed  = 30;
+    ev     = 10 + div_rand_round(power, 10);
+    ac     = 2 + div_rand_round(power, 10);
+    max_hp = 10 + div_rand_round(power, 3);
 }
 
 // Used when creating ghosts: goes through and finds spells for the
