@@ -10,7 +10,8 @@
 #include "itemprop-enum.h" // brand_type
 #include "spl-cast.h"
 
-#define BEOGH_WPN_GIFT_KEY "given beogh weapon"
+#define BEOGH_RANGE_WPN_GIFT_KEY "given beogh range weapon"
+#define BEOGH_MELEE_WPN_GIFT_KEY "given beogh melee weapon"
 #define BEOGH_ARM_GIFT_KEY "given beogh armour"
 #define BEOGH_SH_GIFT_KEY "given beogh shield"
 
@@ -32,6 +33,7 @@ const char * const GOZAG_SHOP_TYPE_KEY       = "gozag_shop_type_%d";
 const char * const GOZAG_SHOP_SUFFIX_KEY     = "gozag_shop_suffix_%d";
 const char * const GOZAG_SHOP_COST_KEY       = "gozag_shop_cost_%d";
 
+#define GOZAG_GOLD_AURA_KEY "gozag_gold_aura_amount"
 #define GOZAG_POTION_PETITION_AMOUNT 400
 #define GOZAG_SHOP_BASE_MULTIPLIER 100
 #define GOZAG_SHOP_MOD_MULTIPLIER 25
@@ -43,7 +45,6 @@ const char * const GOZAG_SHOP_COST_KEY       = "gozag_shop_cost_%d";
 
 struct bolt;
 class stack_iterator;
-class dist;
 
 bool can_do_capstone_ability(god_type god);
 bool bless_weapon(god_type god, brand_type brand, colour_t colour);
@@ -52,7 +53,6 @@ string zin_recite_text(const int seed, const int prayertype, int step);
 bool zin_check_able_to_recite(bool quiet = false);
 int zin_check_recite_to_monsters(bool quiet = false);
 bool zin_recite_to_single_monster(const coord_def& where);
-void zin_recite_interrupt();
 int zin_recite_power();
 bool zin_vitalisation();
 void zin_remove_divine_stamina();
@@ -75,9 +75,9 @@ void trog_remove_trogs_hand();
 void jiyva_paralyse_jellies();
 bool jiyva_remove_bad_mutation();
 
-bool beogh_water_walk();
 bool beogh_can_gift_items_to(const monster* mons, bool quiet = true);
 bool beogh_gift_item();
+bool beogh_resurrect();
 
 bool yred_injury_mirror();
 void yred_make_enslaved_soul(monster* mon, bool force_hostile = false);
@@ -121,16 +121,12 @@ bool cheibriados_slouch();
 void cheibriados_time_step(int pow);
 bool ashenzari_transfer_knowledge();
 bool ashenzari_end_transfer(bool finished = false, bool force = false);
+bool ashenzari_curse_item(int num_rc);
 
 bool can_convert_to_beogh();
 void spare_beogh_convert();
 
 bool dithmenos_shadow_step();
-monster* shadow_monster(bool equip = true);
-void shadow_monster_reset(monster *mon);
-void dithmenos_shadow_melee(actor* target);
-void dithmenos_shadow_throw(const dist &d, const item_def &item);
-void dithmenos_shadow_spell(bolt* orig_beam, spell_type spell);
 
 int gozag_potion_price();
 bool gozag_setup_potion_petition(bool quiet = false);
@@ -147,10 +143,11 @@ bool gozag_bribe_branch();
 
 spret_type qazlal_upheaval(coord_def target, bool quiet = false,
                            bool fail = false);
-void qazlal_elemental_force();
+spret_type qazlal_elemental_force(bool fail);
 bool qazlal_disaster_area();
 
 void init_sac_index();
+int get_sacrifice_piety(ability_type sac, bool include_skill = true);
 void ru_offer_new_sacrifices();
 string ru_sac_text(ability_type sac);
 bool ru_do_sacrifice(ability_type sac);
@@ -161,4 +158,9 @@ void ru_do_retribution(monster* mons, int damage);
 void ru_draw_out_power();
 bool ru_power_leap();
 bool ru_apocalypse();
+string ru_sacrifice_vector(ability_type sac);
+
+bool pakellas_check_quick_charge(bool quiet);
+int pakellas_effective_hex_power(int pow);
+bool pakellas_device_surge();
 #endif
