@@ -70,7 +70,7 @@ static const char *conducts[] =
     "Souled Friend Died", "Attack In Sanctuary",
     "Kill Artificial", "Destroy Spellbook",
     "Exploration", "Desecrate Holy Remains", "Seen Monster",
-    "Fire", "Kill Fiery", "Sacrificed Love"
+    "Fire", "Kill Fiery", "Sacrificed Love", "Channel",
 };
 COMPILE_CHECK(ARRAYSZ(conducts) == NUM_CONDUCTS);
 
@@ -141,6 +141,10 @@ typedef function<void (int &piety, int &denom, const monster* victim)>
 /// A definition of the way in which a god dislikes a conduct being taken.
 struct dislike_response
 {
+    /// Description on god desc screen.
+    const char* desc;
+    /// Whether the god "strongly" dislikes doing this.
+    bool really_dislike;
     /// Loss in piety for triggering this conduct; multiplied by 'level'.
     int piety_factor;
     /// Penance for triggering this conduct; multiplied by 'level'.
@@ -212,76 +216,96 @@ struct dislike_response
 
 /// Good gods' reaction to drinking blood.
 static const dislike_response GOOD_BLOOD_RESPONSE = {
+    "you drink blood", false,
     2, 1, " forgives your inadvertent blood-drinking, just this once."
 };
 
 /// Good gods', and Beogh's, response to cannibalism.
 static const dislike_response RUDE_CANNIBALISM_RESPONSE = {
+    "you perform cannibalism", true,
     5, 3, nullptr, " expects more respect for your departed relatives."
 };
 
 /// Zin and Ely's responses to desecrating holy remains.
 static const dislike_response GOOD_DESECRATE_HOLY_RESPONSE = {
+    "you desecrate holy remains", true,
     1, 1, nullptr, " expects more respect for holy creatures!"
 };
 
-/// Zin and Ely's responses to unholy actions & necromancy.
+/// Zin and Ely's responses to unholy actions.
 static const dislike_response GOOD_UNHOLY_RESPONSE = {
+    "you use unholy magic or items", true,
     1, 1, " forgives your inadvertent unholy act, just this once."
 };
 
+/// Zin and Ely's responses to necromancy.
+static const dislike_response GOOD_EVIL_RESPONSE = {
+    "you use necromancy", true,
+    1, 1, " forgives your inadvertent evil act, just this once."
+};
+
 /// Zin and Ely's responses to the player attacking holy creatures.
 static const dislike_response GOOD_ATTACK_HOLY_RESPONSE = {
+    "you attack non-hostile holy beings", true,
     1, 1, nullptr, nullptr, _attacking_holy_matters
 };
 
 /// Good gods' response to the player killing holy creatures.
 static const dislike_response GOOD_KILL_HOLY_RESPONSE = {
+    "you kill non-hostile holy beings", true,
     3, 3, nullptr, nullptr, _attacking_holy_matters
 };
 
-/// TSO's response to the player stabbing or poisoning monsters.
-static const dislike_response TSO_UNCHIVALRIC_RESPONSE = {
-    1, 2, " forgives your inadvertent dishonourable attack, just"
-              " this once.", nullptr, [] (const monster* victim) -> bool {
-        return !victim || !tso_unchivalric_attack_safe_monster(victim);
-    }
-};
-
 /// TSO and Ely's response to the player attacking neutral monsters.
 static const dislike_response GOOD_ATTACK_NEUTRAL_RESPONSE = {
+    "you attack neutral beings", true,
     1, 1, " forgives your inadvertent attack on a neutral, just this once."
 };
 
 /// Various gods' response to attacking a pal.
-static const dislike_response ATTACK_FRIEND_RESPONSE = {
-    1, 3, " forgives your inadvertent attack on an ally, just this once.",
-    nullptr, [] (const monster* victim) -> bool {
-        dprf("hates friend : %d", god_hates_attacking_friend(you.religion, victim));
-        return god_hates_attacking_friend(you.religion, victim);
-    }
-};
+static dislike_response _on_attack_friend(const char* desc)
+{
+    return
+    {
+        desc, true,
+        1, 3, " forgives your inadvertent attack on an ally, just this once.",
+        nullptr, [] (const monster* victim) -> bool {
+            dprf("hates friend : %d", god_hates_attacking_friend(you.religion, victim));
+            return god_hates_attacking_friend(you.religion, victim);
+        }
+    };
+}
 
 /// Ely response to a friend dying.
-static const dislike_response ELY_FRIEND_DEATH_RESPONSE = {
-    1, 0, nullptr, nullptr, [] (const monster* victim) -> bool {
-        // For everyone but Fedhas, plants are items not creatures,
-        // and animated items are, well, items as well.
-        return victim && !mons_is_object(victim->type)
-                      && victim->holiness() != MH_PLANT
-        // Converted allies (marked as TSOites) can be martyrs.
-                      && victim->god == GOD_SHINING_ONE;
-    }
-};
+static dislike_response _on_ely_friend_death(const char* desc)
+{
+    return
+    {
+        desc, false,
+        1, 0, nullptr, nullptr, [] (const monster* victim) -> bool {
+            // For everyone but Fedhas, plants are items not creatures,
+            // and animated items are, well, items as well.
+            return victim && !mons_is_object(victim->type)
+                          && !(victim->holiness() & MH_PLANT)
+            // Converted allies (marked as TSOites) can be martyrs.
+                          && victim->god == GOD_SHINING_ONE;
+            }
+    };
+}
 
 /// Fedhas's response to a friend(ly plant) dying.
-static const dislike_response FEDHAS_FRIEND_DEATH_RESPONSE = {
-    1, 0, nullptr, nullptr, [] (const monster* victim) -> bool {
-        // ballistomycetes are penalized separately.
-        return victim && fedhas_protects(victim)
-        && victim->mons_species() != MONS_BALLISTOMYCETE;
-    }
-};
+static dislike_response _on_fedhas_friend_death(const char* desc)
+{
+    return
+    {
+        desc, false,
+        1, 0, nullptr, nullptr, [] (const monster* victim) -> bool {
+            // ballistomycetes are penalized separately.
+            return victim && fedhas_protects(victim)
+            && victim->mons_species() != MONS_BALLISTOMYCETE;
+        }
+    };
+}
 
 typedef map<conduct_type, dislike_response> peeve_map;
 
@@ -297,57 +321,80 @@ static peeve_map divine_peeves[] =
         { DID_ATTACK_HOLY, GOOD_ATTACK_HOLY_RESPONSE },
         { DID_KILL_HOLY, GOOD_KILL_HOLY_RESPONSE },
         { DID_DESECRATE_HOLY_REMAINS, GOOD_DESECRATE_HOLY_RESPONSE },
-        { DID_NECROMANCY, GOOD_UNHOLY_RESPONSE },
+        { DID_NECROMANCY, GOOD_EVIL_RESPONSE },
         { DID_UNHOLY, GOOD_UNHOLY_RESPONSE },
-        { DID_ATTACK_FRIEND, ATTACK_FRIEND_RESPONSE },
+        { DID_ATTACK_FRIEND, _on_attack_friend("you attack allies") },
         { DID_ATTACK_NEUTRAL, {
+            "you attack neutral beings", false,
             1, 0,
             " forgives your inadvertent attack on a neutral, just this once."
         } },
         { DID_ATTACK_IN_SANCTUARY, {
+            "you attack monters in a sanctuary", false,
             1, 1
         } },
         { DID_UNCLEAN, {
+            "you use unclean or chatoic magic or items", true,
             1, 1, " forgives your inadvertent unclean act, just this once."
         } },
         { DID_CHAOS, {
+            "you polymorph monsters", true,
             1, 1, " forgives your inadvertent chaotic act, just this once."
         } },
         { DID_DELIBERATE_MUTATING, {
+            "you deliberately mutate or transform yourself", true,
             1, 0, " forgives your inadvertent chaotic act, just this once."
         } },
         { DID_DESECRATE_SOULED_BEING, {
+            "you butcher sentient beings", true,
             5, 3
         } },
-        { DID_CAUSE_GLOWING, { 1 } },
+        { DID_CAUSE_GLOWING, { nullptr, false, 1 } },
     },
     // GOD_SHINING_ONE,
     {
         { DID_DRINK_BLOOD, GOOD_BLOOD_RESPONSE },
         { DID_CANNIBALISM, RUDE_CANNIBALISM_RESPONSE },
         { DID_ATTACK_HOLY, {
+            "you attack non-hostile holy beings", true,
             1, 2, nullptr, nullptr, _attacking_holy_matters
         } },
         { DID_KILL_HOLY, GOOD_KILL_HOLY_RESPONSE },
         { DID_DESECRATE_HOLY_REMAINS, {
+            "you desecrate holy remains", true,
             1, 2, nullptr, " expects more respect for holy creatures!"
         } },
         { DID_NECROMANCY, {
-            1, 2, " forgives your inadvertent unholy act, just this once."
+            "you use necromancy", true,
+            1, 2, " forgives your inadvertent evil act, just this once."
         } },
         { DID_UNHOLY, {
+            "you use unholy magic or items", true,
             1, 2, " forgives your inadvertent unholy act, just this once."
         } },
-        { DID_UNCHIVALRIC_ATTACK, TSO_UNCHIVALRIC_RESPONSE },
-        { DID_POISON, TSO_UNCHIVALRIC_RESPONSE },
+        { DID_UNCHIVALRIC_ATTACK, {
+            "you attack intelligent monsters in an unchivalric manner", true,
+            1, 2, " forgives your inadvertent dishonourable attack, just"
+                      " this once.", nullptr, [] (const monster* victim) -> bool {
+                return !victim || !tso_unchivalric_attack_safe_monster(victim);
+            }
+        } },
+        { DID_POISON, {
+            "you poison monsters", true,
+            1, 2, " forgives your inadvertent dishonourable attack, just"
+                      " this once.", nullptr, [] (const monster* victim) -> bool {
+                return !victim || !tso_unchivalric_attack_safe_monster(victim);
+            }
+        } },
         { DID_ATTACK_NEUTRAL, GOOD_ATTACK_NEUTRAL_RESPONSE },
-        { DID_ATTACK_FRIEND, ATTACK_FRIEND_RESPONSE },
+        { DID_ATTACK_FRIEND, _on_attack_friend("you attack allies") },
     },
     // GOD_KIKUBAAQUDGHA,
     peeve_map(),
     // GOD_YREDELEMNUL,
     {
         { DID_HOLY, {
+            "you use holy magic or items", true,
             1, 2, " forgives your inadvertent holy act, just this once."
         } },
     },
@@ -357,23 +404,26 @@ static peeve_map divine_peeves[] =
     peeve_map(),
     // GOD_OKAWARU,
     {
-        { DID_ATTACK_FRIEND, ATTACK_FRIEND_RESPONSE },
+        { DID_ATTACK_FRIEND, _on_attack_friend("you attack allies") },
     },
     // GOD_MAKHLEB,
     peeve_map(),
     // GOD_SIF_MUNA,
     {
-        { DID_DESTROY_SPELLBOOK, { 1, 2 } },
+        { DID_DESTROY_SPELLBOOK, { "you destroy spellbooks", true, 1, 2 } },
     },
     // GOD_TROG,
     {
         { DID_SPELL_MEMORISE, {
+            "you memorise spells", true,
             10, 10
         } },
         { DID_SPELL_CASTING, {
+            "you attempt to cast spells", true,
             1, 5,
         } },
         { DID_SPELL_PRACTISE, {
+            "you train magic skills", true,
             1, 0, nullptr, " doesn't appreciate your training magic!"
         } },
     },
@@ -386,13 +436,15 @@ static peeve_map divine_peeves[] =
         { DID_ATTACK_HOLY, GOOD_ATTACK_HOLY_RESPONSE },
         { DID_KILL_HOLY, GOOD_KILL_HOLY_RESPONSE },
         { DID_DESECRATE_HOLY_REMAINS, GOOD_DESECRATE_HOLY_RESPONSE },
-        { DID_NECROMANCY, GOOD_UNHOLY_RESPONSE },
+        { DID_NECROMANCY, GOOD_EVIL_RESPONSE },
         { DID_UNHOLY, GOOD_UNHOLY_RESPONSE },
         { DID_ATTACK_NEUTRAL, GOOD_ATTACK_NEUTRAL_RESPONSE },
-        { DID_ATTACK_FRIEND, ATTACK_FRIEND_RESPONSE },
-        { DID_FRIEND_DIED, ELY_FRIEND_DEATH_RESPONSE },
-        { DID_SOULED_FRIEND_DIED, ELY_FRIEND_DEATH_RESPONSE },
+        { DID_ATTACK_FRIEND, _on_attack_friend("you attack allies") },
+        { DID_FRIEND_DIED, _on_ely_friend_death("you allow allies to die") },
+        { DID_SOULED_FRIEND_DIED, _on_ely_friend_death(nullptr) },
         { DID_KILL_LIVING, {
+            "you kill living things while asking for your life to be spared",
+            true,
             1, 2, nullptr, " does not appreciate your shedding blood"
                             " when asking for salvation!",
             [] (const monster*) -> bool {
@@ -406,40 +458,46 @@ static peeve_map divine_peeves[] =
     // GOD_BEOGH,
     {
         { DID_CANNIBALISM, RUDE_CANNIBALISM_RESPONSE },
-        { DID_DESECRATE_ORCISH_REMAINS, { 1 } },
-        { DID_DESTROY_ORCISH_IDOL, { 1, 3 } },
-        { DID_ATTACK_FRIEND, ATTACK_FRIEND_RESPONSE },
+        { DID_DESECRATE_ORCISH_REMAINS, { "you desecrate orcish remains", true, 1 } },
+        { DID_DESTROY_ORCISH_IDOL, { "you destroy orcish idols", true, 1, 3 } },
+        { DID_ATTACK_FRIEND, _on_attack_friend("you attack allied orcs") },
     },
     // GOD_JIYVA,
     {
         { DID_KILL_SLIME, {
+            "you kill slimes", true,
             1, 2, nullptr, nullptr, [] (const monster* victim) -> bool {
                 return victim && !victim->is_shapeshifter();
             }
         } },
         { DID_ATTACK_NEUTRAL, {
+            nullptr, true,
             1, 1, nullptr, nullptr, [] (const monster* victim) -> bool {
                 return victim
                     && mons_is_slime(victim) && !victim->is_shapeshifter();
             }
         } },
-        { DID_ATTACK_FRIEND, ATTACK_FRIEND_RESPONSE },
+        { DID_ATTACK_FRIEND, _on_attack_friend("you attack fellow slimes") },
     },
     // GOD_FEDHAS,
     {
         { DID_CORPSE_VIOLATION, {
+            "you use necromancy on corpses, chunks or skeletons", true,
             1, 1, " forgives your inadvertent necromancy, just this once."
         } },
         { DID_KILL_PLANT, {
+            "you destroy plants", false,
             1, 0
         } },
-        { DID_ATTACK_FRIEND, ATTACK_FRIEND_RESPONSE },
-        { DID_FRIEND_DIED, FEDHAS_FRIEND_DEATH_RESPONSE },
-        { DID_SOULED_FRIEND_DIED, FEDHAS_FRIEND_DEATH_RESPONSE },
+        { DID_ATTACK_FRIEND, _on_attack_friend(nullptr) },
+
+        { DID_FRIEND_DIED, _on_fedhas_friend_death("allied flora die") },
+        { DID_SOULED_FRIEND_DIED, _on_fedhas_friend_death(nullptr) },
     },
     // GOD_CHEIBRIADOS,
     {
         { DID_HASTY, {
+            "you hasten yourself or others", true,
             1, 1, " forgives your accidental hurry, just this once.",
             " thinks you should slow down.", nullptr, -5
         } },
@@ -449,6 +507,7 @@ static peeve_map divine_peeves[] =
     // GOD_DITHMENOS,
     {
         { DID_FIRE, {
+            "you use fiery magic or items", false,
             1, 1, " forgives your accidental fire-starting, just this once.",
             " does not appreciate your starting fires!", nullptr, -5
         } },
@@ -459,8 +518,67 @@ static peeve_map divine_peeves[] =
     peeve_map(),
     // GOD_RU,
     peeve_map(),
+    // GOD_PAKELLAS
+    {
+        { DID_CHANNEL, {
+            "you channel magical energy", true,
+            1, 1,
+        } },
+    },
 };
 
+string get_god_dislikes(god_type which_god)
+{
+    // Return early for the special cases.
+    if (which_god == GOD_NO_GOD || which_god == GOD_XOM)
+        return "";
+
+    string text;
+    vector<string> dislikes;        // Piety loss
+    vector<string> really_dislikes; // Penance
+
+    for (const auto& entry : divine_peeves[which_god])
+    {
+        if (entry.second.desc)
+        {
+            if (entry.second.really_dislike)
+                really_dislikes.emplace_back(entry.second.desc);
+            else
+                dislikes.emplace_back(entry.second.desc);
+        }
+    }
+
+    if (which_god == GOD_CHEIBRIADOS)
+        really_dislikes.emplace_back("use unnaturally quick items");
+
+    if (dislikes.empty() && really_dislikes.empty())
+        return "";
+
+    if (!dislikes.empty())
+    {
+        text += uppercase_first(god_name(which_god));
+        text += " dislikes it when ";
+        text += comma_separated_line(dislikes.begin(), dislikes.end(),
+                                     " or ", ", ");
+        text += ".";
+
+        if (!really_dislikes.empty())
+            text += " ";
+    }
+
+    if (!really_dislikes.empty())
+    {
+        text += uppercase_first(god_name(which_god));
+        text += " strongly dislikes it when ";
+        text += comma_separated_line(really_dislikes.begin(),
+                                     really_dislikes.end(),
+                                     " or ", ", ");
+        text += ".";
+    }
+
+    return text;
+}
+
 
 /**
  * Handle Dithmenos's piety scaling based on piety rank.
@@ -479,6 +597,10 @@ static void _dithmenos_kill(int &piety, int &denom, const monster* /*victim*/)
 /// A definition of the way in which a god likes a conduct being taken.
 struct like_response
 {
+    /// How to describe this conduct on the god description screen.
+    const char* desc;
+    /// Whether the god should be described as "especially" liking it.
+    bool really_like;
     /** Gain in piety for triggering this conduct; added to calculated denom.
      *
      * This number is usually negative. In that case, the maximum piety gain
@@ -538,21 +660,16 @@ struct like_response
  */
 static int _piety_bonus_for_holiness(mon_holy_type holiness)
 {
-    switch (holiness)
-    {
-        case MH_NATURAL:
-        case MH_PLANT:
-            return -6;
-        case MH_UNDEAD:
-            return -5;
-        case MH_DEMONIC:
-            return -4;
-        case MH_HOLY:
-        case MH_NONLIVING: // hi, yred
-            return -3;
-        default:
-            die("unknown holiness type; can't give a bonus");
-    }
+    if (holiness & (MH_NATURAL | MH_PLANT))
+        return -6;
+    else if (holiness & MH_UNDEAD)
+        return -5;
+    else if (holiness & MH_DEMONIC)
+        return -4;
+    else if (holiness & (MH_HOLY | MH_NONLIVING)) // hi, yred
+        return -3;
+    else
+        die("unknown holiness type; can't give a bonus");
 }
 
 /**
@@ -565,10 +682,14 @@ static int _piety_bonus_for_holiness(mon_holy_type holiness)
  * @param special       A special-case function.
  * @return              An appropropriate like_response.
  */
-static like_response _on_kill(mon_holy_type holiness, bool god_is_good = false,
-                              special_piety_t special = nullptr)
+static like_response _on_kill(const char* desc, mon_holy_type holiness,
+                              bool god_is_good = false,
+                              special_piety_t special = nullptr,
+                              bool really_like = false)
 {
     like_response response = {
+        desc,
+        really_like,
         _piety_bonus_for_holiness(holiness),
         18,
         god_is_good ? 0 : 2,
@@ -579,39 +700,46 @@ static like_response _on_kill(mon_holy_type holiness, bool god_is_good = false,
 }
 
 /// Response for gods that like killing the living.
-static const like_response KILL_LIVING_RESPONSE = _on_kill(MH_NATURAL);
+static const like_response KILL_LIVING_RESPONSE =
+    _on_kill("you kill living beings", MH_NATURAL);
 
 /// Response for non-good gods that like killing (?) undead.
-static const like_response KILL_UNDEAD_RESPONSE = _on_kill(MH_UNDEAD);
+static const like_response KILL_UNDEAD_RESPONSE =
+    _on_kill("you kill the undead", MH_UNDEAD);
 
 /// Response for non-good gods that like killing (?) demons.
-static const like_response KILL_DEMON_RESPONSE = _on_kill(MH_DEMONIC);
+static const like_response KILL_DEMON_RESPONSE =
+    _on_kill("you kill demons", MH_DEMONIC);
 
 /// Response for non-good gods that like killing (?) holies.
-static const like_response KILL_HOLY_RESPONSE =  _on_kill(MH_HOLY);
+static const like_response KILL_HOLY_RESPONSE =
+    _on_kill("you kill holy beings", MH_HOLY);
 
-/// Response for TSO/Zin when you kill (most) things they hate.
-static const like_response GOOD_KILL_RESPONSE = _on_kill(MH_DEMONIC, true);
 // Note that holy deaths are special - they're always noticed...
 // If you or any friendly kills one, you'll get the credit/blame.
 
-static const like_response OKAWARU_KILL = {
-    0, 0, 0, nullptr, [] (int &piety, int &denom, const monster* victim)
+static like_response okawaru_kill(const char* desc)
+{
+    return
     {
-        piety = get_fuzzied_monster_difficulty(victim);
-        dprf("fuzzied monster difficulty: %4.2f", piety * 0.01);
-        denom = 550;
-
-        if (piety > 3200)
+        desc, false,
+        0, 0, 0, nullptr, [] (int &piety, int &denom, const monster* victim)
         {
-            mprf(MSGCH_GOD, you.religion,
-                 "<white>%s is honoured by your kill.</white>",
-                 uppercase_first(god_name(you.religion)).c_str());
+            piety = get_fuzzied_monster_difficulty(victim);
+            dprf("fuzzied monster difficulty: %4.2f", piety * 0.01);
+            denom = 550;
+
+            if (piety > 3200)
+            {
+                mprf(MSGCH_GOD, you.religion,
+                     "<white>%s is honoured by your kill.</white>",
+                     uppercase_first(god_name(you.religion)).c_str());
+            }
+            else if (piety > 9) // might still be miniscule
+                simple_god_message(" accepts your kill.");
         }
-        else if (piety > 9) // might still be miniscule
-            simple_god_message(" accepts your kill.");
-    }
-};
+    };
+}
 
 
 typedef map<conduct_type, like_response> like_map;
@@ -623,16 +751,18 @@ static like_map divine_likes[] =
     like_map(),
     // GOD_ZIN,
     {
-        { DID_KILL_UNCLEAN, GOOD_KILL_RESPONSE },
-        { DID_KILL_CHAOTIC, GOOD_KILL_RESPONSE },
+        { DID_KILL_UNCLEAN, _on_kill("you kill unclean or chaotic beings", MH_DEMONIC, true) },
+        { DID_KILL_CHAOTIC, _on_kill(nullptr, MH_DEMONIC, true) },
     },
     // GOD_SHINING_ONE,
     {
-        { DID_KILL_UNDEAD, _on_kill(MH_UNDEAD, true) },
-        { DID_KILL_DEMON, GOOD_KILL_RESPONSE },
-        { DID_KILL_NATURAL_UNHOLY, GOOD_KILL_RESPONSE },
-        { DID_KILL_NATURAL_EVIL, GOOD_KILL_RESPONSE },
+        { DID_KILL_UNDEAD, _on_kill("you kill the undead", MH_UNDEAD, true) },
+        { DID_KILL_DEMON, _on_kill("you kill demons", MH_DEMONIC, true) },
+        { DID_KILL_NATURAL_UNHOLY, _on_kill("you kill unholy or evil beings", MH_DEMONIC, true) },
+        { DID_KILL_NATURAL_EVIL, _on_kill(nullptr, MH_DEMONIC, true) },
         { DID_SEE_MONSTER, {
+            "you meet creatures to determine whether they need to be "
+            "eradicated", false,
             0, 0, 0, nullptr, [] (int &piety, int &denom, const monster* victim)
             {
                 // don't give piety for seeing things we get piety for killing.
@@ -654,15 +784,17 @@ static like_map divine_likes[] =
     // GOD_YREDELEMNUL,
     {
         { DID_KILL_LIVING, KILL_LIVING_RESPONSE },
-        { DID_KILL_HOLY, _on_kill(MH_HOLY, false,
+        { DID_KILL_HOLY, _on_kill("you kill holy beings", MH_HOLY, false,
                                   [](int &piety, int &denom,
                                      const monster* victim)
             {
                 piety *= 2;
                 simple_god_message(" appreciates your killing of a holy being.");
-            }
+            },
+            true
         ) },
-        { DID_KILL_ARTIFICIAL, _on_kill(MH_NONLIVING, false) },
+        { DID_KILL_ARTIFICIAL, _on_kill("you kill artificial beings",
+                                        MH_NONLIVING, false) },
     },
     // GOD_XOM,
     like_map(),
@@ -675,14 +807,14 @@ static like_map divine_likes[] =
     },
     // GOD_OKAWARU,
     {
-        { DID_KILL_LIVING, OKAWARU_KILL },
-        { DID_KILL_UNDEAD, OKAWARU_KILL },
-        { DID_KILL_DEMON, OKAWARU_KILL },
-        { DID_KILL_HOLY, OKAWARU_KILL },
+        { DID_KILL_LIVING, okawaru_kill("you kill living beings") },
+        { DID_KILL_UNDEAD, okawaru_kill("you kill the undead") },
+        { DID_KILL_DEMON, okawaru_kill("you kill demons") },
+        { DID_KILL_HOLY, okawaru_kill("you kill holy beings") },
     },
     // GOD_MAKHLEB,
     {
-        { DID_KILL_LIVING, _on_kill(MH_NATURAL, false,
+        { DID_KILL_LIVING, _on_kill("you kill living beings", MH_NATURAL, false,
                                   [](int &piety, int &denom,
                                      const monster* victim)
             {
@@ -697,6 +829,7 @@ static like_map divine_likes[] =
     // GOD_SIF_MUNA,
     {
         { DID_SPELL_PRACTISE, {
+            "you train your various spell casting skills", false,
             0, 0, 0, nullptr,
             [] (int &piety, int &denom, const monster* /*victim*/)
             {
@@ -707,7 +840,7 @@ static like_map divine_likes[] =
     },
     // GOD_TROG,
     {
-        { DID_KILL_LIVING, _on_kill(MH_NATURAL, false,
+        { DID_KILL_LIVING, _on_kill("you kill living beings", MH_NATURAL, false,
                                   [](int &piety, int &denom,
                                      const monster* victim)
             {
@@ -718,12 +851,14 @@ static like_map divine_likes[] =
         { DID_KILL_DEMON, KILL_DEMON_RESPONSE },
         { DID_KILL_HOLY, KILL_HOLY_RESPONSE },
         { DID_KILL_WIZARD, {
+            "you kill wizards and other users of magic", true,
             -6, 10, 0, " appreciates your killing of a magic user."
         } },
     },
     // GOD_NEMELEX_XOBEH,
     {
         { DID_EXPLORATION, {
+            "you explore the world", false,
             0, 0, 0, nullptr,
             [] (int &piety, int &denom, const monster* /*victim*/)
             {
@@ -735,6 +870,7 @@ static like_map divine_likes[] =
     // GOD_ELYVILON,
     {
         { DID_EXPLORATION, {
+            "you explore the world", false,
             0, 0, 0, nullptr,
             [] (int &piety, int &denom, const monster* /*victim*/)
             {
@@ -745,7 +881,7 @@ static like_map divine_likes[] =
     },
     // GOD_LUGONU,
     {
-        { DID_KILL_LIVING, _on_kill(MH_NATURAL, false,
+        { DID_KILL_LIVING, _on_kill("you kill living beings", MH_NATURAL, false,
                                   [](int &piety, int &denom,
                                      const monster* victim)
             {
@@ -757,6 +893,7 @@ static like_map divine_likes[] =
         { DID_KILL_DEMON, KILL_DEMON_RESPONSE },
         { DID_KILL_HOLY, KILL_HOLY_RESPONSE },
         { DID_BANISH, {
+            "you banish creatures to the Abyss", false,
             -6, 18, 2, " claims a new guest."
         } },
     },
@@ -767,7 +904,8 @@ static like_map divine_likes[] =
         { DID_KILL_DEMON, KILL_DEMON_RESPONSE },
         { DID_KILL_HOLY, KILL_HOLY_RESPONSE },
         { DID_KILL_PRIEST, {
-            -6, 10, 0, " appreciates your killing of a heretic priest."
+            "you kill the priests of other religions", true,
+            -6, 18, 0, " appreciates your killing of a heretic priest."
         } },
     },
     // GOD_JIYVA,
@@ -777,6 +915,7 @@ static like_map divine_likes[] =
     // GOD_CHEIBRIADOS,
     {
         { DID_KILL_FAST, {
+            "you kill fast things, relative to your speed", false,
             -6, 18, 2, nullptr,
             [] (int &piety, int &/*denom*/, const monster* victim)
             {
@@ -799,6 +938,7 @@ static like_map divine_likes[] =
     // GOD_ASHENZARI,
     {
         { DID_EXPLORATION, {
+            "you explore the world (preferably while bound by curses)", false,
             0, 0, 0, nullptr,
             [] (int &piety, int &denom, const monster* /*victim*/)
             {
@@ -812,11 +952,16 @@ static like_map divine_likes[] =
     },
     // GOD_DITHMENOS,
     {
-        { DID_KILL_LIVING, _on_kill(MH_NATURAL, false, _dithmenos_kill) },
-        { DID_KILL_UNDEAD, _on_kill(MH_UNDEAD, false, _dithmenos_kill) },
-        { DID_KILL_DEMON, _on_kill(MH_DEMONIC, false, _dithmenos_kill) },
-        { DID_KILL_HOLY, _on_kill(MH_HOLY, false, _dithmenos_kill) },
+        { DID_KILL_LIVING, _on_kill("you kill living beings",
+                                    MH_NATURAL, false, _dithmenos_kill) },
+        { DID_KILL_UNDEAD, _on_kill("you kill the undead",
+                                    MH_UNDEAD, false, _dithmenos_kill) },
+        { DID_KILL_DEMON, _on_kill("you kill demons",
+                                   MH_DEMONIC, false, _dithmenos_kill) },
+        { DID_KILL_HOLY, _on_kill("you kill holy beings",
+                                  MH_HOLY, false, _dithmenos_kill) },
         { DID_KILL_FIERY, {
+            "you kill beings that bring fire to the dungeon", true,
             -6, 10, 0, " appreciates your extinguishing a source of fire."
         } },
     },
@@ -832,7 +977,7 @@ static like_map divine_likes[] =
     // GOD_RU,
     {
         { DID_EXPLORATION, {
-            0, 0, 0, nullptr,
+            nullptr, false, 0, 0, 0, nullptr,
             [] (int &piety, int &denom, const monster* /*victim*/)
             {
                 piety = 0;
@@ -845,6 +990,20 @@ static like_map divine_likes[] =
             }
         } },
     },
+    // GOD_PAKELLAS,
+    {
+        { DID_KILL_LIVING, _on_kill("you kill living beings", MH_NATURAL, false,
+                                  [](int &piety, int &denom,
+                                     const monster* victim)
+            {
+                piety *= 4;
+                denom *= 3;
+            }
+        ) },
+        { DID_KILL_UNDEAD, KILL_UNDEAD_RESPONSE },
+        { DID_KILL_DEMON, KILL_DEMON_RESPONSE },
+        { DID_KILL_HOLY, KILL_HOLY_RESPONSE },
+    },
 };
 
 /**
@@ -971,6 +1130,82 @@ void disable_attack_conducts(god_conduct_trigger conduct[3])
         conduct[i].enabled = false;
 }
 
+string get_god_likes(god_type which_god)
+{
+    if (which_god == GOD_NO_GOD || which_god == GOD_XOM)
+        return "";
+
+    string text = uppercase_first(god_name(which_god));
+    vector<string> likes;
+    vector<string> really_likes;
+
+    // Unique/unusual piety gain methods first.
+    switch (which_god)
+    {
+    case GOD_FEDHAS:
+        likes.emplace_back("you promote the decay of nearby corpses by "
+                           "<w>p</w>raying");
+        break;
+    case GOD_TROG:
+        likes.emplace_back("you destroy spellbooks via the <w>a</w> command");
+        break;
+    case GOD_JIYVA:
+        likes.emplace_back("you sacrifice items by allowing slimes to consume "
+                           "them");
+        break;
+    case GOD_GOZAG:
+        likes.emplace_back("you collect gold");
+        break;
+    case GOD_RU:
+        likes.emplace_back("you make personal sacrifices");
+        break;
+    case GOD_ZIN:
+        likes.emplace_back("you donate money");
+        break;
+    default:
+        break;
+    }
+
+
+    for (const auto& entry : divine_likes[which_god])
+    {
+        if (entry.second.desc)
+        {
+            if (entry.second.really_like)
+                really_likes.emplace_back(entry.second.desc);
+            else
+                likes.emplace_back(entry.second.desc);
+        }
+    }
+
+    if (likes.empty() && really_likes.empty())
+        text += " doesn't like anything? This is a bug; please report it.";
+    else
+    {
+        text += " likes it when ";
+        text += comma_separated_line(likes.begin(), likes.end());
+        text += ".";
+
+        if (!really_likes.empty())
+        {
+            text += " ";
+            text += uppercase_first(god_name(which_god));
+
+            text += " especially likes it when ";
+            text += comma_separated_line(really_likes.begin(),
+                                         really_likes.end());
+            text += ".";
+        }
+    }
+
+    return text;
+}
+
+bool god_hates_cannibalism(god_type god)
+{
+    return divine_peeves[god].count(DID_CANNIBALISM);
+}
+
 /**
  * Will this god definitely be upset if you cast this spell?
  *
