@@ -39,5 +39,8 @@ void disable_attack_conducts(god_conduct_trigger conduct[3]);
 void god_conduct_turn_start();
 
 bool god_punishes_spell(spell_type spell, god_type god);
+bool god_hates_cannibalism(god_type god);
 
+string get_god_likes(god_type which_god);
+string get_god_dislikes(god_type which_god);
 #endif
