@@ -26,7 +26,7 @@
 #include "spl-util.h"
 
 static bool _is_bookrod_type(const item_def& item,
-                             bool (*suitable)(spell_type spell))
+                             bool (*matches)(spell_type spell))
 {
     if (!item.defined())
         return false;
@@ -40,24 +40,18 @@ static bool _is_bookrod_type(const item_def& item,
     }
 
     if (item.base_type == OBJ_RODS)
-        return suitable(spell_in_rod(static_cast<rod_type>(item.sub_type)));
+        return matches(spell_in_rod(static_cast<rod_type>(item.sub_type)));
 
     if (!item_is_spellbook(item))
         return false;
 
-    int total       = 0;
-    int total_liked = 0;
-
+    // Book matches only if all the spells match
     for (spell_type spell : spells_in_book(item))
     {
-        total++;
-        if (suitable(spell))
-            total_liked++;
+        if (!matches(spell))
+            return false;
     }
-
-    // If at least half of the available spells are suitable, the whole
-    // spellbook is, too.
-    return total_liked >= (total / 2) + 1;
+    return true;
 }
 
 bool is_holy_item(const item_def& item)
@@ -66,7 +60,7 @@ bool is_holy_item(const item_def& item)
 
     if (is_unrandom_artefact(item))
     {
-        const unrandart_entry* entry = get_unrand_entry(item.special);
+        const unrandart_entry* entry = get_unrand_entry(item.unrand_idx);
 
         if (entry->flags & UNRAND_FLAG_HOLY)
             return true;
@@ -94,7 +88,7 @@ bool is_unholy_item(const item_def& item)
 
     if (is_unrandom_artefact(item))
     {
-        const unrandart_entry* entry = get_unrand_entry(item.special);
+        const unrandart_entry* entry = get_unrand_entry(item.unrand_idx);
 
         if (entry->flags & UNRAND_FLAG_UNHOLY)
             return true;
@@ -142,11 +136,8 @@ bool is_potentially_evil_item(const item_def& item)
             return true;
         break;
     case OBJ_RODS:
-        if (item.sub_type == ROD_DESTRUCTION
-            || item.sub_type == ROD_CLOUDS)
-        {
+        if (item.sub_type == ROD_CLOUDS)
             return true;
-        }
         break;
     default:
         break;
@@ -162,7 +153,7 @@ bool is_corpse_violating_item(const item_def& item)
 
     if (is_unrandom_artefact(item))
     {
-        const unrandart_entry* entry = get_unrand_entry(item.special);
+        const unrandart_entry* entry = get_unrand_entry(item.unrand_idx);
 
         if (entry->flags & UNRAND_FLAG_CORPSE_VIOLATING)
             return true;
@@ -191,7 +182,7 @@ bool is_evil_item(const item_def& item)
 {
     if (is_unrandom_artefact(item))
     {
-        const unrandart_entry* entry = get_unrand_entry(item.special);
+        const unrandart_entry* entry = get_unrand_entry(item.unrand_idx);
 
         if (entry->flags & UNRAND_FLAG_EVIL)
             return true;
@@ -208,8 +199,6 @@ bool is_evil_item(const item_def& item)
                || item_brand == SPWPN_REAPING;
         }
         break;
-    case OBJ_WANDS:
-        return item.sub_type == WAND_DRAINING;
     case OBJ_POTIONS:
         return is_blood_potion(item);
     case OBJ_SCROLLS:
@@ -219,8 +208,8 @@ bool is_evil_item(const item_def& item)
     case OBJ_BOOKS:
     case OBJ_RODS:
         return _is_bookrod_type(item, is_evil_spell);
-    case OBJ_MISCELLANY:
-        return item.sub_type == MISC_LANTERN_OF_SHADOWS;
+    case OBJ_JEWELLERY:
+        return item.sub_type == AMU_HARM;
     default:
         return false;
     }
@@ -230,7 +219,7 @@ bool is_unclean_item(const item_def& item)
 {
     if (is_unrandom_artefact(item))
     {
-        const unrandart_entry* entry = get_unrand_entry(item.special);
+        const unrandart_entry* entry = get_unrand_entry(item.unrand_idx);
 
         if (entry->flags & UNRAND_FLAG_UNCLEAN)
             return true;
@@ -248,7 +237,7 @@ bool is_chaotic_item(const item_def& item)
 
     if (is_unrandom_artefact(item))
     {
-        const unrandart_entry* entry = get_unrand_entry(item.special);
+        const unrandart_entry* entry = get_unrand_entry(item.unrand_idx);
 
         if (entry->flags & UNRAND_FLAG_CHAOTIC)
             return true;
@@ -361,6 +350,9 @@ bool is_hasty_item(const item_def& item)
 
 bool is_poisoned_item(const item_def& item)
 {
+    if (is_unrandom_artefact(item, UNRAND_OLGREB))
+        return true;
+
     switch (item.base_type)
     {
     case OBJ_WEAPONS:
@@ -404,11 +396,8 @@ static bool _is_potentially_fiery_item(const item_def& item)
             return true;
         break;
     case OBJ_RODS:
-        if (item.sub_type == ROD_DESTRUCTION
-            || item.sub_type == ROD_CLOUDS)
-        {
+        if (item.sub_type == ROD_CLOUDS)
             return true;
-        }
         break;
     default:
         break;
@@ -419,10 +408,6 @@ static bool _is_potentially_fiery_item(const item_def& item)
 
 bool is_fiery_item(const item_def& item)
 {
-    // Flaming Death is handled through its fire brand.
-    if (is_unrandom_artefact(item, UNRAND_HELLFIRE))
-        return true;
-
     switch (item.base_type)
     {
     case OBJ_WEAPONS:
@@ -440,12 +425,8 @@ bool is_fiery_item(const item_def& item)
         }
         break;
     case OBJ_WANDS:
-        if (item.sub_type == WAND_FLAME
-            || item.sub_type == WAND_FIRE
-            || item.sub_type == WAND_FIREBALL)
-        {
+        if (item.sub_type == WAND_FLAME)
             return true;
-        }
         break;
     case OBJ_SCROLLS:
         if (item.sub_type == SCR_IMMOLATION)
@@ -470,6 +451,16 @@ bool is_fiery_item(const item_def& item)
     return false;
 }
 
+bool is_channeling_item(const item_def& item)
+{
+    if (is_unrandom_artefact(item, UNRAND_WUCAD_MU))
+        return true;
+
+    return item.base_type == OBJ_STAVES && item.sub_type == STAFF_ENERGY
+           || item.base_type == OBJ_MISCELLANY
+              && item.sub_type == MISC_CRYSTAL_BALL_OF_ENERGY;
+}
+
 bool is_unholy_spell(spell_type spell)
 {
     unsigned int flags = get_spell_flags(spell);
@@ -487,8 +478,10 @@ bool is_corpse_violating_spell(spell_type spell)
 bool is_evil_spell(spell_type spell)
 {
     const spschools_type disciplines = get_spell_disciplines(spell);
+    unsigned int flags = get_spell_flags(spell);
 
-    return bool(disciplines & SPTYP_NECROMANCY);
+    return bool(disciplines & SPTYP_NECROMANCY)
+           && !bool(flags & SPFLAG_NOT_EVIL);
 }
 
 bool is_unclean_spell(spell_type spell)
@@ -524,6 +517,11 @@ static bool _your_god_hates_spell(spell_type spell)
     return god_hates_spell(spell, you.religion);
 }
 
+static bool _your_god_hates_rod_spell(spell_type spell)
+{
+    return god_hates_spell(spell, you.religion, true);
+}
+
 static conduct_type good_god_hates_item_handling(const item_def &item)
 {
     if (!is_good_god(you.religion)
@@ -575,6 +573,8 @@ conduct_type god_hates_item_handling(const item_def &item)
     case GOD_SHINING_ONE:
         if (item_type_known(item) && is_poisoned_item(item))
             return DID_POISON;
+        if (is_unrandom_artefact(item, UNRAND_CAPTAIN))
+            return DID_UNCHIVALRIC_ATTACK;
         break;
 
     case GOD_YREDELEMNUL:
@@ -590,7 +590,7 @@ conduct_type god_hates_item_handling(const item_def &item)
         {
             return DID_SPELL_PRACTISE;
         }
-        // Only Trog cares about spellsbooks vs rods.
+        // Only Trog cares about spellbooks vs rods.
         if (item.base_type == OBJ_RODS)
             return DID_NOTHING;
         break;
@@ -618,6 +618,11 @@ conduct_type god_hates_item_handling(const item_def &item)
         }
         break;
 
+    case GOD_PAKELLAS:
+        if (item_type_known(item) && is_channeling_item(item))
+            return DID_CHANNEL;
+        break;
+
     default:
         break;
     }
@@ -628,7 +633,10 @@ conduct_type god_hates_item_handling(const item_def &item)
         return DID_NECROMANCY;
     }
 
-    if (item_type_known(item) && _is_bookrod_type(item, _your_god_hates_spell))
+    if (item_type_known(item) && _is_bookrod_type(item,
+                                                  item.base_type == OBJ_RODS
+                                                  ? _your_god_hates_rod_spell
+                                                  : _your_god_hates_spell))
     {
         return NUM_CONDUCTS; // FIXME: Get the specific reason, if it
     }                          // will ever be needed for spellbooks.
@@ -641,85 +649,75 @@ bool god_hates_item(const item_def &item)
     return god_hates_item_handling(item) != DID_NOTHING;
 }
 
-bool god_dislikes_spell_type(spell_type spell, god_type god)
+/**
+ * Does the given god like items of the given kind enough to make artefacts
+ * from them? (Thematically.)
+ *
+ * @param item          The item which may be the basis for an artefact.
+ * @param which_god     The god in question.
+ * @return              Whether it makes sense for the given god to make an
+ *                      artefact out of the given item. Thematically.
+ *                      (E.g., Ely shouldn't be forging swords.)
+ */
+bool god_likes_item_type(const item_def &item, god_type which_god)
 {
-    if (god_hates_spell(spell, god))
-        return true;
-
-    unsigned int flags       = get_spell_flags(spell);
-    spschools_type disciplines = get_spell_disciplines(spell);
-
-    switch (god)
+    // XXX: also check god_hates_item()?
+    switch (which_god)
     {
-    case GOD_SHINING_ONE:
-        // TSO probably wouldn't like spells which would put enemies
-        // into a state where attacking them would be unchivalrous.
-        if (spell == SPELL_CAUSE_FEAR || spell == SPELL_PARALYSE
-            || spell == SPELL_CONFUSE || spell == SPELL_MASS_CONFUSION
-            || spell == SPELL_HIBERNATION)
-        {
-            return true;
-        }
-        break;
+        case GOD_ELYVILON:
+            // Peaceful healer god: no weapons, no berserking.
+            if (item.base_type == OBJ_WEAPONS)
+                return false;
 
-    case GOD_XOM:
-        // Ideally, Xom would only like spells which have a random
-        // effect, are risky to use, or would otherwise amuse him, but
-        // that would be a really small number of spells.
+            if (item.is_type(OBJ_JEWELLERY, AMU_RAGE))
+                return false;
+            break;
 
-        // Neutral, but in an amusing way.
-        if (spell == SPELL_INNER_FLAME)
-            return false;
+        case GOD_SHINING_ONE:
+            // Crusader god: holiness, honourable combat.
+            if (item.is_type(OBJ_JEWELLERY, RING_STEALTH))
+                return false;
+            break;
 
-        // Xom would probably find these extra boring.
-        if (flags & (SPFLAG_HELPFUL | SPFLAG_NEUTRAL | SPFLAG_ESCAPE
-                     | SPFLAG_RECOVERY))
-        {
-            return true;
-        }
+        case GOD_SIF_MUNA:
+        case GOD_VEHUMET:
+            // The magic gods: no weapons, no preventing spellcasting.
+            if (item.base_type == OBJ_WEAPONS)
+                return false;
+            break;
 
-        // Things are more fun for Xom the less the player knows in
-        // advance.
-        if (disciplines & SPTYP_DIVINATION)
-            return true;
-        break;
+        case GOD_TROG:
+            // Anti-magic god: no spell use, no enhancing magic.
+            if (item.base_type == OBJ_BOOKS)
+                return false;
 
-    case GOD_ELYVILON:
-        // A peaceful god of healing wouldn't like combat spells.
-        if (disciplines & SPTYP_CONJURATION)
-            return true;
+            if (item.base_type == OBJ_JEWELLERY
+                && (item.sub_type == RING_WIZARDRY
+                    || item.sub_type == RING_ICE
+                    || item.sub_type == RING_MAGICAL_POWER))
+            {
+                return false;
+            }
+            break;
 
-        // Also doesn't like battle spells of the non-conjuration type.
-        if (flags & SPFLAG_BATTLE)
-            return true;
-        break;
+        case GOD_CHEIBRIADOS:
+            // Slow god: no quick blades, no berserking.
+            if (item.is_type(OBJ_WEAPONS, WPN_QUICK_BLADE))
+                return false;
 
-    default:
-        break;
+            if (item.is_type(OBJ_JEWELLERY, AMU_RAGE))
+                return false;
+            break;
+
+        case GOD_DITHMENOS:
+            // Shadow god: no reducing stealth.
+            if (item.is_type(OBJ_JEWELLERY, RING_LOUDNESS))
+                return false;
+            break;
+
+        default:
+            break;
     }
 
-    return false;
-}
-
-bool god_dislikes_spell_discipline(spschools_type discipline, god_type god)
-{
-    if (is_good_god(god) && (discipline & SPTYP_NECROMANCY))
-        return true;
-
-    switch (god)
-    {
-    case GOD_SHINING_ONE:
-        return bool(discipline & SPTYP_POISON);
-
-    case GOD_ELYVILON:
-        return bool(discipline & (SPTYP_CONJURATION | SPTYP_SUMMONING));
-
-    case GOD_DITHMENOS:
-        return bool(discipline & SPTYP_FIRE);
-
-    default:
-        break;
-    }
-
-    return false;
+    return true;
 }
