@@ -18,6 +18,7 @@
 #include "itemprop.h"
 #include "items.h"
 #include "libutil.h" // map_find
+#include "randbook.h"
 #include "spl-book.h"
 #include "state.h"
 #include "stepdown.h"
@@ -86,7 +87,7 @@ void item_colour(item_def &item)
                                          // since it might be the only set bit
     }
 
-    if (is_unrandom_artefact(item) && !is_randapp_artefact(item))
+    if (is_unrandom_artefact(item))
         return; // don't stomp on item.special!
 
     // initialize item appearance.
@@ -123,7 +124,7 @@ static bool _is_boring_item(int type, int sub_type)
         }
         break;
     case OBJ_JEWELLERY:
-        return sub_type == AMU_RESIST_MUTATION;
+        return sub_type == AMU_NOTHING;
     default:
         break;
     }
@@ -182,13 +183,14 @@ static weapon_type _determine_weapon_subtype(int item_level)
     }
 }
 
-static bool _try_make_item_unrand(item_def& item, int force_type)
+static bool _try_make_item_unrand(item_def& item, int force_type, int agent)
 {
-    if (player_in_branch(BRANCH_PANDEMONIUM))
+    if (player_in_branch(BRANCH_PANDEMONIUM) && agent == -1)
         return false;
 
     int idx = find_okay_unrandart(item.base_type, force_type,
-                                  player_in_branch(BRANCH_ABYSS));
+                                  player_in_branch(BRANCH_ABYSS)
+                                      && agent == -1);
 
     if (idx != -1 && make_item_unrandart(item, idx))
         return true;
@@ -198,7 +200,8 @@ static bool _try_make_item_unrand(item_def& item, int force_type)
 
 // Return whether we made an artefact.
 static bool _try_make_weapon_artefact(item_def& item, int force_type,
-                                      int item_level, bool force_randart = false)
+                                      int item_level, bool force_randart,
+                                      int agent)
 {
     if (item_level > 2 && x_chance_in_y(101 + item_level * 3, 4000)
         || force_randart)
@@ -209,7 +212,7 @@ static bool _try_make_weapon_artefact(item_def& item, int force_type,
         if (one_chance_in(item_level == ISPEC_GOOD_ITEM ? 7 : 20)
             && !force_randart)
         {
-            if (_try_make_item_unrand(item, force_type))
+            if (_try_make_item_unrand(item, force_type, agent))
                 return true;
         }
 
@@ -368,15 +371,16 @@ static void _roll_weapon_type(item_def& item, int item_level)
     for (int i = 0; i < 1000; ++i)
     {
         item.sub_type = _determine_weapon_subtype(item_level);
-        if (is_weapon_brand_ok(item.sub_type, item.special, true))
+        if (is_weapon_brand_ok(item.sub_type, item.brand, true))
             return;
     }
 
-    item.special = SPWPN_NORMAL; // fall back to no brand
+    item.brand = SPWPN_NORMAL; // fall back to no brand
 }
 
 static void _generate_weapon_item(item_def& item, bool allow_uniques,
-                                  int force_type, int item_level)
+                                  int force_type, int item_level,
+                                  int agent = -1)
 {
     // Determine weapon type.
     if (force_type != OBJ_RANDOM)
@@ -387,9 +391,10 @@ static void _generate_weapon_item(item_def& item, bool allow_uniques,
     // Forced randart.
     if (item_level == ISPEC_RANDART)
     {
-        int ego = item.special;
+        int ego = item.brand;
         for (int i = 0; i < 100; ++i)
-            if (_try_make_weapon_artefact(item, force_type, 0, true) && is_artefact(item))
+            if (_try_make_weapon_artefact(item, force_type, 0, true, agent)
+                && is_artefact(item))
             {
                 if (ego > SPWPN_NORMAL)
                     item.props[ARTEFACT_PROPS_KEY].get_vector()[ARTP_BRAND].get_short() = ego;
@@ -410,7 +415,7 @@ static void _generate_weapon_item(item_def& item, bool allow_uniques,
 
     // If we make the unique roll, no further generation necessary.
     if (allow_uniques
-        && _try_make_weapon_artefact(item, force_type, item_level))
+        && _try_make_weapon_artefact(item, force_type, item_level, false, agent))
     {
         return;
     }
@@ -419,8 +424,8 @@ static void _generate_weapon_item(item_def& item, bool allow_uniques,
 
     // Artefacts handled, let's make a normal item.
     const bool force_good = item_level >= ISPEC_GIFT;
-    const bool forced_ego = item.special > 0;
-    const bool no_brand   = item.special == SPWPN_FORBID_BRAND;
+    const bool forced_ego = item.brand > 0;
+    const bool no_brand   = item.brand == SPWPN_FORBID_BRAND;
 
     if (no_brand)
         set_item_ego_type(item, OBJ_WEAPONS, SPWPN_NORMAL);
@@ -457,7 +462,7 @@ static void _generate_weapon_item(item_def& item, bool allow_uniques,
         }
 
         // if acquired item still not ego... enchant it up a bit.
-        if (force_good && item.special == SPWPN_NORMAL)
+        if (force_good && item.brand == SPWPN_NORMAL)
             item.plus += 2 + random2(3);
 
         const int chance = (force_good ? 200 : item_level);
@@ -472,7 +477,7 @@ static void _generate_weapon_item(item_def& item, bool allow_uniques,
         }
 
         // squash boring items.
-        if (!force_good && item.special == SPWPN_NORMAL && item.plus < 3)
+        if (!force_good && item.brand == SPWPN_NORMAL && item.plus < 3)
             item.plus = 0;
     }
     else
@@ -495,8 +500,8 @@ static special_missile_type _determine_missile_brand(const item_def& item,
                                                      int item_level)
 {
     // Forced ego.
-    if (item.special != 0)
-        return static_cast<special_missile_type>(item.special);
+    if (item.brand != 0)
+        return static_cast<special_missile_type>(item.brand);
 
     const bool force_good = item_level >= ISPEC_GIFT;
     special_missile_type rc = SPMSL_NORMAL;
@@ -506,6 +511,17 @@ static special_missile_type _determine_missile_brand(const item_def& item,
 
     switch (item.sub_type)
     {
+#if TAG_MAJOR_VERSION == 34
+    case MI_DART:
+#endif
+    case MI_THROWING_NET:
+    case MI_STONE:
+    case MI_LARGE_ROCK:
+    case MI_SLING_BULLET:
+    case MI_ARROW:
+    case MI_BOLT:
+        rc = SPMSL_NORMAL;
+        break;
     case MI_NEEDLE:
         // Curare is special cased, all the others aren't.
         if (got_curare_roll(item_level))
@@ -514,32 +530,13 @@ static special_missile_type _determine_missile_brand(const item_def& item,
             break;
         }
 
-        rc = random_choose_weighted(20, SPMSL_SLEEP,
-                                    20, SPMSL_SLOW,
-                                    20, SPMSL_CONFUSION,
+        rc = random_choose_weighted(30, SPMSL_SLEEP,
+                                    30, SPMSL_CONFUSION,
                                     10, SPMSL_PARALYSIS,
                                     10, SPMSL_FRENZY,
                                     nw, SPMSL_POISONED,
                                     0);
         break;
-    case MI_ARROW:
-        rc = random_choose_weighted(30, SPMSL_FLAME,
-                                    30, SPMSL_FROST,
-                                    20, SPMSL_POISONED,
-                                    15, SPMSL_DISPERSAL,
-                                    nw, SPMSL_NORMAL,
-                                    0);
-        break;
-    case MI_BOLT:
-        rc = random_choose_weighted(30, SPMSL_FLAME,
-                                    30, SPMSL_FROST,
-                                    20, SPMSL_POISONED,
-                                    15, SPMSL_PENETRATION,
-                                    15, SPMSL_SILVER,
-                                    10, SPMSL_STEEL,
-                                    nw, SPMSL_NORMAL,
-                                    0);
-        break;
     case MI_JAVELIN:
         rc = random_choose_weighted(30, SPMSL_RETURNING,
                                     32, SPMSL_PENETRATION,
@@ -559,31 +556,6 @@ static special_missile_type _determine_missile_brand(const item_def& item,
                                     nw, SPMSL_NORMAL,
                                     0);
         break;
-#if TAG_MAJOR_VERSION == 34
-    case MI_DART:
-#endif
-    case MI_STONE:
-        // deliberate fall through
-    case MI_LARGE_ROCK:
-        // Stones get no brands. Slings may be branded.
-        rc = SPMSL_NORMAL;
-        break;
-    case MI_SLING_BULLET:
-        rc = random_choose_weighted(30, SPMSL_FLAME,
-                                    30, SPMSL_FROST,
-                                    20, SPMSL_POISONED,
-                                    15, SPMSL_STEEL,
-                                    15, SPMSL_SILVER,
-                                    20, SPMSL_EXPLODING,
-                                    nw, SPMSL_NORMAL,
-                                    0);
-        break;
-    case MI_THROWING_NET:
-        rc = random_choose_weighted(30, SPMSL_STEEL,
-                                    30, SPMSL_SILVER,
-                                    nw, SPMSL_NORMAL,
-                                    0);
-        break;
     }
 
     ASSERT(is_missile_brand_ok(item.sub_type, rc, true));
@@ -593,8 +565,13 @@ static special_missile_type _determine_missile_brand(const item_def& item,
 
 bool is_missile_brand_ok(int type, int brand, bool strict)
 {
-    // Stones can never be branded.
-    if ((type == MI_STONE || type == MI_LARGE_ROCK) && brand != SPMSL_NORMAL
+    // Launcher ammo can never be branded.
+    if ((type == MI_STONE
+        || type == MI_LARGE_ROCK
+        || type == MI_SLING_BULLET
+        || type == MI_ARROW
+        || type == MI_BOLT)
+        && brand != SPMSL_NORMAL
         && strict)
     {
         return false;
@@ -611,7 +588,9 @@ bool is_missile_brand_ok(int type, int brand, bool strict)
 
     case SPMSL_CURARE:
     case SPMSL_PARALYSIS:
+#if TAG_MAJOR_VERSION == 34
     case SPMSL_SLOW:
+#endif
     case SPMSL_SLEEP:
     case SPMSL_CONFUSION:
 #if TAG_MAJOR_VERSION == 34
@@ -647,45 +626,36 @@ bool is_missile_brand_ok(int type, int brand, bool strict)
     switch (brand)
     {
     case SPMSL_FLAME:
-        return type == MI_SLING_BULLET || type == MI_ARROW
-               || type == MI_BOLT;
     case SPMSL_FROST:
-        return type == MI_SLING_BULLET || type == MI_ARROW
-               || type == MI_BOLT;
+        return false;
     case SPMSL_POISONED:
-        return type == MI_SLING_BULLET || type == MI_ARROW
-               || type == MI_BOLT || type == MI_JAVELIN
-               || type == MI_TOMAHAWK;
+        return type == MI_JAVELIN || type == MI_TOMAHAWK;
     case SPMSL_RETURNING:
         return type == MI_JAVELIN || type == MI_TOMAHAWK;
     case SPMSL_CHAOS:
-        return type == MI_SLING_BULLET || type == MI_ARROW
-               || type == MI_BOLT || type == MI_TOMAHAWK
-               || type == MI_JAVELIN || type == MI_THROWING_NET;
+        return type == MI_TOMAHAWK || type == MI_JAVELIN;
     case SPMSL_PENETRATION:
-        return type == MI_JAVELIN || type == MI_BOLT;
+        return type == MI_JAVELIN;
     case SPMSL_DISPERSAL:
-        return type == MI_ARROW || type == MI_TOMAHAWK;
+        return type == MI_TOMAHAWK;
     case SPMSL_EXPLODING:
-        return type == MI_SLING_BULLET || type == MI_TOMAHAWK;
+        return type == MI_TOMAHAWK;
     case SPMSL_STEEL: // deliberate fall through
     case SPMSL_SILVER:
-        return type == MI_BOLT || type == MI_SLING_BULLET
-               || type == MI_JAVELIN || type == MI_TOMAHAWK
-               || type == MI_THROWING_NET;
+        return type == MI_JAVELIN || type == MI_TOMAHAWK;
     default: break;
     }
 
-    // Assume yes, if we've gotten this far.
+    // Assume no, if we've gotten this far.
     return false;
 }
 
 static void _generate_missile_item(item_def& item, int force_type,
                                    int item_level)
 {
-    const bool no_brand = (item.special == SPMSL_FORBID_BRAND);
+    const bool no_brand = (item.brand == SPMSL_FORBID_BRAND);
     if (no_brand)
-        item.special = SPMSL_NORMAL;
+        item.brand = SPMSL_NORMAL;
 
     item.plus = 0;
 
@@ -743,7 +713,8 @@ static void _generate_missile_item(item_def& item, int force_type,
 }
 
 static bool _try_make_armour_artefact(item_def& item, int force_type,
-                                      int item_level, bool force_randart = false)
+                                      int item_level, bool force_randart,
+                                      int agent)
 {
     if (item_level > 2 && x_chance_in_y(101 + item_level * 3, 4000)
         || force_randart)
@@ -754,7 +725,7 @@ static bool _try_make_armour_artefact(item_def& item, int force_type,
         if (one_chance_in(item_level == ISPEC_GOOD_ITEM ? 7 : 20)
             && !force_randart)
         {
-            if (_try_make_item_unrand(item, force_type))
+            if (_try_make_item_unrand(item, force_type, agent))
                 return true;
         }
 
@@ -1021,7 +992,7 @@ bool is_armour_brand_ok(int type, int brand, bool strict)
 }
 
 /**
- * Return the number of plusses required for a type of armour to be noteable.
+ * Return the number of plusses required for a type of armour to be notable.
  * (From plus alone.)
  *
  * @param armour_type   The type of armour being considered.
@@ -1140,7 +1111,8 @@ static armour_type _get_random_armour_type(int item_level)
 }
 
 static void _generate_armour_item(item_def& item, bool allow_uniques,
-                                  int force_type, int item_level)
+                                  int force_type, int item_level,
+                                  int agent = -1)
 {
     if (force_type != OBJ_RANDOM)
         item.sub_type = force_type;
@@ -1149,7 +1121,7 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
         for (int i = 0; i < 1000; ++i)
         {
             item.sub_type = _get_random_armour_type(item_level);
-            if (is_armour_brand_ok(item.sub_type, item.special, true))
+            if (is_armour_brand_ok(item.sub_type, item.brand, true))
                 break;
         }
     }
@@ -1158,7 +1130,7 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
     if (item_level == ISPEC_RANDART)
     {
         for (int i = 0; i < 100; ++i)
-            if (_try_make_armour_artefact(item, force_type, 0, true)
+            if (_try_make_armour_artefact(item, force_type, 0, true, agent)
                 && is_artefact(item))
             {
                 return;
@@ -1168,7 +1140,7 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
     }
 
     if (allow_uniques
-        && _try_make_armour_artefact(item, force_type, item_level))
+        && _try_make_armour_artefact(item, force_type, item_level, false, agent))
     {
         return;
     }
@@ -1182,11 +1154,11 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
     }
 
     const bool force_good = item_level >= ISPEC_GIFT;
-    const bool forced_ego = (item.special > 0);
-    const bool no_ego     = (item.special == SPARM_FORBID_EGO);
+    const bool forced_ego = (item.brand > 0);
+    const bool no_ego     = (item.brand == SPARM_FORBID_EGO);
 
     if (no_ego)
-        item.special = SPARM_NORMAL;
+        item.brand = SPARM_NORMAL;
 
     if (item_level < 0)
     {
@@ -1252,7 +1224,7 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
         item.plus = 0;
 
     // squash boring items.
-    if (!force_good && item.special == SPARM_NORMAL && item.plus > 0
+    if (!force_good && item.brand == SPARM_NORMAL && item.plus > 0
         && item.plus < _armour_plus_threshold(get_armour_slot(item)))
     {
         item.plus = 0;
@@ -1260,7 +1232,7 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
 
     if (armour_is_hide(item))
     {
-        do_uncurse_item(item, false);
+        do_uncurse_item(item);
         item.plus = 0;
         set_ident_flags(item, ISFLAG_IDENT_MASK);
     }
@@ -1281,35 +1253,53 @@ static monster_type _choose_random_monster_corpse()
     return MONS_RAT;          // if you can't find anything else...
 }
 
+/**
+ * Choose a random wand subtype for ordinary wand generation.
+ *
+ * Some wands [mostly more powerful ones] are less common than others.
+ * Attack wands are more common, mostly to preserve historical wand freqs.
+ *
+ * @return      A random wand_type.
+ */
 static int _random_wand_subtype()
 {
-    int rc = random2(NUM_WANDS);
-
-    // Adjusted distribution here -- bwr
-    // Wands used to be uniform (5.26% each)
-    //
-    // Now:
-    // hasting, heal wounds                                (1.11% each)
-    // invisibility, enslavement, fireball, teleportation  (3.74% each)
-    // others                                              (6.37% each)
-    if (rc == WAND_INVISIBILITY || rc == WAND_HASTING || rc == WAND_HEAL_WOUNDS
-        || (rc == WAND_INVISIBILITY || rc == WAND_ENSLAVEMENT
-            || rc == WAND_FIREBALL || rc == WAND_TELEPORTATION) && coinflip())
-    {
-        rc = random2(NUM_WANDS);
-    }
-    return rc;
+    // total weight 84 [historical]
+    return random_choose_weighted(10, WAND_FLAME,
+                                  10, WAND_LIGHTNING,
+                                  10, WAND_ICEBLAST,
+                                  6, WAND_SLOWING,
+                                  6, WAND_PARALYSIS,
+                                  6, WAND_CONFUSION,
+                                  6, WAND_POLYMORPH,
+                                  6, WAND_RANDOM_EFFECTS,
+                                  6, WAND_ACID,
+                                  5, WAND_DISINTEGRATION,
+                                  5, WAND_DIGGING,
+                                  3, WAND_ENSLAVEMENT,
+                                  3, WAND_TELEPORTATION,
+                                  1, WAND_HASTING,
+                                  1, WAND_HEAL_WOUNDS,
+                                  0);
 }
 
+/**
+ * Should wands of this type NOT spawn extremely early on? (At very low
+ * item_level, or in the hands of very low HD monsters?)
+ *
+ * @param type      The wand_type in question.
+ * @return          Whether it'd be excessively mean for this wand to be used
+ *                  against very early players.
+ */
 bool is_high_tier_wand(int type)
 {
     switch (type)
     {
+    case WAND_ENSLAVEMENT:
+    case WAND_CONFUSION:
     case WAND_PARALYSIS:
-    case WAND_FIRE:
-    case WAND_COLD:
     case WAND_LIGHTNING:
-    case WAND_DRAINING:
+    case WAND_ACID:
+    case WAND_ICEBLAST:
     case WAND_DISINTEGRATION:
         return true;
     default:
@@ -1323,22 +1313,20 @@ static void _generate_wand_item(item_def& item, int force_type, int item_level)
     if (force_type != OBJ_RANDOM)
         item.sub_type = force_type;
     else
-    {
-        do
-        {
-            item.sub_type = _random_wand_subtype();
-        }
-        while (item_level < 2 && is_high_tier_wand(item.sub_type));
-    }
+        item.sub_type = _random_wand_subtype();
 
     // Generate charges randomly...
-    item.plus = random2avg(wand_max_charges(item.sub_type), 3);
+    item.plus = random2avg(wand_max_charges(item), 3);
 
     // ...but 0 charges is silly
     if (item.charges == 0)
         item.charges++;
 
     item.used_count = 0;
+
+    // don't let monsters pickup early high-tier wands
+    if (item_level < 2 && is_high_tier_wand(item.sub_type))
+        item.flags |= ISFLAG_NO_PICKUP;
 }
 
 static void _generate_food_item(item_def& item, int force_quant, int force_type)
@@ -1364,7 +1352,7 @@ static void _generate_food_item(item_def& item, int force_quant, int force_type)
         item.plus = _choose_random_monster_corpse();
         item.orig_monnum = item.plus;
         // Set duration.
-        item.special = (10 + random2(11)) * 10;
+        item.freshness = (10 + random2(11)) * 10;
     }
 
     // Determine quantity.
@@ -1408,34 +1396,34 @@ static void _generate_potion_item(item_def& item, int force_type,
             // total weight is 1065
             stype = random_choose_weighted(192, POT_CURING,
                                             95, POT_HEAL_WOUNDS,
-                                            66, POT_POISON,
+                                            72, POT_DEGENERATION,
+                                            72, POT_LIGNIFY,
+                                            72, POT_FLIGHT,
                                             66, POT_MIGHT,
                                             66, POT_AGILITY,
                                             66, POT_BRILLIANCE,
                                             63, POT_HASTE,
-                                            60, POT_FLIGHT,
-                                            60, POT_LIGNIFY,
-                                            52, POT_DEGENERATION,
+                                            46, POT_MUTATION,
                                             35, POT_INVISIBILITY,
                                             35, POT_RESISTANCE,
                                             35, POT_MAGIC,
                                             35, POT_BERSERK_RAGE,
-                                            35, POT_MUTATION,
                                             34, POT_CANCELLATION,
                                             34, POT_AMBROSIA,
-                                            23, POT_CURE_MUTATION,
+                                            34, POT_CURE_MUTATION,
                                             11, POT_BENEFICIAL_MUTATION,
                                              2, POT_EXPERIENCE,
                                              0);
         }
-        while (stype == POT_POISON && item_level < 1
-               // Too dangerous on monsters early on
-               || stype == POT_BERSERK_RAGE && item_level < 2
-               || (agent == GOD_XOM && _is_boring_item(OBJ_POTIONS, stype)
-                   && --tries > 0));
+        while (agent == GOD_XOM
+               && _is_boring_item(OBJ_POTIONS, stype)
+               && --tries > 0);
 
         item.sub_type = stype;
     }
+    // don't let monsters pickup early dangerous potions
+    if (item_level < 2 && item.sub_type == POT_BERSERK_RAGE)
+        item.flags |= ISFLAG_NO_PICKUP;
 }
 
 static void _generate_scroll_item(item_def& item, int force_type,
@@ -1482,8 +1470,8 @@ static void _generate_scroll_item(item_def& item, int force_type,
         }
         while (item.sub_type == NUM_SCROLLS
                || agent == GOD_XOM
-               && _is_boring_item(OBJ_SCROLLS, item.sub_type)
-               && --tries > 0);
+                  && _is_boring_item(OBJ_SCROLLS, item.sub_type)
+                  && --tries > 0);
     }
 
     if (one_chance_in(24))
@@ -1563,10 +1551,7 @@ static void _generate_book_item(item_def& item, bool allow_uniques,
     }
 
     if (item.sub_type == BOOK_RANDART_THEME)
-    {
-        make_book_theme_randart(item, SPTYP_NONE, SPTYP_NONE,
-                                5 + coinflip(), 20);
-    }
+        build_themed_book(item, capped_spell_filter(20));
     else if (item.sub_type == BOOK_RANDART_LEVEL)
     {
         int max_level  = min(9, max(1, item_level / 3));
@@ -1575,7 +1560,8 @@ static void _generate_book_item(item_def& item, bool allow_uniques,
     }
 }
 
-static void _generate_staff_item(item_def& item, bool allow_uniques, int force_type, int item_level)
+static void _generate_staff_item(item_def& item, bool allow_uniques,
+                                 int force_type, int item_level, int agent)
 {
     // If we make the unique roll, no further generation necessary.
     // Copied unrand code from _try_make_weapon_artefact since randart enhancer staves
@@ -1585,7 +1571,7 @@ static void _generate_staff_item(item_def& item, bool allow_uniques, int force_t
     {
         // Temporarily fix the base_type to get enhancer staves
         item.base_type = OBJ_WEAPONS;
-        if (_try_make_item_unrand(item, WPN_STAFF))
+        if (_try_make_item_unrand(item, WPN_STAFF, agent))
             return;
         item.base_type = OBJ_STAVES;
     }
@@ -1647,7 +1633,7 @@ static void _generate_rune_item(item_def& item, int force_type)
 }
 
 static bool _try_make_jewellery_unrandart(item_def& item, int force_type,
-                                          int item_level)
+                                          int item_level, int agent)
 {
     int type = (force_type == NUM_RINGS)     ? get_random_ring_type() :
                (force_type == NUM_JEWELLERY) ? get_random_amulet_type()
@@ -1656,7 +1642,7 @@ static bool _try_make_jewellery_unrandart(item_def& item, int force_type,
         && one_chance_in(20)
         && x_chance_in_y(101 + item_level * 3, 2000))
     {
-        if (_try_make_item_unrand(item, type))
+        if (_try_make_item_unrand(item, type, agent))
             return true;
     }
 
@@ -1685,13 +1671,14 @@ static int _bad_ring_plus()
  * @return              Between 1 and 6 (inclusive); 2-6 for statrings.
  *                      (+1 stat rings are extremely boring.)
  */
-static int _good_ring_plus(int subtype)
+static int _good_jewellery_plus(int subtype)
 {
     switch (subtype)
     {
         case RING_STRENGTH:
         case RING_DEXTERITY:
         case RING_INTELLIGENCE:
+        case AMU_REFLECTION:
             return 2 + (one_chance_in(3) ? random2(2) : random2avg(5, 2));
         default:
             return 1 + (one_chance_in(3) ? random2(3) : random2avg(6, 2));
@@ -1716,7 +1703,10 @@ static int _determine_ring_plus(int subtype)
     case RING_INTELLIGENCE:
         if (one_chance_in(5)) // 20% of such rings are cursed {dlb}
             return _bad_ring_plus();
-        return _good_ring_plus(subtype);
+        return _good_jewellery_plus(subtype);
+
+    case AMU_REFLECTION:
+        return _good_jewellery_plus(subtype);
 
     default:
         return 0;
@@ -1728,7 +1718,7 @@ static void _generate_jewellery_item(item_def& item, bool allow_uniques,
                                      int agent)
 {
     if (allow_uniques && item_level != ISPEC_RANDART
-        && _try_make_jewellery_unrandart(item, force_type, item_level))
+        && _try_make_jewellery_unrandart(item, force_type, item_level, agent))
     {
         return;
     }
@@ -1797,7 +1787,6 @@ static void _generate_misc_item(item_def& item, int force_type, int force_ego)
                                       MISC_BOX_OF_BEASTS,
                                       MISC_SACK_OF_SPIDERS,
                                       MISC_CRYSTAL_BALL_OF_ENERGY,
-                                      MISC_LANTERN_OF_SHADOWS,
                                       MISC_PHANTOM_MIRROR);
     }
 
@@ -1842,7 +1831,7 @@ void squash_plusses(int item_slot)
     ASSERT(!is_deck(item));
     item.plus         = 0;
     item.used_count   = 0;
-    item.special      = 0;
+    item.brand        = 0;
     set_equip_desc(item, ISFLAG_NO_DESC);
 }
 
@@ -1851,7 +1840,7 @@ void squash_plusses(int item_slot)
  *
  * Various parameters determine whether the item can be an artifact, set the
  * item class (ex. weapon, wand), set the item subtype (ex.
- * hand axe, wand of fire), set the item ego (ex. of flaming, of running), set
+ * hand axe, wand of flame), set the item ego (ex. of flaming, of running), set
  * the rough power level of the item, and set the agent of the item (which
  * affects what artefacts can be generated, and also non-artefact items if the
  * agent is Xom). Item class, Item type, and Item ego can also be randomly
@@ -1892,7 +1881,7 @@ int items(bool allow_uniques,
     if (force_ego != 0)
         allow_uniques = false;
 
-    item.special = force_ego;
+    item.brand = force_ego;
 
     // cap item_level unless an acquirement-level item {dlb}:
     if (item_level > 50 && !force_good)
@@ -1959,7 +1948,7 @@ int items(bool allow_uniques,
             return p;
         }
         // the base item otherwise
-        item.special = SPWPN_NORMAL;
+        item.brand = SPWPN_NORMAL;
         force_ego = 0;
     }
 
@@ -1968,7 +1957,7 @@ int items(bool allow_uniques,
     {
     case OBJ_WEAPONS:
         _generate_weapon_item(item, allow_uniques, force_type,
-                              item_level);
+                              item_level, agent);
         break;
 
     case OBJ_MISSILES:
@@ -1976,7 +1965,8 @@ int items(bool allow_uniques,
         break;
 
     case OBJ_ARMOUR:
-        _generate_armour_item(item, allow_uniques, force_type, item_level);
+        _generate_armour_item(item, allow_uniques, force_type, item_level,
+                              agent);
         break;
 
     case OBJ_WANDS:
@@ -2007,7 +1997,7 @@ int items(bool allow_uniques,
     case OBJ_STAVES:
         // Don't generate unrand staves this way except through acquirement,
         // since they also generate as OBJ_WEAPONS.
-        _generate_staff_item(item, (agent != -1), force_type, item_level);
+        _generate_staff_item(item, (agent != -1), force_type, item_level, agent);
         break;
 
     case OBJ_RODS:
@@ -2038,12 +2028,12 @@ int items(bool allow_uniques,
         || item.base_type == OBJ_ARMOUR
           && !is_armour_brand_ok(item.sub_type, get_armour_ego_type(item), false)
         || item.base_type == OBJ_MISSILES
-          && !is_missile_brand_ok(item.sub_type, item.special, false))
+          && !is_missile_brand_ok(item.sub_type, item.brand, false))
     {
         mprf(MSGCH_ERROR, "Invalid brand on item %s, annulling.",
             item.name(DESC_PLAIN, false, true, false, false, ISFLAG_KNOW_PLUSES
                       | ISFLAG_KNOW_CURSE).c_str());
-        item.special = 0;
+        item.brand = 0;
     }
 
     // Colour the item.
@@ -2071,13 +2061,13 @@ void reroll_brand(item_def &item, int item_level)
     switch (item.base_type)
     {
     case OBJ_WEAPONS:
-        item.special = _determine_weapon_brand(item, item_level);
+        item.brand = _determine_weapon_brand(item, item_level);
         break;
     case OBJ_MISSILES:
-        item.special = _determine_missile_brand(item, item_level);
+        item.brand = _determine_missile_brand(item, item_level);
         break;
     case OBJ_ARMOUR:
-        item.special = _generate_armour_ego(item, item_level);
+        item.brand = _generate_armour_ego(item, item_level);
         break;
     default:
         die("can't reroll brands of this type");
@@ -2193,13 +2183,8 @@ jewellery_type get_random_ring_type()
 {
     const jewellery_type j = _get_raw_random_ring_type();
     // Adjusted distribution here. - bwr
-    if ((j == RING_INVISIBILITY
-           || j == AMU_REGENERATION
-           || j == RING_SLAYING)
-        && !one_chance_in(3))
-    {
+    if (j == RING_SLAYING && !one_chance_in(3))
         return _get_raw_random_ring_type();
-    }
 
     return j;
 }
@@ -2270,17 +2255,17 @@ void makeitem_tests()
         level = _test_item_level();
         item.base_type = OBJ_WEAPONS;
         if (coinflip())
-            item.special = SPWPN_NORMAL;
+            item.brand = SPWPN_NORMAL;
         else
-            item.special = random2(NUM_REAL_SPECIAL_WEAPONS);
+            item.brand = random2(NUM_REAL_SPECIAL_WEAPONS);
 #if TAG_MAJOR_VERSION == 34
-        if (item.special == SPWPN_ORC_SLAYING
-            || item.special == SPWPN_REACHING
-            || item.special == SPWPN_RETURNING
-            || item.special == SPWPN_CONFUSE
-            || item.special == SPWPN_DRAGON_SLAYING)
+        if (item.brand == SPWPN_ORC_SLAYING
+            || item.brand == SPWPN_REACHING
+            || item.brand == SPWPN_RETURNING
+            || item.brand == SPWPN_CONFUSE
+            || item.brand == SPWPN_DRAGON_SLAYING)
         {
-            item.special = SPWPN_FORBID_BRAND;
+            item.brand = SPWPN_FORBID_BRAND;
         }
 #endif
         _generate_weapon_item(item,
@@ -2296,9 +2281,9 @@ void makeitem_tests()
         level = _test_item_level();
         item.base_type = OBJ_ARMOUR;
         if (coinflip())
-            item.special = SPARM_NORMAL;
+            item.brand = SPARM_NORMAL;
         else
-            item.special = random2(NUM_REAL_SPECIAL_ARMOURS);
+            item.brand = random2(NUM_REAL_SPECIAL_ARMOURS);
         int type = coinflip() ? OBJ_RANDOM : random2(NUM_ARMOURS);
 #if TAG_MAJOR_VERSION == 34
         if (type == ARM_CAP)
