@@ -20,7 +20,8 @@ enum unarmed_attack_type
     UNAT_PSEUDOPODS,
     UNAT_TENTACLES,
     UNAT_FIRST_ATTACK = UNAT_CONSTRICT,
-    UNAT_LAST_ATTACK = UNAT_TENTACLES
+    UNAT_LAST_ATTACK = UNAT_TENTACLES,
+    NUM_UNARMED_ATTACKS,
 };
 
 class melee_attack : public attack
@@ -69,8 +70,6 @@ private:
     void check_autoberserk();
     bool check_unrand_effects() override;
 
-    bool attack_ignores_shield(bool verbose) override;
-
     void rot_defender(int amount);
     void splash_defender_with_acid(int strength);
 
@@ -141,8 +140,7 @@ private:
 
     // Added in, were previously static methods of fight.cc
     bool _extra_aux_attack(unarmed_attack_type atk);
-    int calc_your_to_hit_unarmed(int uattack = UNAT_NO_ATTACK,
-                                 bool vampiric = false);
+    int calc_your_to_hit_unarmed(int uattack = UNAT_NO_ATTACK);
     bool _player_vampire_draws_blood(const monster* mon, const int damage,
                                      bool needs_bite_msg = false);
     bool _vamp_wants_blood_from_monster(const monster* mon);
