@@ -9,9 +9,10 @@
 // a dancing weapon.
 #define TUKIMA_WEAPON "tukima-weapon"
 #define TUKIMA_POWER "tukima-power"
-// Technically only used for spectral weapon, not dancing weapons
-// Equal to weapon skill with a scale of 10
-#define TUKIMA_SKILL "tukima-skill"
+
+#define MGEN_NUM_HEADS "num_heads"
+#define MGEN_BLOB_SIZE "blob_size"
+#define MGEN_TENTACLE_CONNECT "tentacle_connect"
 
 // A structure with all the data needed to whip up a new monster.
 struct mgen_data
@@ -49,8 +50,8 @@ struct mgen_data
     // just wandering around.
     unsigned short  foe;
 
-    // Generation flags from mgen_flag_type.
-    uint32_t        flags;
+    // Generation flags.
+    mgen_flags      flags;
 
     // What god the monster worships, if any. Used for monsters that
     // are god gifts, to indicate which god sent them, and by priest
@@ -62,13 +63,6 @@ struct mgen_data
     // set to MONS_NO_MONSTER when not used.
     monster_type    base_type;
 
-    // The number of hydra heads, the number of manticore attack volleys,
-    // or the number of merged slime creatures.
-    //
-    // Note: in older versions this field was used for both this and for
-    // base_type.
-    int             number;
-
     // The colour of the monster, or COLOUR_UNDEF for col:any
     int             colour;
 
@@ -117,15 +111,14 @@ struct mgen_data
 
     mgen_data(monster_type mt = RANDOM_MONSTER,
               beh_type beh = BEH_HOSTILE,
-              const actor* sner = 0,
+              const actor* sner = nullptr,
               int abj = 0,
               int st = 0,
               const coord_def &p = coord_def(-1, -1),
               unsigned short mfoe = MHITNOT,
-              uint32_t genflags = 0,
+              mgen_flags genflags = MG_NONE,
               god_type which_god = GOD_NO_GOD,
               monster_type base = MONS_NO_MONSTER,
-              int monnumber = 0,
               int moncolour = COLOUR_INHERIT,
               proximity_type prox = PROX_ANYWHERE,
               level_id _place = level_id::current(),
@@ -137,7 +130,7 @@ struct mgen_data
 
         : cls(mt), behaviour(beh), summoner(sner), abjuration_duration(abj),
           summon_type(st), pos(p), foe(mfoe), flags(genflags), god(which_god),
-          base_type(base), number(monnumber), colour(moncolour),
+          base_type(base), colour(moncolour),
           proximity(prox), place(_place), hd(mhd), hp(mhp),
           extra_flags(extflags), mname(monname), non_actor_summoner(nas),
           initial_shifter(is)
@@ -158,8 +151,8 @@ struct mgen_data
         return (flags & (MG_PERMIT_BANDS|MG_FORBID_BANDS)) == MG_PERMIT_BANDS;
     }
 
-    bool force_place() const        { return flags & MG_FORCE_PLACE; }
-    bool needs_patrol_point() const { return flags & MG_PATROLLING; }
+    bool force_place() const        { return bool(flags & MG_FORCE_PLACE); }
+    bool needs_patrol_point() const { return bool(flags & MG_PATROLLING); }
 
     // Is there a valid position set on this struct that we want to use
     // when placing the monster?
@@ -169,7 +162,7 @@ struct mgen_data
 
     static mgen_data sleeper_at(monster_type what,
                                 const coord_def &where,
-                                unsigned genflags = 0)
+                                mgen_flags genflags = MG_NONE)
     {
         return mgen_data(what, BEH_SLEEP, 0, 0, MF_NO_FLAGS, where,
                          MHITNOT, genflags);
@@ -181,14 +174,14 @@ struct mgen_data
                                 int abj = 0,
                                 int st = 0,
                                 const coord_def &p = coord_def(-1, -1),
-                                uint32_t genflags = 0,
+                                mgen_flags genflags = MG_NONE,
                                 god_type ngod = GOD_NO_GOD,
                                 monster_type base = MONS_NO_MONSTER)
 
     {
         return mgen_data(mt, BEH_HOSTILE, 0, abj, st, p,
                          alert ? MHITYOU : MHITNOT,
-                         genflags, ngod, base, 0, COLOUR_INHERIT,
+                         genflags, ngod, base, COLOUR_INHERIT,
                          PROX_ANYWHERE, level_id::current(), 0, 0, MF_NO_FLAGS,
                          "", nsummoner, RANDOM_MONSTER);
     }
