@@ -19,7 +19,6 @@ enum band_type
     BAND_HELL_HOUNDS,
     BAND_JACKALS,
     BAND_HELL_KNIGHTS,
-    BAND_ORC_HIGH_PRIEST,
     BAND_GNOLLS,
     BAND_WIGHTS,
     BAND_CENTAURS,
@@ -33,7 +32,6 @@ enum band_type
     BAND_CACODEMON,
     BAND_EXECUTIONER,
     BAND_HELLWING,
-    BAND_DEEP_ELF_FIGHTER,
     BAND_DEEP_ELF_KNIGHT,
     BAND_DEEP_ELF_HIGH_PRIEST,
     BAND_KOBOLD_DEMONOLOGIST,
@@ -68,7 +66,6 @@ enum band_type
     BAND_ALLIGATOR,
     BAND_ELEPHANT,
     BAND_REDBACK,
-    BAND_SPIDER,
     BAND_JUMPING_SPIDER,
     BAND_TARANTELLA,
     BAND_POLYPHEMUS,
@@ -88,7 +85,6 @@ enum band_type
     BAND_THRASHING_HORRORS,
     BAND_RAIJU,
     BAND_FAUN_PARTY,
-    BAND_NAGA_ELITES,
     BAND_NAGA_RITUALIST,
     BAND_NAGA_SHARPSHOOTER,
     BAND_SALAMANDERS,
@@ -112,8 +108,11 @@ enum band_type
     BAND_ANUBIS_GUARD,
     BAND_HOLIES,
     BAND_ROBIN,
+    BAND_SPARK_WASPS,
     BAND_RANDOM_SINGLE,
     BAND_JOSEPHINE,
+    BAND_IRON_GIANT,
+    BAND_HOWLER_MONKEY,
     NUM_BANDS                   // always last
 };
 
@@ -132,8 +131,9 @@ enum proximity_type   // proximity to player to create monster
     PROX_NEAR_STAIRS,
 };
 
-enum mgen_flag_type
+enum mgen_flag
 {
+    MG_NONE         = 0x000,
     MG_PERMIT_BANDS = 0x001, ///< allow placing band members too
     MG_FORCE_PLACE  = 0x002,
     MG_FORCE_BEH    = 0x004,
@@ -145,5 +145,6 @@ enum mgen_flag_type
     MG_FORBID_BANDS = 0x100, ///< override MG_PERMIT_BANDS
     MG_NO_OOD       = 0x200, ///< don't choose out-of-depth random monsters
 };
+DEF_BITFIELD(mgen_flags, mgen_flag);
 
 #endif
