@@ -22,6 +22,7 @@
 #include "fight.h"
 #include "fprop.h"
 #include "hints.h"
+#include "items.h"
 #include "libutil.h"
 #include "losglobal.h"
 #include "message.h"
@@ -126,7 +127,7 @@ bool monster::add_ench(const mon_enchant &ench)
         return false;
 
     if (ench.ench == ENCH_FEAR
-        && (holiness() == MH_NONLIVING || berserk_or_insane()))
+        && (holiness() & MH_NONLIVING || berserk_or_insane()))
     {
         return false;
     }
@@ -193,15 +194,9 @@ void monster::add_enchantment_effect(const mon_enchant &ench, bool quiet)
         // deliberate fall-through
 
     case ENCH_INSANE:
-
         if (has_ench(ENCH_SUBMERGED))
             del_ench(ENCH_SUBMERGED);
 
-        if (mons_is_lurking(this))
-        {
-            behaviour = BEH_WANDER;
-            behaviour_event(this, ME_EVAL);
-        }
         calc_speed();
         break;
 
@@ -214,46 +209,7 @@ void monster::add_enchantment_effect(const mon_enchant &ench, bool quiet)
         break;
 
     case ENCH_SUBMERGED:
-        mons_clear_trapping_net(this);
-
-        // Don't worry about invisibility. You should be able to see if
-        // something has submerged.
-        if (!quiet && mons_near(this))
-        {
-            if (type == MONS_TRAPDOOR_SPIDER)
-            {
-                mprf("%s hides itself under the floor.",
-                     name(DESC_A, true).c_str());
-            }
-            else if (seen_context == SC_SURFACES)
-            {
-                // The monster surfaced and submerged in the same turn
-                // without doing anything else.
-                interrupt_activity(AI_SEE_MONSTER,
-                                   activity_interrupt_data(this,
-                                                           SC_SURFACES_BRIEFLY));
-                // Why does this handle only land-capables?  I'd imagine this
-                // to happen mostly (only?) for fish. -- 1KB
-            }
-            else if (crawl_state.game_is_arena())
-                mprf("%s submerges.", name(DESC_A, true).c_str());
-        }
-
-        // Pacified monsters leave the level when they submerge.
-        if (pacified())
-            make_mons_leave_level(this);
-        break;
-
-    case ENCH_CONFUSION:
-    case ENCH_MAD:
-        if (type == MONS_TRAPDOOR_SPIDER && has_ench(ENCH_SUBMERGED))
-            del_ench(ENCH_SUBMERGED);
-
-        if (mons_is_lurking(this))
-        {
-            behaviour = BEH_WANDER;
-            behaviour_event(this, ME_EVAL);
-        }
+        dprf("%s submerges.", name(DESC_A, true).c_str());
         break;
 
     case ENCH_CHARM:
@@ -295,7 +251,7 @@ void monster::add_enchantment_effect(const mon_enchant &ench, bool quiet)
         stop_constricting(MID_PLAYER, true);
         you.stop_constricting(mid, true);
 
-        if (invisible() && mons_near(this) && !you.can_see_invisible()
+        if (invisible() && you.see_cell(pos()) && !you.can_see_invisible()
             && !backlit() && !has_ench(ENCH_SUBMERGED))
         {
             if (!quiet)
@@ -350,26 +306,6 @@ static bool _prepare_del_ench(monster* mon, const mon_enchant &me)
     if (me.ench != ENCH_SUBMERGED)
         return true;
 
-    // Unbreathing stuff that can't swim stays on the bottom.
-    if (grd(mon->pos()) == DNGN_DEEP_WATER
-        && !mon->can_drown()
-        && !monster_habitable_grid(mon, DNGN_DEEP_WATER))
-    {
-        return false;
-    }
-
-    // Lurking monsters only unsubmerge when their foe is in sight if the foe
-    // is right next to them.
-    if (mons_is_lurking(mon))
-    {
-        const actor* foe = mon->get_foe();
-        if (foe != nullptr && mon->can_see(*foe)
-            && !adjacent(mon->pos(), foe->pos()))
-        {
-            return false;
-        }
-    }
-
     int midx = mon->mindex();
 
     if (!monster_at(mon->pos()))
@@ -430,7 +366,7 @@ static bool _prepare_del_ench(monster* mon, const mon_enchant &me)
     {
         if (!actor_at(*ai)
             && monster_habitable_grid(mon, grd(*ai))
-            && !find_trap(*ai))
+            && !trap_at(*ai))
         {
             if (one_chance_in(++okay_squares))
                 target_square = *ai;
@@ -529,10 +465,10 @@ void monster::remove_enchantment_effect(const mon_enchant &me, bool quiet)
         calc_speed();
         break;
 
-    case ENCH_STONESKIN:
+    case ENCH_MAGIC_ARMOUR:
         if (!quiet && you.can_see(*this))
         {
-            mprf("%s skin looks tender.",
+            mprf("%s magical armour fades away.",
                  apostrophise(name(DESC_THE)).c_str());
         }
         break;
@@ -570,7 +506,7 @@ void monster::remove_enchantment_effect(const mon_enchant &me, bool quiet)
     case ENCH_FEAR:
     {
         string msg;
-        if (holiness() == MH_NONLIVING || berserk_or_insane())
+        if (holiness() & MH_NONLIVING || berserk_or_insane())
         {
             // This should only happen because of fleeing sanctuary
             msg = " stops retreating.";
@@ -601,7 +537,7 @@ void monster::remove_enchantment_effect(const mon_enchant &me, bool quiet)
         // Note: Invisible monsters are not forced to stay invisible, so
         // that they can properly have their invisibility removed just
         // before being polymorphed into a non-invisible monster.
-        if (mons_near(this) && !you.can_see_invisible() && !backlit()
+        if (you.see_cell(pos()) && !you.can_see_invisible() && !backlit()
             && !has_ench(ENCH_SUBMERGED)
             && !friendly() && !you.duration[DUR_TELEPATHY])
         {
@@ -617,7 +553,7 @@ void monster::remove_enchantment_effect(const mon_enchant &me, bool quiet)
     case ENCH_NEUTRAL_BRIBED:
     case ENCH_FRIENDLY_BRIBED:
     case ENCH_HEXED:
-        if (invisible() && mons_near(this) && !you.can_see_invisible()
+        if (invisible() && you.see_cell(pos()) && !you.can_see_invisible()
             && !backlit() && !has_ench(ENCH_SUBMERGED))
         {
             if (!quiet)
@@ -692,7 +628,7 @@ void monster::remove_enchantment_effect(const mon_enchant &me, bool quiet)
         {
             if (visible_to(&you))
                 simple_monster_message(this, " stops glowing.");
-            else if (has_ench(ENCH_INVIS) && mons_near(this))
+            else if (has_ench(ENCH_INVIS) && you.see_cell(pos()))
             {
                 mprf("%s stops glowing and disappears.",
                      name(DESC_THE, true).c_str());
@@ -750,7 +686,7 @@ void monster::remove_enchantment_effect(const mon_enchant &me, bool quiet)
         monster_die(this, KILL_TIMEOUT, NON_MONSTER);
         break;
     case ENCH_SUBMERGED:
-        if (mons_is_wandering(this) || mons_is_lurking(this))
+        if (mons_is_wandering(this))
         {
             behaviour = BEH_SEEK;
             behaviour_event(this, ME_EVAL);
@@ -770,42 +706,14 @@ void monster::remove_enchantment_effect(const mon_enchant &me, bool quiet)
 
         if (you.can_see(*this))
         {
-            if (!mons_is_safe(this) && delay_is_run(current_delay_action()))
+            if (!quiet && feat_is_watery(grd(pos())))
             {
-                // Already set somewhere else.
-                if (seen_context)
-                    return;
-
-                if (!monster_habitable_grid(this, DNGN_FLOOR))
-                    seen_context = SC_FISH_SURFACES;
-                else
-                    seen_context = SC_SURFACES;
-            }
-            else if (!quiet)
-            {
-                msg_channel_type channel = MSGCH_PLAIN;
-                if (!seen_context)
-                {
-                    channel = MSGCH_WARN;
-                    seen_context = SC_JUST_SEEN;
-                }
-
-                if (type == MONS_TRAPDOOR_SPIDER)
-                {
-                    mprf(channel,
-                         "%s leaps out from its hiding place under the floor!",
-                         name(DESC_A, true).c_str());
-                }
-                else if (type == MONS_LOST_SOUL)
-                {
-                    mprf(channel, "%s flickers into view.",
-                                  name(DESC_A).c_str());
-                }
-                else if (crawl_state.game_is_arena())
-                    mprf("%s surfaces.", name(DESC_A, true).c_str());
+                mprf(MSGCH_WARN, "%s bursts forth from the water.",
+                     name(DESC_A, true).c_str());
+                seen_monster(this);
             }
         }
-        else if (mons_near(this) && feat_is_watery(grd(pos())))
+        else if (you.see_cell(pos()) && feat_is_watery(grd(pos())))
         {
             mpr("Something invisible bursts forth from the water.");
             interrupt_activity(AI_FORCE_INTERRUPT);
@@ -1023,18 +931,21 @@ void monster::remove_enchantment_effect(const mon_enchant &me, bool quiet)
             simple_monster_message(this, " is no longer deflecting missiles.");
         break;
 
-    case ENCH_CONDENSATION_SHIELD:
-        if (!quiet && you.can_see(*this))
-        {
-            mprf("%s icy shield evaporates.",
-                 apostrophise(name(DESC_THE)).c_str());
-        }
-
     case ENCH_RESISTANCE:
         if (!quiet)
             simple_monster_message(this, " is no longer unusually resistant.");
         break;
 
+    case ENCH_BRILLIANCE_AURA:
+        if (!quiet)
+            simple_monster_message(this, " is no longer giving off an aura.");
+        break;
+
+    case ENCH_EMPOWERED_SPELLS:
+        if (!quiet)
+            simple_monster_message(this, " seems less brilliant.");
+        break;
+
     default:
         break;
     }
@@ -1104,6 +1015,13 @@ bool monster::decay_enchantment(enchant_type en, bool decay_degree)
     if (me.duration >= INFINITE_DURATION)
         return false;
 
+    // Gozag-incited haste/berserk is permanent.
+    if (has_ench(ENCH_GOZAG_INCITE)
+        && (en == ENCH_HASTE || en == ENCH_BERSERK))
+    {
+        return false;
+    }
+
     // Faster monsters can wiggle out of the net more quickly.
     const int spd = (me.ench == ENCH_HELD) ? speed :
                                              10;
@@ -1357,7 +1275,7 @@ static void _merfolk_avatar_song(monster* mons)
     int ally_hd = 0;
     for (monster_near_iterator mi(&you); mi; ++mi)
     {
-        if (*mi != mons && mons_aligned(mons, *mi) && !mons_is_firewood(*mi)
+        if (*mi != mons && mons_aligned(mons, *mi) && mons_is_threatening(*mi)
             && mi->type != MONS_DROWNED_SOUL)
         {
             ally_hd += mi->get_experience_level();
@@ -1485,7 +1403,7 @@ void monster::apply_enchantment(const mon_enchant &me)
     case ENCH_TIDE:
     case ENCH_REGENERATION:
     case ENCH_RAISED_MR:
-    case ENCH_STONESKIN:
+    case ENCH_MAGIC_ARMOUR:
     case ENCH_FEAR_INSPIRING:
     case ENCH_LIFE_TIMER:
     case ENCH_FLIGHT:
@@ -1513,12 +1431,10 @@ void monster::apply_enchantment(const mon_enchant &me)
     case ENCH_GOLD_LUST:
     case ENCH_RESISTANCE:
     case ENCH_HEXED:
-        decay_enchantment(en);
-        break;
-
+    case ENCH_BRILLIANCE_AURA:
+    case ENCH_EMPOWERED_SPELLS:
     case ENCH_ANTIMAGIC:
-        if (!has_ench(ENCH_SAP_MAGIC))
-            decay_enchantment(en);
+        decay_enchantment(en);
         break;
 
     case ENCH_MIRROR_DAMAGE:
@@ -1532,8 +1448,6 @@ void monster::apply_enchantment(const mon_enchant &me)
         invalidate_agrid();
         break;
 
-    case ENCH_BATTLE_FRENZY:
-    case ENCH_ROUSED:
     case ENCH_DRAINED:
         decay_enchantment(en, false);
         break;
@@ -1577,20 +1491,7 @@ void monster::apply_enchantment(const mon_enchant &me)
         const dungeon_feature_type grid = grd(pos());
 
         if (!monster_can_submerge(this, grid))
-        {
-            // unbreathing stuff can stay on the bottom
-            if (grid != DNGN_DEEP_WATER
-                || monster_habitable_grid(this, grid)
-                || can_drown())
-            {
-                del_ench(ENCH_SUBMERGED); // forced to surface
-            }
-        }
-        else if (mons_landlubbers_in_reach(this))
-        {
-            del_ench(ENCH_SUBMERGED);
-            make_mons_stop_fleeing(this);
-        }
+            del_ench(ENCH_SUBMERGED); // forced to surface
         break;
     }
     case ENCH_POISON:
@@ -1609,7 +1510,7 @@ void monster::apply_enchantment(const mon_enchant &me)
             dprf("%s takes poison damage: %d (degree %d)",
                  name(DESC_THE).c_str(), dam, me.degree);
 
-            hurt(me.agent(), dam, BEAM_POISON);
+            hurt(me.agent(), dam, BEAM_POISON, KILLED_BY_POISON);
         }
 
         decay_enchantment(en, true);
@@ -1621,7 +1522,7 @@ void monster::apply_enchantment(const mon_enchant &me)
     {
         if (feat_is_watery(grd(pos())) && ground_level())
         {
-            if (mons_near(this) && visible_to(&you))
+            if (you.can_see(*this))
             {
                 mprf("The flames covering %s go out.",
                      name(DESC_THE, false).c_str());
@@ -1911,8 +1812,6 @@ void monster::apply_enchantment(const mon_enchant &me)
         break;
 
     case ENCH_WORD_OF_RECALL:
-    case ENCH_CHANT_FIRE_STORM:
-    case ENCH_CHANT_WORD_OF_ENTROPY:
         // If we've gotten silenced or somehow incapacitated since we started,
         // cancel the recitation
         if (silenced(pos()) || paralysed() || petrified()
@@ -1935,36 +1834,7 @@ void monster::apply_enchantment(const mon_enchant &me)
         {
             int breath_timeout_turns = random_range(4, 12);
 
-            if (en == ENCH_WORD_OF_RECALL)
-                mons_word_of_recall(this, random_range(3, 7));
-            else if (en == ENCH_CHANT_FIRE_STORM
-                  || en == ENCH_CHANT_WORD_OF_ENTROPY)
-            {
-                actor *mons_foe = get_foe();
-                coord_def foe_pos;
-                if (mons_foe)
-                    foe_pos = mons_foe->pos();
-
-                if  (mons_foe
-                     && !(is_sanctuary(pos())
-                        || is_sanctuary(mons_foe->pos())))
-                {
-                    if (can_see(*mons_foe))
-                    {
-                        if (en == ENCH_CHANT_FIRE_STORM)
-                            finish_chanting_fire_storm(this, foe_pos);
-                        else // word of entropy
-                            finish_chanting_word_of_entropy(this, mons_foe);
-                    }
-                    // remove the timeout because the effect was entirely dodged
-                    else
-                        breath_timeout_turns = 0;
-                }
-
-            }
-            else
-                die("Unknown chant type!"); // squash a warning
-
+            mons_word_of_recall(this, random_range(3, 7));
             add_ench(mon_enchant(ENCH_BREATH_WEAPON, 1, this,
                                  breath_timeout_turns * BASELINE_DELAY));
         }
@@ -2092,14 +1962,8 @@ void monster::mark_summoned(int longevity, bool mark_items, int summon_type, boo
         add_ench(mon_enchant(ENCH_SUMMON, summon_type, 0, INT_MAX));
 
     if (mark_items)
-    {
-        for (int i = 0; i < NUM_MONSTER_SLOTS; ++i)
-        {
-            const int item = inv[i];
-            if (item != NON_ITEM)
-                mitm[item].flags |= ISFLAG_SUMMONED;
-        }
-    }
+        for (mon_inv_iterator ii(*this); ii; ++ii)
+            ii->flags |= ISFLAG_SUMMONED;
 }
 
 bool monster::is_summoned(int* duration, int* summon_type) const
@@ -2203,9 +2067,9 @@ static const char *enchant_names[] =
 #if TAG_MAJOR_VERSION == 34
     "sleepy",
 #endif
-    "held", "battle_frenzy",
+    "held",
 #if TAG_MAJOR_VERSION == 34
-    "temp_pacif",
+     "battle_frenzy", "temp_pacif",
 #endif
     "petrifying",
     "petrified", "lowered_mr", "soul_ripe", "slowly_dying", "eat_items",
@@ -2224,10 +2088,17 @@ static const char *enchant_names[] =
 #endif
     "regen",
     "magic_res", "mirror_dam", "stoneskin", "fear inspiring", "temporarily pacified",
-    "withdrawn", "attached", "guardian_timer", "flight",
-    "liquefying", "tornado", "fake_abjuration",
+    "withdrawn",
+#if TAG_MAJOR_VERSION == 34
+    "attached",
+#endif
+    "guardian_timer", "flight", "liquefying", "tornado", "fake_abjuration",
     "dazed", "mute", "blind", "dumb", "mad", "silver_corona", "recite timer",
-    "inner_flame", "roused", "breath timer", "deaths_door", "rolling",
+    "inner_flame",
+#if TAG_MAJOR_VERSION == 34
+    "roused",
+#endif
+    "breath timer", "deaths_door", "rolling",
     "ozocubus_armour", "wretched", "screamed", "rune_of_recall", "injury bond",
     "drowning", "flayed", "haunting",
 #if TAG_MAJOR_VERSION == 34
@@ -2257,11 +2128,14 @@ static const char *enchant_names[] =
     "corrosion", "gold_lust", "drained", "repel missiles",
     "deflect missiles",
 #if TAG_MAJOR_VERSION == 34
-    "negative_vuln",
+    "negative_vuln", "condensation_shield",
 #endif
-    "condensation_shield", "resistant",
-    "hexed", "corpse_armour", "chanting_fire_storm",
-    "chanting_word_of_entropy", "buggy",
+    "resistant", "hexed", "corpse_armour",
+#if TAG_MAJOR_VERSION == 34
+    "chanting_fire_storm", "chanting_word_of_entropy",
+#endif
+    "aura_of_brilliance", "empowered_spells", "gozag_incite",
+    "buggy",
 };
 
 static const char *_mons_enchantment_name(enchant_type ench)
@@ -2402,7 +2276,7 @@ int mon_enchant::calc_duration(const monster* mons,
     case ENCH_MIGHT:
     case ENCH_INVIS:
     case ENCH_FEAR_INSPIRING:
-    case ENCH_STONESKIN:
+    case ENCH_MAGIC_ARMOUR:
     case ENCH_AGILE:
     case ENCH_BLACK_MARK:
     case ENCH_RESISTANCE:
@@ -2525,6 +2399,14 @@ int mon_enchant::calc_duration(const monster* mons,
     case ENCH_FROZEN:
         cturn = 3 * BASELINE_DELAY;
         break;
+    case ENCH_BRILLIANCE_AURA:
+        cturn = 20 * BASELINE_DELAY;
+        break;
+    case ENCH_EMPOWERED_SPELLS:
+        cturn = 2 * BASELINE_DELAY;
+        break;
+    case ENCH_GOZAG_INCITE:
+        cturn = 100; // is never decremented
     default:
         break;
     }
