@@ -107,8 +107,7 @@ enum monclass_flag_type : uint64_t
     /// can do damage when attacked in melee
     M_SPINY             = BIT(32),
 
-    /// phase shift (EV bonus not included)
-    M_PHASE_SHIFT       = BIT(33),
+                        //BIT(33),
 
     /// not a valid polymorph target (but can be polymorphed)
     M_NO_POLY_TO        = BIT(34),
@@ -132,7 +131,8 @@ enum monclass_flag_type : uint64_t
 
     M_HERD              = BIT(41),
 
-                       // BIT(42),
+    // has a double-sized tile
+    M_TALL_TILE         = BIT(42),
 
     /// can sense vibrations in web traps
     M_WEB_SENSE         = BIT(43),
@@ -166,6 +166,9 @@ enum monclass_flag_type : uint64_t
 
     /// monster is a proxy for a charm/conjuration spell (ball lightning, etc.)
     M_CONJURED          = BIT(54),
+
+    /// monster will never harm the player
+    M_NO_THREAT         = BIT(55),
 };
 DEF_BITFIELD(monclass_flags_t, monclass_flag_type);
 
@@ -179,8 +182,8 @@ enum monster_flag_type : uint64_t
     MF_JUST_SUMMONED      = BIT(1),
     /// is following player through stairs
     MF_TAKING_STAIRS      = BIT(2),
-    /// Player finds monster interesting
-    MF_INTERESTING        = BIT(3),
+
+    //                      BIT(3),
 
     /// Player has already seen monster
     MF_SEEN               = BIT(4),
@@ -202,8 +205,8 @@ enum monster_flag_type : uint64_t
 
     /// Created as a member of a band
     MF_BAND_MEMBER        = BIT(11),
-    /// Player already got half xp value earlier
-    MF_GOT_HALF_XP        = BIT(12),
+    /// Monter has been pacified
+    MF_PACIFIED           = BIT(12),
     /// Consider this monster to have MH_UNDEAD holiness, regardless
     /// of its actual type
     MF_FAKE_UNDEAD        = BIT(13),
@@ -217,7 +220,6 @@ enum monster_flag_type : uint64_t
     MF_NAME_ADJECTIVE     = BIT(16),
     /// mname entirely replaces normal monster name.
     MF_NAME_REPLACE       = MF_NAME_SUFFIX|MF_NAME_ADJECTIVE,
-    MF_NAME_MASK          = MF_NAME_REPLACE,
     /// Is a god gift.
     MF_GOD_GIFT           = BIT(17),
     /// Is running away from player sanctuary
@@ -234,7 +236,6 @@ enum monster_flag_type : uint64_t
     MF_TWO_WEAPONS        = BIT(21),
     /// Monster gets various archery boosts.
     MF_ARCHER             = BIT(22),
-    MF_MELEE_MASK         = MF_FIGHTER|MF_TWO_WEAPONS|MF_ARCHER,
 
                           //BIT(23),
                           //BIT(24),
@@ -272,4 +273,8 @@ enum monster_flag_type : uint64_t
     MF_TSO_SEEN           = BIT(38),
 };
 DEF_BITFIELD(monster_flags_t, monster_flag_type);
+
+constexpr monster_flags_t MF_NAME_MASK = MF_NAME_REPLACE;
+constexpr monster_flags_t MF_MELEE_MASK = MF_FIGHTER | MF_TWO_WEAPONS
+                                        | MF_ARCHER;
 #endif
