@@ -15,7 +15,7 @@
 #include "itemprop.h"
 #include "items.h"
 #include "mon-place.h"
-#include "spl-book.h"
+#include "randbook.h" // roxanne, roxanne...
 #include "state.h"
 #include "tilepick.h"
 #include "unwind.h"
@@ -63,9 +63,9 @@ static void _give_monster_item(monster* mon, int thing,
         bool enchanted = mthing.plus;
         // The item could either lose or gain brand after being generated,
         // adjust the glowing flag.
-        if (!mthing.special && !enchanted)
+        if (!mthing.brand && !enchanted)
             set_equip_desc(mthing, 0);
-        else if (mthing.special && !get_equip_desc(mthing))
+        else if (mthing.brand && !get_equip_desc(mthing))
             set_equip_desc(mthing, ISFLAG_GLOWING);
     }
 
@@ -116,7 +116,7 @@ static void _give_book(monster* mon, int level)
 
         // Maybe give Roxanne a random book containing Statue Form instead.
         if (coinflip())
-            make_book_Roxanne_special(&mitm[thing_created]);
+            make_book_roxanne_special(&mitm[thing_created]);
 
         _give_monster_item(mon, thing_created, true);
     }
@@ -136,8 +136,8 @@ static void _give_wand(monster* mon, int level)
     // Don't give top-tier wands before 5 HD, except to Ijyb and not in sprint.
     const bool no_high_tier =
             (mon->get_experience_level() < 5
-            || mons_class_flag(mon->type, M_NO_HT_WAND))
-                && (mon->type != MONS_IJYB || crawl_state.game_is_sprint());
+                || mons_class_flag(mon->type, M_NO_HT_WAND))
+            && (mon->type != MONS_IJYB || crawl_state.game_is_sprint());
 
     const int idx = items(false, OBJ_WANDS, OBJ_RANDOM, level);
 
@@ -219,18 +219,18 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
     string equip_tile = "";
 
     item_def item;
-    int type = mon->type;
+    monster_type type = mon->type;
 
     item.base_type = OBJ_UNASSIGNED;
 
-    if (mon->type == MONS_DANCING_WEAPON || merc)
+    if (type == MONS_DANCING_WEAPON || merc)
         level = ISPEC_GOOD_ITEM;
 
     // moved setting of quantity here to keep it in mind {dlb}
     item.quantity = 1;
 
     if (spectral_orcs)
-        type = mon->orc_type;
+        type = mon->base_monster;
 
     switch (type)
     {
@@ -467,10 +467,8 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
                                        WPN_TRIDENT);
         break;
 
-    case MONS_DEEP_ELF_FIGHTER:
     case MONS_DEEP_ELF_HIGH_PRIEST:
     case MONS_DEEP_ELF_KNIGHT:
-    case MONS_DEEP_ELF_PRIEST:
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = random_choose_weighted(
             22, WPN_LONG_SWORD, 22, WPN_SHORT_SWORD, 17, WPN_SCIMITAR,
@@ -498,18 +496,30 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
         break;
     }
 
+    case MONS_DEEP_ELF_ARCHER:
+        force_uncursed = true;
+        item.base_type = OBJ_WEAPONS;
+        if (!melee_only)
+        {
+            item.sub_type  = random_choose_weighted(2, WPN_SHORTBOW,
+                                                    1, WPN_LONGBOW,
+                                                    0);
+            break;
+        }
+        item.sub_type  = random_choose(WPN_SHORT_SWORD, WPN_DAGGER);
+        break;
+
     case MONS_DEEP_ELF_MASTER_ARCHER:
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = WPN_LONGBOW;
         break;
 
     case MONS_DEEP_ELF_ANNIHILATOR:
-    case MONS_DEEP_ELF_CONJURER:
     case MONS_DEEP_ELF_DEATH_MAGE:
     case MONS_DEEP_ELF_DEMONOLOGIST:
     case MONS_DEEP_ELF_MAGE:
     case MONS_DEEP_ELF_SORCERER:
-    case MONS_DEEP_ELF_SUMMONER:
+    case MONS_DEEP_ELF_ELEMENTALIST:
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = random_choose(WPN_LONG_SWORD,  WPN_LONG_SWORD,
                                        WPN_SHORT_SWORD, WPN_RAPIER,
@@ -666,12 +676,12 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
     case MONS_ORC_KNIGHT:
     case MONS_TENGU_WARRIOR:
         // Occasionally get crossbows, or a longbow for tengu and minotaurs.
-        if (!melee_only && mon->type != MONS_TENGU_REAVER
-            && mon->type != MONS_DRACONIAN_KNIGHT && one_chance_in(9))
+        if (!melee_only && type != MONS_TENGU_REAVER
+            && type != MONS_DRACONIAN_KNIGHT && one_chance_in(9))
         {
             item.base_type = OBJ_WEAPONS;
-            item.sub_type  = ((mon->type == MONS_TENGU_WARRIOR
-                               || mon->type == MONS_MINOTAUR)
+            item.sub_type  = ((type == MONS_TENGU_WARRIOR
+                               || type == MONS_MINOTAUR)
                               && coinflip())
                              ? WPN_LONGBOW
                              : WPN_ARBALEST;
@@ -739,7 +749,7 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
         item.sub_type  = one_chance_in(3) ? WPN_GIANT_SPIKED_CLUB
                                           : WPN_GIANT_CLUB;
 
-        if (one_chance_in(10) || mon->type == MONS_ETTIN)
+        if (one_chance_in(10) || type == MONS_ETTIN)
         {
             item.sub_type = one_chance_in(10) ? WPN_GREAT_MACE
                                               : WPN_DIRE_FLAIL;
@@ -832,7 +842,7 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
     case MONS_CENTAUR_WARRIOR:
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = WPN_SHORTBOW;
-        if (mon->type == MONS_CENTAUR_WARRIOR && one_chance_in(3))
+        if (type == MONS_CENTAUR_WARRIOR && one_chance_in(3))
             item.sub_type = WPN_LONGBOW;
         break;
 
@@ -842,9 +852,9 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
         item.base_type = OBJ_WEAPONS;
         if (!melee_only)
         {
-            item.sub_type = (mon->type == MONS_FAUN ? WPN_HUNTING_SLING :
-                                   one_chance_in(3) ? WPN_GREATSLING:
-                                                      WPN_LONGBOW);
+            item.sub_type = (type == MONS_FAUN ? WPN_HUNTING_SLING :
+                              one_chance_in(3) ? WPN_GREATSLING:
+                                                 WPN_LONGBOW);
         }
         else
         {
@@ -973,7 +983,7 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
         force_item = true;
         item.base_type = OBJ_WEAPONS;
 
-        if (mon->type == MONS_MARGERY && one_chance_in(5))
+        if (type == MONS_MARGERY && one_chance_in(5))
         {
             item.sub_type = random_choose(WPN_DEMON_WHIP, WPN_DEMON_BLADE,
                                           WPN_DEMON_TRIDENT);
@@ -1037,14 +1047,14 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = WPN_GREAT_SWORD;
         item.flags    |= ISFLAG_KNOW_TYPE;
-        item.special   = SPWPN_FLAMING;
+        item.brand     = SPWPN_FLAMING;
         break;
 
     case MONS_FROST_GIANT:
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = WPN_BATTLEAXE;
         item.flags    |= ISFLAG_KNOW_TYPE;
-        item.special   = SPWPN_FREEZING;
+        item.brand     = SPWPN_FREEZING;
         break;
 
     case MONS_ORC_WIZARD:
@@ -1086,7 +1096,7 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = WPN_DAGGER;
 
-        if (mon->type == MONS_PSYCHE)
+        if (type == MONS_PSYCHE)
         {
             force_item = true;
             set_item_ego_type(item, OBJ_WEAPONS,
@@ -1203,18 +1213,6 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
     }
     break;
 
-    case MONS_SALAMANDER_FIREBRAND:
-        force_item = true;
-        item.base_type = OBJ_WEAPONS;
-        item.sub_type  = random_choose(WPN_GREAT_SWORD, WPN_GREAT_MACE,
-                                       WPN_BATTLEAXE);
-        set_item_ego_type(item, OBJ_WEAPONS, SPWPN_FLAMING);
-        item.flags |= ISFLAG_KNOW_TYPE;
-        if (one_chance_in(3))
-            item.plus = 2 + random2(4);
-
-        break;
-
     case MONS_SALAMANDER_MYSTIC:
         item.base_type = OBJ_WEAPONS;
         item.sub_type  = random_choose_weighted(10, WPN_QUARTERSTAFF,
@@ -1282,7 +1280,7 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
                                        WPN_DEMON_WHIP,
                                        WPN_FLAIL);
         level = ISPEC_GOOD_ITEM;
-        if (mon->type == MONS_THE_ENCHANTRESS && one_chance_in(6))
+        if (type == MONS_THE_ENCHANTRESS && one_chance_in(6))
         {
             force_item = true;
             set_item_ego_type(item, OBJ_WEAPONS, SPWPN_DISTORTION);
@@ -1476,7 +1474,7 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
     if (item.base_type == OBJ_UNASSIGNED)
         return;
 
-    if (!force_item && mons_is_unique(mon->type))
+    if (!force_item && mons_is_unique(type))
     {
         if (x_chance_in_y(10 + mon->get_experience_level(), 100))
             level = ISPEC_GOOD_ITEM;
@@ -1492,7 +1490,7 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
     // and subtype and create a new item. - bwr
     const int thing_created =
         ((force_item) ? get_mitm_slot() : items(false, xitc, xitt, level,
-                                                item.special));
+                                                item.brand));
 
     if (thing_created == NON_ITEM)
         return;
@@ -1515,7 +1513,7 @@ static void _give_weapon(monster* mon, int level, bool melee_only = false,
         item_set_appearance(i);
 
     if (force_uncursed)
-        do_uncurse_item(i, false);
+        do_uncurse_item(i);
 
     if (!is_artefact(mitm[thing_created]) && !floor_tile.empty())
     {
@@ -1594,7 +1592,7 @@ static void _give_ammo(monster* mon, int level, bool mons_summoned)
             if (ammo_brand != SPMSL_NORMAL
                 && (bow_brand == SPWPN_FLAMING || bow_brand == SPWPN_FREEZING))
             {
-                mitm[thing_created].special = SPMSL_NORMAL;
+                mitm[thing_created].brand = SPMSL_NORMAL;
             }
         }
 
@@ -1605,10 +1603,6 @@ static void _give_ammo(monster* mon, int level, bool mons_summoned)
                 mitm[thing_created].quantity *= 2;
                 break;
 
-            case MONS_NESSOS:
-                mitm[thing_created].special = SPMSL_POISONED;
-                break;
-
             case MONS_JOSEPH:
                 mitm[thing_created].quantity += 2 + random2(7);
                 break;
@@ -1695,9 +1689,9 @@ static void _give_ammo(monster* mon, int level, bool mons_summoned)
         case MONS_DRACONIAN_KNIGHT:
         case MONS_GNOLL:
         case MONS_HILL_GIANT:
-            if (!one_chance_in(20))
+            if (!level || !one_chance_in(20))
                 break;
-            // deliberate fall-through
+            // deliberate fall-through to harold
 
         case MONS_HAROLD: // bounty hunter, up to 5 nets
             if (mons_summoned)
@@ -1784,17 +1778,8 @@ static void _give_shield(monster* mon, int level)
         break;
 
     case MONS_CHERUB:
-        if ((!main_weap || mon->hands_reqd(*main_weap) == HANDS_ONE)
-            && (!alt_weap || mon->hands_reqd(*alt_weap) == HANDS_ONE))
-        {
-            // Big shields interfere with ranged combat, at least theme-wise.
-            make_item_for_monster(mon, OBJ_ARMOUR, ARM_BUCKLER, level, 1);
-        }
-        break;
-
-    case MONS_DEEP_ELF_FIGHTER:
-        if (one_chance_in(6))
-            make_item_for_monster(mon, OBJ_ARMOUR, ARM_BUCKLER, level);
+        // Big shields interfere with ranged combat, at least theme-wise.
+        make_item_for_monster(mon, OBJ_ARMOUR, ARM_BUCKLER, level, 1);
         break;
 
     case MONS_MINOTAUR:
@@ -1806,6 +1791,7 @@ static void _give_shield(monster* mon, int level)
     case MONS_NAGA_WARRIOR:
     case MONS_VAULT_GUARD:
     case MONS_VAULT_WARDEN:
+    case MONS_ORC_WARLORD:
         if (one_chance_in(3))
         {
             make_item_for_monster(mon, OBJ_ARMOUR,
@@ -1815,13 +1801,6 @@ static void _give_shield(monster* mon, int level)
         }
         break;
 
-    case MONS_OCTOPODE_CRUSHER:
-        if (one_chance_in(3))
-            level = ISPEC_GOOD_ITEM;
-        if (coinflip())
-            make_item_for_monster(mon, OBJ_ARMOUR, ARM_SHIELD, level);
-        break;
-
     case MONS_DRACONIAN_KNIGHT:
         if (coinflip())
         {
@@ -1925,10 +1904,9 @@ static void _give_shield(monster* mon, int level)
         break;
 
     case MONS_ROBIN:
-        shield = make_item_for_monster(mon, OBJ_ARMOUR, ARM_HELMET,
-                                       level * 2 + 1, 1);
-        // but actually, a hat
         // The Nikola Hack
+        make_item_for_monster(mon, OBJ_ARMOUR, ARM_HELMET,
+                              level * 2 + 1, 1);
         break;
 
     case MONS_CORRUPTER:
@@ -1936,7 +1914,7 @@ static void _give_shield(monster* mon, int level)
         if (one_chance_in(3))
         {
             armour_type shield_type = coinflip() ? ARM_BUCKLER : ARM_SHIELD;
-            shield = make_item_for_monster(mon, OBJ_ARMOUR, shield_type, level);
+            make_item_for_monster(mon, OBJ_ARMOUR, shield_type, level);
         }
         break;
 
@@ -1959,13 +1937,14 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs, bool merc)
     item.quantity  = 1;
 
     bool force_item = false;
-    int type = mon->type;
+    monster_type type = mon->type;
 
     if (spectral_orcs)
-        type = mon->orc_type;
+        type = mon->base_monster;
 
     switch (type)
     {
+    case MONS_DEEP_ELF_ARCHER:
     case MONS_DEEP_ELF_BLADEMASTER:
     case MONS_DEEP_ELF_MASTER_ARCHER:
         item.base_type = OBJ_ARMOUR;
@@ -1975,16 +1954,13 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs, bool merc)
     case MONS_IJYB:
     case MONS_DUVESSA:
     case MONS_DEEP_ELF_ANNIHILATOR:
-    case MONS_DEEP_ELF_CONJURER:
     case MONS_DEEP_ELF_DEATH_MAGE:
     case MONS_DEEP_ELF_DEMONOLOGIST:
-    case MONS_DEEP_ELF_FIGHTER:
     case MONS_DEEP_ELF_HIGH_PRIEST:
     case MONS_DEEP_ELF_KNIGHT:
     case MONS_DEEP_ELF_MAGE:
-    case MONS_DEEP_ELF_PRIEST:
     case MONS_DEEP_ELF_SORCERER:
-    case MONS_DEEP_ELF_SUMMONER:
+    case MONS_DEEP_ELF_ELEMENTALIST:
     case MONS_ORC:
     case MONS_ORC_HIGH_PRIEST:
     case MONS_ORC_PRIEST:
@@ -2152,13 +2128,6 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs, bool merc)
         item.sub_type  = ARM_LEATHER_ARMOUR;
         break;
 
-    case MONS_OCTOPODE_CRUSHER:
-        if (one_chance_in(3))
-            level = ISPEC_GOOD_ITEM;
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_HAT;
-        break;
-
     case MONS_ANGEL:
     case MONS_CHERUB:
     case MONS_SIGMUND:
@@ -2180,10 +2149,10 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs, bool merc)
     case MONS_CENTAUR_WARRIOR:
     case MONS_YAKTAUR:
     case MONS_YAKTAUR_CAPTAIN:
-        if (one_chance_in(mon->type == MONS_CENTAUR              ? 1000 :
-                            mon->type == MONS_CENTAUR_WARRIOR      ?  500 :
-                            mon->type == MONS_YAKTAUR              ?  300
-                         /* mon->type == MONS_YAKTAUR_CAPTAIN ? */ :  200))
+        if (one_chance_in(type == MONS_CENTAUR              ? 1000 :
+                          type == MONS_CENTAUR_WARRIOR      ?  500 :
+                          type == MONS_YAKTAUR              ?  300
+                       /* type == MONS_YAKTAUR_CAPTAIN ? */ :  200))
         {
             item.base_type = OBJ_ARMOUR;
             item.sub_type  = ARM_CENTAUR_BARDING;
@@ -2198,16 +2167,16 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs, bool merc)
     case MONS_NAGA_SHARPSHOOTER:
     case MONS_NAGA_WARRIOR:
     case MONS_GREATER_NAGA:
-        if (one_chance_in(mon->type == MONS_NAGA         ?  800 :
-                          mon->type == MONS_NAGA_WARRIOR ?  300 :
-                          mon->type == MONS_GREATER_NAGA ?  100
-                                                         :  200))
+        if (one_chance_in(type == MONS_NAGA         ?  800 :
+                          type == MONS_NAGA_WARRIOR ?  300 :
+                          type == MONS_GREATER_NAGA ?  100
+                                                    :  200))
         {
             item.base_type = OBJ_ARMOUR;
             item.sub_type  = ARM_NAGA_BARDING;
         }
-        else if (mon->type == MONS_GREATER_NAGA
-                 || mon->type == MONS_NAGA_RITUALIST
+        else if (type == MONS_GREATER_NAGA
+                 || type == MONS_NAGA_RITUALIST
                  || one_chance_in(3))
         {
             item.base_type = OBJ_ARMOUR;
@@ -2422,7 +2391,7 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs, bool merc)
         if (item.base_type == OBJ_UNASSIGNED)
         {
             item.base_type = OBJ_ARMOUR;
-            item.sub_type = mons_is_draconian(mon->type) ? ARM_CLOAK : ARM_ROBE;
+            item.sub_type = mons_is_draconian(type) ? ARM_CLOAK : ARM_ROBE;
         }
     }
 
@@ -2433,7 +2402,7 @@ static void _give_armour(monster* mon, int level, bool spectral_orcs, bool merc)
     const object_class_type xitc = item.base_type;
     const int xitt = item.sub_type;
 
-    if (!force_item && mons_is_unique(mon->type) && level != ISPEC_GOOD_ITEM)
+    if (!force_item && mons_is_unique(type) && level != ISPEC_GOOD_ITEM)
     {
         if (x_chance_in_y(9 + mon->get_experience_level(), 100))
             level = ISPEC_GOOD_ITEM;
@@ -2469,7 +2438,7 @@ static void _give_gold(monster* mon, int level)
     _give_monster_item(mon, it);
 }
 
-void give_weapon(monster *mons, int level_number, bool mons_summoned, bool spectral_orcs)
+void give_weapon(monster *mons, int level_number, bool spectral_orcs)
 {
     _give_weapon(mons, level_number, false, true, spectral_orcs);
 }
