@@ -9,6 +9,7 @@ static const pop_entry pop_d[] =
   {  1,  3, 1000, FLAT, MONS_KOBOLD },
   {  1,  3, 1000, FLAT, MONS_RAT },
   {  1,  3, 1000, FLAT, MONS_HOBGOBLIN },
+  {  1,  5,  335, FALL, MONS_DART_SLUG },
   {  1, 11,  515, SEMI, MONS_GIANT_GECKO },
   {  1, 11,  335, SEMI, MONS_JACKAL },
   {  1, 11,  192, PEAK, MONS_GNOLL },
@@ -27,6 +28,7 @@ static const pop_entry pop_d[] =
   {  4, 14,  515, SEMI, MONS_ORC_WIZARD },
   {  4, 14,  515, SEMI, MONS_SCORPION },
   {  4, 14,  335, SEMI, MONS_PHANTOM },
+  {  4, 14,  335, SEMI, MONS_HOWLER_MONKEY },
   {  4, 16, 1000, FLAT, MONS_SKELETON },
   {  5, 13,   89, PEAK, MONS_GNOLL_SERGEANT },
   {  5, 15,  650, FLAT, MONS_CRIMSON_IMP },
@@ -55,13 +57,12 @@ static const pop_entry pop_d[] =
   {  8, 18,  335, SEMI, MONS_WYVERN },
   {  8, 18,  230, PEAK, MONS_EYE_OF_DRAINING },
   {  9, 14,  825, SEMI, MONS_YAK },
-  {  9, 16,  475, SEMI, MONS_DEEP_ELF_MAGE },
   {  9, 17,  825, SEMI, MONS_TROLL },
+  {  9, 19,  192, PEAK, MONS_VAMPIRE },
   { 10, 16,  194, PEAK, MONS_SOLDIER_ANT },
   { 10, 18, 1000, FLAT, MONS_HILL_GIANT },
   { 10, 18,  370, SEMI, MONS_GARGOYLE },
   { 10, 18,  335, SEMI, MONS_WRAITH },
-  { 10, 18,  220, PEAK, MONS_TRAPDOOR_SPIDER },
   { 10, 20,  515, SEMI, MONS_UNSEEN_HORROR },
   { 10, 20,  192, PEAK, MONS_KOMODO_DRAGON },
   { 11, 18,  235, SEMI, MONS_KOBOLD_DEMONOLOGIST },
@@ -72,11 +73,11 @@ static const pop_entry pop_d[] =
   { 11, 21,  335, SEMI, MONS_MOTTLED_DRAGON },
   { 11, 21,  260, PEAK, MONS_BASILISK },
   { 11, 21,  192, PEAK, MONS_SKELETAL_WARRIOR },
-  { 11, 21,  146, PEAK, MONS_BRAIN_WORM },
+  { 11, 21,  192, PEAK, MONS_DEATH_KNIGHT },
   { 11, 23,  515, SEMI, MONS_HYDRA },
+  { 12, 19,  475, SEMI, MONS_DEEP_ELF_MAGE },
   { 12, 20,  515, SEMI, MONS_VAMPIRE_MOSQUITO },
   { 12, 22,  440, FALL, MONS_SLIME_CREATURE },
-  { 12, 22,  192, PEAK, MONS_VAMPIRE },
   { 13, 21,   89, PEAK, MONS_RAKSHASA },
   { 13, 17,  925, FLAT, MONS_CENTAUR_WARRIOR },
   { 18, 23,  925, FALL, MONS_CENTAUR_WARRIOR },
@@ -86,9 +87,8 @@ static const pop_entry pop_d[] =
   { 13, 23,  675, SEMI, MONS_SHAPESHIFTER },
   { 13, 23,  335, SEMI, MONS_GRIFFON },
   { 13, 27,   89, FALL, MONS_CATOBLEPAS },
-  { 14, 19,  150, RISE, MONS_SALAMANDER_STORMCALLER },
   { 14, 19,  140, FLAT, MONS_WIZARD },
-  { 14, 20,  136, SEMI, MONS_DEEP_ELF_FIGHTER },
+  { 14, 21,  140, RISE, MONS_SALAMANDER_STORMCALLER },
   { 14, 22,  260, SEMI, MONS_FREEZING_WRAITH },
   { 14, 22,  270, SEMI, MONS_SIMULACRUM },
   { 14, 22,  115, SEMI, MONS_BOGGART },
@@ -105,11 +105,11 @@ static const pop_entry pop_d[] =
   { 17, 24,  102, SEMI, MONS_GREAT_ORB_OF_EYES },
   { 17, 24,   52, SEMI, MONS_NECROMANCER },
   { 17, 25,  136, SEMI, MONS_DEEP_ELF_KNIGHT },
+  { 17, 25,  136, SEMI, MONS_DEEP_ELF_ARCHER },
   { 17, 25,  136, SEMI, MONS_HORNET },
   { 17, 25,   89, PEAK, MONS_FIRE_CRAB },
   { 17, 25,   89, PEAK, MONS_HARPY },
-  { 17, 25,   68, SEMI, MONS_DEEP_ELF_CONJURER },
-  { 17, 25,   68, SEMI, MONS_DEEP_ELF_PRIEST },
+  { 17, 25,  136, SEMI, MONS_DEEP_ELF_MAGE },
   { 18, 24,   52, SEMI, MONS_GIANT_ORANGE_BRAIN },
   { 18, 28,  180, PEAK, MONS_FLAYED_GHOST },
   { 19, 25,   35, PEAK, MONS_ORC_HIGH_PRIEST },
@@ -146,44 +146,45 @@ static const pop_entry pop_temple[] =
 
 static const pop_entry pop_orc[] =
 { // Orcish Mines
-  {  1,  4, 1000, FLAT, MONS_ORC },
+  {  1,  4,  384, FLAT, MONS_NO_MONSTER },
   {  1,  4,  192, FLAT, MONS_ORC_WARRIOR },
-  {  1,  4,   25, SEMI, MONS_ORC_PRIEST },
-  {  1,  5,   25, SEMI, MONS_ORC_WIZARD },
-  {  1,  5,   25, SEMI, MONS_ORC_KNIGHT },
-  {  2,  4,    8, RISE, MONS_ORC_HIGH_PRIEST },
-  {  1,  4,   25, RISE, MONS_ORC_SORCERER },
-  {  2,  4,    8, RISE, MONS_ORC_WARLORD },
+  {  1,  4,   25, FLAT, MONS_ORC_PRIEST },
+  {  1,  4,   25, FLAT, MONS_ORC_WIZARD },
+  {  1,  4,   25, FLAT, MONS_ORC_KNIGHT },
+  {  1,  4,    8, FLAT, MONS_ORC_HIGH_PRIEST },
+  {  1,  4,   25, FLAT, MONS_ORC_SORCERER },
+  {  1,  4,    8, FLAT, MONS_ORC_WARLORD },
   {  1,  4,   40, FLAT, MONS_WARG },
-  {  1,  4,  280, FLAT, MONS_NO_MONSTER },
-  {  2,  4,    3, SEMI, MONS_GNOLL },
-  {  4,  4,    1, FLAT, MONS_GNOLL_SHAMAN },
-  {  4,  4,    1, FLAT, MONS_GNOLL_SERGEANT },
+  {  1,  4,    3, FLAT, MONS_GNOLL },
+  {  1,  4,    1, FLAT, MONS_GNOLL_SHAMAN },
+  {  1,  4,    1, FLAT, MONS_GNOLL_SERGEANT },
   {  1,  4,   89, FLAT, MONS_OGRE },
-  {  2,  4,    8, RISE, MONS_TWO_HEADED_OGRE },
-  {  4,  4,    1, FLAT, MONS_OGRE_MAGE },
-  {  1,  4,   40, RISE, MONS_TROLL },
-  {  2,  4,    8, RISE, MONS_CYCLOPS },
-  {  3,  4,    4, RISE, MONS_ETTIN },
-  {  3,  4,    4, RISE, MONS_STONE_GIANT },
+  {  1,  4,    8, FLAT, MONS_TWO_HEADED_OGRE },
+  {  1,  4,    1, FLAT, MONS_OGRE_MAGE },
+  {  1,  4,   40, FLAT, MONS_TROLL },
+  {  1,  4,    8, FLAT, MONS_CYCLOPS },
+  {  1,  4,    4, FLAT, MONS_ETTIN },
+  {  1,  4,    4, FLAT, MONS_STONE_GIANT },
   { 0,0,0,FLAT,MONS_0 }
 };
 
 static const pop_entry pop_elf[] =
 { // Elven Halls (OOD cap: 7)
-  {  1,  7, 1000, FLAT, MONS_NO_MONSTER }, // was fungus
   {  1,  5,   50, FLAT, MONS_ORC_HIGH_PRIEST },
   {  1,  6,   50, FLAT, MONS_ORC_SORCERER },
-  {  1,  7, 1000, FLAT, MONS_DEEP_ELF_FIGHTER },
-  {  1,  7, 1200, FLAT, MONS_DEEP_ELF_MAGE },
+  {  1,  7, 2775, FLAT, MONS_DEEP_ELF_MAGE },
+  {  1,  7, 1385, FLAT, MONS_DANCING_WEAPON },
   {  1,  7,  925, FLAT, MONS_DEEP_ELF_KNIGHT },
-  {  1,  7,  780, FLAT, MONS_DEEP_ELF_CONJURER },
-  {  1,  7,  650, FLAT, MONS_DEEP_ELF_SUMMONER },
-  {  1,  7,  350, FLAT, MONS_DEEP_ELF_PRIEST },
+  {  1,  7,  925, FLAT, MONS_DEEP_ELF_ARCHER },
+  {  1,  7,  345, FLAT, MONS_FIRE_ELEMENTAL },
+  {  1,  7,  345, FLAT, MONS_WATER_ELEMENTAL },
+  {  1,  7,  345, FLAT, MONS_AIR_ELEMENTAL },
+  {  1,  7,  345, FLAT, MONS_EARTH_ELEMENTAL },
   {  1,  8,   65, SEMI, MONS_DEEP_ELF_SORCERER },
   {  1,  7,   40, SEMI, MONS_DEEP_ELF_ANNIHILATOR },
   {  1,  8,   65, SEMI, MONS_DEEP_ELF_DEMONOLOGIST },
   {  1,  7,   40, SEMI, MONS_DEEP_ELF_HIGH_PRIEST },
+  {  1,  8,   65, SEMI, MONS_DEEP_ELF_ELEMENTALIST },
   {  0,  7,   45, SEMI, MONS_DEEP_ELF_DEATH_MAGE },
   {  6,  7,   10, RISE, MONS_DEEP_ELF_BLADEMASTER },
   {  6,  7,   10, RISE, MONS_DEEP_ELF_MASTER_ARCHER },
@@ -236,7 +237,7 @@ static const pop_entry pop_lair[] =
   {  1,  9,  275, SEMI, MONS_SHEEP },
   {  1, 11,  515, SEMI, MONS_HYDRA },
   {  1, 11,  455, SEMI, MONS_BLACK_MAMBA },
-  {  1, 11,  275, PEAK, MONS_FIRE_DRAKE },
+  {  1, 11,  275, PEAK, MONS_RIME_DRAKE },
   {  2,  6,    8, PEAK, MONS_WASP },
   {  2,  8,   25, PEAK, MONS_HELL_RAT },
   {  2,  8,   25, PEAK, MONS_STEAM_DRAGON },
@@ -249,7 +250,6 @@ static const pop_entry pop_lair[] =
   {  3,  9,   52, SEMI, MONS_CATOBLEPAS },
   {  3,  9,   25, PEAK, MONS_OKLOB_PLANT },
   {  4,  8,   89, RISE, MONS_BOULDER_BEETLE },
-  {  4,  8,   14, SEMI, MONS_BRAIN_WORM },
   {  4, 10,   52, SEMI, MONS_POLAR_BEAR },
   {  4, 10,   25, PEAK, MONS_LINDWURM },
   {  5, 12,   66, RISE, MONS_FIRE_CRAB },
@@ -257,40 +257,24 @@ static const pop_entry pop_lair[] =
   { 0,0,0,FLAT,MONS_0 }
 };
 
-/* If a save originated before the Lair rune branches were reduced to 4
- * levels, the Lair rune branches will still last 5 levels. If this is
- * the case, having just the spawn lists which assume 4 level branches
- * could cause some odd spawns. Extending a few FLAT ranges from 4 to 5
- * partially corrects this. This solution does not affect future saves
- * outside some OOD spawns.
- *
- * After the release of 0.17 stable, this can be removed.
-*/
-
-#if TAG_MAJOR_VERSION == 34
-#define BRANCH_END 5
-#else
-#define BRANCH_END 4
-#endif
-
 static const pop_entry pop_swamp[] =
 { // Swamp
-  {  1,  BRANCH_END, 2000, FLAT, MONS_NO_MONSTER }, // was plant + fungus
+  {  1,  4, 2000, FLAT, MONS_NO_MONSTER }, // was plant + fungus
   { -6,  4,  480, RISE, MONS_SLIME_CREATURE },
   { -2,  6,  245, SEMI, MONS_SHADOW },
   {  0,  5,  480, SEMI, MONS_SPRIGGAN_RIDER },
   {  0,  6,   40, PEAK, MONS_UGLY_THING },
-  {  1,  BRANCH_END, 1000, FLAT, MONS_ALLIGATOR },
-  {  1,  BRANCH_END, 1000, FLAT, MONS_SPINY_FROG },
-  {  1,  BRANCH_END,  925, FLAT, MONS_BOG_BODY },
-  {  1,  BRANCH_END,  925, FLAT, MONS_SWAMP_DRAKE },
-  {  1,  BRANCH_END,  915, FLAT, MONS_HYDRA },
-  {  1,  BRANCH_END,  825, FLAT, MONS_GIANT_LEECH },
-  {  1,  BRANCH_END,  665, FLAT, MONS_VAMPIRE_MOSQUITO },
-  {  1,  BRANCH_END,  500, FLAT, MONS_SWAMP_DRAGON },
-  {  1,  BRANCH_END,  335, FLAT, MONS_INSUBSTANTIAL_WISP },
-  {  1,  BRANCH_END,  345, FLAT, MONS_WASP },
-  {  1,  BRANCH_END,  192, FLAT, MONS_HORNET },
+  {  1,  4, 1000, FLAT, MONS_ALLIGATOR },
+  {  1,  4, 1000, FLAT, MONS_SPINY_FROG },
+  {  1,  4,  925, FLAT, MONS_BOG_BODY },
+  {  1,  4,  925, FLAT, MONS_SWAMP_DRAKE },
+  {  1,  4,  915, FLAT, MONS_HYDRA },
+  {  1,  4,  825, FLAT, MONS_GIANT_LEECH },
+  {  1,  4,  665, FLAT, MONS_VAMPIRE_MOSQUITO },
+  {  1,  4,  500, FLAT, MONS_SWAMP_DRAGON },
+  {  1,  4,  335, FLAT, MONS_INSUBSTANTIAL_WISP },
+  {  1,  4,  345, FLAT, MONS_WASP },
+  {  1,  4,  192, FLAT, MONS_HORNET },
   {  1,  4,  100, FALL, MONS_KOMODO_DRAGON },
   {  1,  4,   25, RISE, MONS_TENTACLED_MONSTROSITY },
   {  1,  4,  435, RISE, MONS_THORN_HUNTER },
@@ -314,14 +298,14 @@ static const pop_entry pop_shoals[] =
   {  0,  6,   73, SEMI, MONS_KRAKEN },
   {  0,  7,  265, SEMI, MONS_MERFOLK_IMPALER },
   {  0,  7,  125, SEMI, MONS_MERFOLK_AQUAMANCER },
-  {  1,  BRANCH_END,  735, FLAT, MONS_MERFOLK },
-  {  1,  BRANCH_END,  475, FLAT, MONS_SEA_SNAKE },
-  {  1,  BRANCH_END,  385, FLAT, MONS_SNAPPING_TURTLE },
-  {  1,  BRANCH_END,  360, FLAT, MONS_MANTICORE },
-  {  1,  BRANCH_END,  300, FLAT, MONS_SIREN },
-  {  1,  BRANCH_END,  195, FLAT, MONS_WATER_ELEMENTAL },
-  {  1,  BRANCH_END,  125, FLAT, MONS_WIND_DRAKE },
-  {  1,  BRANCH_END,  175, FLAT, MONS_HARPY },
+  {  1,  4,  735, FLAT, MONS_MERFOLK },
+  {  1,  4,  475, FLAT, MONS_SEA_SNAKE },
+  {  1,  4,  385, FLAT, MONS_SNAPPING_TURTLE },
+  {  1,  4,  360, FLAT, MONS_MANTICORE },
+  {  1,  4,  300, FLAT, MONS_SIREN },
+  {  1,  4,  195, FLAT, MONS_WATER_ELEMENTAL },
+  {  1,  4,  125, FLAT, MONS_WIND_DRAKE },
+  {  1,  4,  175, FLAT, MONS_HARPY },
   {  1,  7,  135, PEAK, MONS_MERFOLK_JAVELINEER },
   {  1,  7,   85, PEAK, MONS_ALLIGATOR_SNAPPING_TURTLE },
   {  2,  4,  190, SEMI, MONS_SATYR },
@@ -351,22 +335,20 @@ static const pop_entry pop_spider[] =
   { -1,  4,  260, RISE, MONS_HORNET },
   { -1,  6,   89, SEMI, MONS_BOULDER_BEETLE },
   { -1,  9,  765, SEMI, MONS_DEMONIC_CRAWLER },
-  {  1,  BRANCH_END,  955, FLAT, MONS_WOLF_SPIDER },
-  {  1,  BRANCH_END,  880, FLAT, MONS_TRAPDOOR_SPIDER },
-  {  1,  BRANCH_END,  765, FLAT, MONS_JUMPING_SPIDER },
-  {  1,  BRANCH_END,  690, FLAT, MONS_TARANTELLA },
-  {  1,  BRANCH_END,  605, FLAT, MONS_REDBACK },
-  {  1,  BRANCH_END,  550, FLAT, MONS_ORB_SPIDER },
-  {  1,  BRANCH_END,  335, FLAT, MONS_SPIDER },
-  {  1,  BRANCH_END,   52, FLAT, MONS_WASP },
+  {  1,  4,  955, FLAT, MONS_WOLF_SPIDER },
+  {  1,  4,  985, FLAT, MONS_JUMPING_SPIDER },
+  {  1,  4,  910, FLAT, MONS_TARANTELLA },
+  {  1,  4, 1045, FLAT, MONS_REDBACK },
+  {  1,  4,  550, FLAT, MONS_ORB_SPIDER },
+  {  1,  4,   52, FLAT, MONS_WASP },
   {  1,  6,  100, FLAT, MONS_TORPOR_SNAIL },
   {  1,  6,  190, SEMI, MONS_EMPEROR_SCORPION },
   {  1,  6,  155, SEMI, MONS_MOTH_OF_WRATH },
   {  1,  9,  300, SEMI, MONS_ENTROPY_WEAVER },
   {  1,  9,  200, PEAK, MONS_GHOST_MOTH },
+  {  2, 10,  260, PEAK, MONS_SPARK_WASP },
   { 0,0,0,FLAT,MONS_0 }
 };
-#undef BRANCH_END
 
 static const pop_entry pop_slime[] =
 { // Slime Pits
@@ -381,7 +363,8 @@ static const pop_entry pop_slime[] =
   {  1,  9,  390, SEMI, MONS_GREAT_ORB_OF_EYES },
   {  1,  6,  200, RISE, MONS_DEATH_OOZE },
   {  2,  6,  100, RISE, MONS_GIANT_ORANGE_BRAIN },
-  {  1,  6,  800, FLAT, MONS_NO_MONSTER }, // Old ooze weight
+  {  2,  9,   50, SEMI, MONS_GIANT_EYEBALL },
+  {  1,  6,  750, FLAT, MONS_NO_MONSTER }, // Old ooze weight
   { 0,0,0,FLAT,MONS_0 }
 };
 
@@ -397,8 +380,8 @@ static const pop_entry pop_vaults[] =
   { -4,  6,  335, SEMI, MONS_YAKTAUR },
   { -2,  6,  136, SEMI, MONS_GREAT_ORB_OF_EYES },
   { -2,  6,  136, SEMI, MONS_HORNET },
-  { -2,  6,  136, SEMI, MONS_DEEP_ELF_FIGHTER },
   { -2,  6,  136, SEMI, MONS_DEEP_ELF_KNIGHT },
+  { -2,  6,  136, SEMI, MONS_DEEP_ELF_ARCHER },
   { -2,  6,   89, PEAK, MONS_ICE_DRAGON },
   { -2,  6,   89, PEAK, MONS_HARPY },
   { -2,  6,   89, PEAK, MONS_FIRE_CRAB },
@@ -424,6 +407,7 @@ static const pop_entry pop_vaults[] =
   {  1,  4,  440, FALL, MONS_UGLY_THING },
   {  1,  4,  440, FALL, MONS_CENTAUR_WARRIOR },
   {  1,  5,   89, FLAT, MONS_NECROMANCER },
+  {  1,  5,   89, FLAT, MONS_DEATH_KNIGHT },
   {  1,  6,  275, FALL, MONS_WOLF_SPIDER },
   {  1,  7,  690, FALL, MONS_ORC_KNIGHT },
   {  1, 10,  640, FALL, MONS_VAULT_SENTINEL },
@@ -435,8 +419,7 @@ static const pop_entry pop_vaults[] =
   {  2, 12,   75, FALL, MONS_SALAMANDER_STORMCALLER },
   {  2, 12,  340, FALL, MONS_STONE_GIANT },
   {  2, 12,  192, PEAK, MONS_ETTIN },
-  {  3, 10,   40, FLAT, MONS_DEEP_ELF_CONJURER },
-  {  3, 10,   40, FLAT, MONS_DEEP_ELF_PRIEST },
+  {  3, 10,   80, FLAT, MONS_DEEP_ELF_MAGE },
   {  3, 11,  136, SEMI, MONS_FIRE_GIANT },
   {  3, 11,  136, SEMI, MONS_FROST_GIANT },
   {  3, 11,   68, SEMI, MONS_DEEP_TROLL },
@@ -461,6 +444,7 @@ static const pop_entry pop_vaults[] =
   { 11, 12,   16, FLAT, MONS_DEEP_ELF_ANNIHILATOR },
   { 11, 12,   16, FLAT, MONS_DEEP_ELF_SORCERER },
   { 11, 12,   16, FLAT, MONS_DEEP_ELF_DEATH_MAGE },
+  { 11, 12,   16, FLAT, MONS_DEEP_ELF_ELEMENTALIST },
   { 12, 12,   16, FLAT, MONS_ANCIENT_LICH },
   { 0,0,0,FLAT,MONS_0 }
 };
@@ -471,16 +455,15 @@ static const pop_entry pop_crypt[] =
   { -3,  3,   40, PEAK, MONS_WIGHT },
   { -3,  3,   45, PEAK, MONS_FLYING_SKULL },
   { -3,  3,   75, SEMI, MONS_NECROMANCER },
+  { -3,  3,   75, SEMI, MONS_DEATH_KNIGHT },
   { -2,  4,  125, SEMI, MONS_WRAITH },
   { -1,  5,   75, PEAK, MONS_JIANGSHI },
   { -1,  5,  125, PEAK, MONS_PHANTASMAL_WARRIOR },
   { -1,  9,  120, PEAK, MONS_ANCIENT_CHAMPION },
   {  0,  2,   65, SEMI, MONS_FREEZING_WRAITH },
-  {  0,  3,   85, FALL, MONS_VAMPIRE },
-  {  0,  5,  125, PEAK, MONS_VAMPIRE_MAGE },
+  {  0,  5,  125, FLAT, MONS_VAMPIRE_MAGE },
   {  0,  5,   93, PEAK, MONS_GHOUL },
-  {  0,  5,  105, RISE, MONS_VAMPIRE_KNIGHT },
-  {  0,  6,   75, SEMI, MONS_DEATH_KNIGHT },
+  {  0,  5,  105, FLAT, MONS_VAMPIRE_KNIGHT },
   {  1,  4,   75, FLAT, MONS_SKELETAL_WARRIOR },
   {  1,  5,   55, SEMI, MONS_SOUL_EATER },
   {  1,  6,  145, SEMI, MONS_EIDOLON },
@@ -497,7 +480,6 @@ static const pop_entry pop_crypt[] =
 
 static const pop_entry pop_tomb[] =
 { // Tomb (OOD cap: 5)
-  {  1,  3,    3, SEMI, MONS_TRAPDOOR_SPIDER },
   {  1,  5,  200, FLAT, MONS_SKELETON },
   {  1,  5,  185, FLAT, MONS_ZOMBIE },
   {  1,  5,   50, SEMI, MONS_SIMULACRUM },
@@ -526,9 +508,8 @@ static const pop_entry pop_hell[] =
   {  1,  1,   25, FLAT, MONS_HELLEPHANT },
   {  1,  1,   25, FLAT, MONS_TENTACLED_MONSTROSITY },
   {  1,  1,   89, FLAT, MONS_RED_DEVIL },
-  {  1,  1,   89, FLAT, MONS_BLUE_DEVIL },
+  {  1,  1,   89, FLAT, MONS_ICE_DEVIL },
   {  1,  1,  515, FLAT, MONS_SUN_DEMON },
-  {  1,  1,  515, FLAT, MONS_ICE_DEVIL },
   {  1,  1,  515, FLAT, MONS_SOUL_EATER },
   {  1,  1,  515, FLAT, MONS_REAPER },
   {  1,  1,   89, FLAT, MONS_LOROCYPROCA },
@@ -551,7 +532,6 @@ static const pop_entry pop_dis[] =
   {  1,  7,   66, FALL, MONS_PHANTOM },
   {  1,  6,  420, FALL, MONS_WIGHT },
   {  1,  7,  475, SEMI, MONS_WRAITH },
-  {  1,  7,   81, PEAK, MONS_VAMPIRE },
   {  1,  5,  625, FALL, MONS_SHADOW },
   {  1,  7,  260, FALL, MONS_FLYING_SKULL },
   {  1,  7,  192, SEMI, MONS_FREEZING_WRAITH },
@@ -569,8 +549,7 @@ static const pop_entry pop_dis[] =
   {  1,  2,    8, FALL, MONS_CRIMSON_IMP },
   {  1,  7, 1000, FLAT, MONS_RUST_DEVIL },
   {  1,  7,  540, FALL, MONS_RED_DEVIL },
-  {  1,  7,  335, FLAT, MONS_BLUE_DEVIL },
-  {  1,  7,  192, FLAT, MONS_ICE_DEVIL },
+  {  1,  7,  335, FLAT, MONS_ICE_DEVIL },
   {  1,  7,   25, PEAK, MONS_SOUL_EATER },
   {  1,  7,  900, FLAT, MONS_REAPER },
   {  1,  7,  775, FLAT, MONS_TORMENTOR },
@@ -579,18 +558,18 @@ static const pop_entry pop_dis[] =
   {  2,  8,   25, PEAK, MONS_IRON_DRAGON },
   {  1, 12,   60, FALL, MONS_IRON_GOLEM },
   {  1,  7,   25, PEAK, MONS_DANCING_WEAPON },
+  {  1,  7,  270, RISE, MONS_IRON_GIANT },
   { 0,0,0,FLAT,MONS_0 }
 };
 
 static const pop_entry pop_geh[] =
 { // Gehenna
-  {  1,  7, 2000, FLAT, MONS_SKELETON },
-  {  1,  7, 2000, FLAT, MONS_ZOMBIE },
+  {  1,  7, 1950, FLAT, MONS_SKELETON },
+  {  1,  7, 1950, FLAT, MONS_ZOMBIE },
   {  1,  7,  215, FALL, MONS_PHANTOM },
   {  1,  7,  515, FALL, MONS_NECROPHAGE },
   {  1,  7,  690, FALL, MONS_WIGHT },
   {  0,  7,  570, FLAT, MONS_WRAITH },
-  { -1,  7,  400, SEMI, MONS_VAMPIRE },
   {  1,  7,  705, FALL, MONS_SHADOW },
   {  1,  7,  385, FLAT, MONS_FLYING_SKULL },
   {  1,  9,   89, PEAK, MONS_PHANTASMAL_WARRIOR },
@@ -601,7 +580,7 @@ static const pop_entry pop_geh[] =
   {  2,  6,  215, FLAT, MONS_EFREET },
   { -1,  7,  515, PEAK, MONS_HELL_KNIGHT },
   {  1,  7,  350, FLAT, MONS_HELL_HOUND },
-  {  1,  7,  192, FLAT, MONS_HELL_HOG },
+  {  1,  7,  300, FLAT, MONS_HELL_HOG },
   {  1,  7,  192, FALL, MONS_CRIMSON_IMP },
   {  1, 12,  690, FALL, MONS_RED_DEVIL },
   { -1,  7,   89, PEAK, MONS_RUST_DEVIL },
@@ -629,7 +608,6 @@ static const pop_entry pop_coc[] =
   {  1,  7,  136, FALL, MONS_NECROPHAGE },
   {  1,  7,  420, FALL, MONS_WIGHT },
   { -1,  7,  420, SEMI, MONS_WRAITH },
-  {  1,  7,  345, FALL, MONS_VAMPIRE },
   {  1,  6,  625, FALL, MONS_SHADOW },
   {  1,  7,  970, FLAT, MONS_FREEZING_WRAITH },
   {  1,  7,  640, SEMI, MONS_FLYING_SKULL },
@@ -639,7 +617,6 @@ static const pop_entry pop_coc[] =
   {  2,  8,   35, PEAK, MONS_LICH },
   {  3,  7,    8, PEAK, MONS_ANCIENT_LICH },
   {  1,  7,  890, FLAT, MONS_WHITE_IMP },
-  {  1,  7,  890, SEMI, MONS_BLUE_DEVIL },
   {  1,  7,  890, FLAT, MONS_ICE_DEVIL },
   {  1,  7,   81, PEAK, MONS_SOUL_EATER },
   {  1,  7,  285, FLAT, MONS_TORMENTOR },
@@ -663,7 +640,8 @@ static const pop_entry pop_tar[] =
   {  1,  7,  550, SEMI, MONS_WRAITH },
   {  1,  7,  550, FALL, MONS_PHANTOM },
   {  1,  7,  835, FALL, MONS_WIGHT },
-  {  1,  7,  400, FLAT, MONS_VAMPIRE },
+  {  1,  7,  200, FLAT, MONS_VAMPIRE_MAGE },
+  {  1,  7,  200, FLAT, MONS_VAMPIRE_KNIGHT },
   {  1,  7,  570, FLAT, MONS_FLYING_SKULL },
   {  1,  7,  690, SEMI, MONS_FREEZING_WRAITH },
   {  1,  7,  420, FLAT, MONS_PHANTASMAL_WARRIOR },
@@ -674,11 +652,11 @@ static const pop_entry pop_tar[] =
   {  1,  9,  125, PEAK, MONS_LICH },
   {  3,  7,   11, PEAK, MONS_ANCIENT_LICH },
   {  1,  7,  550, FALL, MONS_HELL_HOUND },
+  {  1,  7,  729, FLAT, MONS_DOOM_HOUND },
   {  1,  7,   46, FALL, MONS_HELL_KNIGHT },
   {  1,  7,   35, PEAK, MONS_NECROMANCER },
   {  1,  7,   89, FALL, MONS_CRIMSON_IMP },
   {  1,  7, 1000, FLAT, MONS_SHADOW_IMP },
-  {  1,  7,  215, SEMI, MONS_BLUE_DEVIL },
   {  1,  7,   40, PEAK, MONS_RED_DEVIL },
   {  1,  7,  245, SEMI, MONS_ICE_DEVIL },
   {  1,  9,  260, SEMI, MONS_SOUL_EATER },
@@ -780,16 +758,15 @@ static const pop_entry pop_abyss[] =
   {  1,  4,  192, FALL, MONS_IRON_IMP },
   {  1,  4,   25, FALL, MONS_SHADOW_IMP },
   {  1,  5,    8, FALL, MONS_RED_DEVIL },
-  {  1,  5,   25, FALL, MONS_BLUE_DEVIL },
+  {  1,  5,   25, FALL, MONS_ICE_DEVIL },
   {  1,  5,   36, FALL, MONS_RUST_DEVIL },
   {  1,  8,   73, FALL, MONS_HELLWING },
   {  1,  8,   91, FALL, MONS_SIXFIRHY },
   {  1,  5,  125, FALL, MONS_ORANGE_DEMON },
   {  1,  8,  315, FALL, MONS_YNOXINUL },
-  {  1,  5,  325, FLAT, MONS_NEQOXEC },
+  {  1,  5,  225, FLAT, MONS_NEQOXEC },
   {  1,  5,  300, FLAT, MONS_SMOKE_DEMON },
   {  1,  5,  192, FLAT, MONS_CHAOS_SPAWN },
-  {  1,  5,   22, FLAT, MONS_ICE_DEVIL },
   {  1,  5,   22, FLAT, MONS_SUN_DEMON },
   {  1,  5,   14, FLAT, MONS_SOUL_EATER },
   {  1,  5,   25, FLAT, MONS_HELLION },
@@ -806,8 +783,8 @@ static const pop_entry pop_abyss[] =
   {  1,  5,   63, FLAT, MONS_EFREET },
   {  1,  5,   66, FLAT, MONS_RAKSHASA },
   {  1,  5,   25, FLAT, MONS_DEMONIC_CRAWLER },
-  {  1,  5,   30, FLAT, MONS_HELL_HOUND },
-  {  1,  5,   30, FLAT, MONS_HELL_HOG },
+  {  1,  8,   30, FALL, MONS_HELL_HOUND },
+  {  1, 10,   40, SEMI, MONS_HELL_HOG },
   {  1, 10,   16, SEMI, MONS_HELLEPHANT },
   // Misc Undead
   {  1,  5,  110, FALL, MONS_SKELETON },
@@ -830,9 +807,10 @@ static const pop_entry pop_abyss[] =
   {  1,  5,    8, FLAT, MONS_ANCIENT_LICH },
   // Thematic branch representatives, outsiders
   {  1,  5,    8, FLAT, MONS_ORC_SORCERER },
-  {  1,  5,    4, FLAT, MONS_DEEP_ELF_PRIEST },
+  {  1,  5,    4, FLAT, MONS_DEEP_ELF_MAGE },
   {  1,  5,    8, FLAT, MONS_DEEP_ELF_SORCERER },
   {  1,  5,    5, FLAT, MONS_DEEP_ELF_DEMONOLOGIST },
+  {  1,  5,    8, FLAT, MONS_DEEP_ELF_ELEMENTALIST },
   {  1,  5,   29, FLAT, MONS_BLINK_FROG },
   {  1,  5,    4, FALL, MONS_BASILISK },
   {  1,  5,    8, FLAT, MONS_MANA_VIPER },
@@ -867,7 +845,6 @@ static const pop_entry pop_abyss[] =
   {  1,  5,    3, FLAT, MONS_DRACONIAN_SCORCHER },
   {  3,  5,    1, FLAT, MONS_CORRUPTER },
   // Misc
-  {  1,  5,   50, FALL, MONS_BRAIN_WORM },
   {  1,  5,    8, FLAT, MONS_DEATH_DRAKE },
   {  1,  5,    2, FLAT, MONS_SHADOW_DRAGON },
   {  1,  5,    2, FLAT, MONS_QUICKSILVER_DRAGON },
@@ -912,13 +889,12 @@ static const pop_entry pop_pan[] =
   {  1,  1, 1000, FLAT, MONS_HELLWING },
   {  1,  1, 1000, FLAT, MONS_SIXFIRHY },
   {  1,  1,  670, FLAT, MONS_RED_DEVIL },
-  {  1,  1,  335, FLAT, MONS_BLUE_DEVIL },
+  {  1,  1,  335, FLAT, MONS_ICE_DEVIL },
   {  1,  1,  335, FLAT, MONS_RUST_DEVIL },
   {  1,  1, 1000, FLAT, MONS_YNOXINUL },
-  {  1,  1,  900, FLAT, MONS_NEQOXEC },
+  {  1,  1,  400, FLAT, MONS_NEQOXEC },
   {  1,  1,  900, FLAT, MONS_SMOKE_DEMON },
   {  1,  1,  335, FLAT, MONS_SUN_DEMON },
-  {  1,  1,  335, FLAT, MONS_ICE_DEVIL },
   {  1,  1,  335, FLAT, MONS_SOUL_EATER },
   {  1,  1,  192, FLAT, MONS_CHAOS_SPAWN },
   {  1,  1, 1000, FLAT, MONS_BALRUG },
@@ -935,7 +911,7 @@ static const pop_entry pop_pan[] =
   {  1,  1,  335, FLAT, MONS_BRIMSTONE_FIEND },
   {  1,  1,  335, FLAT, MONS_ICE_FIEND },
   {  1,  1,  335, FLAT, MONS_HELL_SENTINEL },
-  {  1,  1,  335, FLAT, MONS_SHADOW_FIEND },
+  {  1,  1,  335, FLAT, MONS_TZITZIMITL },
   {  1,  1,    8, FLAT, MONS_PROFANE_SERVITOR },
   {  1,  1,  200, FLAT, MONS_MONSTROUS_DEMONSPAWN },
   {  1,  1,  200, FLAT, MONS_GELID_DEMONSPAWN },
@@ -1009,8 +985,8 @@ static const pop_entry pop_icecv[] =
   {  1,  1,   89, FLAT, MONS_POLAR_BEAR },
   {  1,  1,  515, FLAT, MONS_ICE_BEAST },
   {  1,  1,  515, FLAT, MONS_WHITE_IMP },
-  {  1,  1,   25, FLAT, MONS_BLUE_DEVIL },
   {  1,  1,  515, FLAT, MONS_ICE_DEVIL },
+  {  1,  1,  515, FLAT, MONS_RIME_DRAKE },
   {  1,  1,  260, FLAT, MONS_FREEZING_WRAITH },
   {  1,  1, 1030, FLAT, MONS_SIMULACRUM },
   { 0,0,0,FLAT,MONS_0 }
@@ -1020,15 +996,14 @@ static const pop_entry pop_volcano[] =
 { // Volcano
   {  1,  1,  515, FLAT, MONS_SALAMANDER },
   {  1,  1,  515, FLAT, MONS_HELL_HOUND },
-  {  1,  1,  385, FLAT, MONS_HELL_HOG },
   {  1,  1,  385, FLAT, MONS_RED_DEVIL },
   {  1,  1,  515, FLAT, MONS_EFREET },
-  {  1,  1,  515, FLAT, MONS_FIRE_DRAKE },
   {  1,  1,  515, FLAT, MONS_MANTICORE },
   {  1,  1,  515, FLAT, MONS_LINDWURM },
   {  1,  1,  385, FLAT, MONS_TOENAIL_GOLEM },
   {  1,  1,  515, FLAT, MONS_FIRE_ELEMENTAL },
   {  1,  1,  385, FLAT, MONS_GARGOYLE },
+  {  1,  1,  385, FLAT, MONS_MOLTEN_GARGOYLE },
   { 0,0,0,FLAT,MONS_0 }
 };
 
@@ -1067,6 +1042,7 @@ static const pop_entry pop_depths[] =
   {  1,  7,  100, FALL, MONS_TENGU_CONJURER },
   {  1,  8,  600, FALL, MONS_STONE_GIANT },
   {  1,  8,  370, FALL, MONS_ETTIN },
+  {  1, 10,  100, SEMI, MONS_SPARK_WASP },
   {  1, 12,   60, FLAT, MONS_LICH },
   {  1, 12,   40, FLAT, MONS_FLAYED_GHOST },
   {  1, 14,   80, SEMI, MONS_GLOWING_SHAPESHIFTER },
@@ -1074,6 +1050,7 @@ static const pop_entry pop_depths[] =
   {  1, 14,   60, SEMI, MONS_SPHINX },
   {  2,  8,  135, SEMI, MONS_SPRIGGAN_AIR_MAGE },
   {  2,  8,  185, SEMI, MONS_SPRIGGAN_BERSERKER },
+  {  2, 10,   25, FLAT, MONS_GIANT_EYEBALL },
   {  3, 14,   45, FLAT, MONS_SPRIGGAN_DEFENDER },
   {  4, 14,   80, SEMI, MONS_TENTACLED_MONSTROSITY },
   {  4, 14,   40, FLAT, MONS_STORM_DRAGON },
@@ -1086,9 +1063,11 @@ static const pop_entry pop_depths[] =
   {  4, 14,   25, RISE, MONS_DEEP_ELF_ANNIHILATOR },
   {  4, 14,   25, RISE, MONS_DEEP_ELF_SORCERER },
   {  4, 14,   25, RISE, MONS_DEEP_ELF_DEATH_MAGE },
+  {  4, 14,   25, RISE, MONS_DEEP_ELF_ELEMENTALIST },
   {  5, 14,   50, FLAT, MONS_JUGGERNAUT },
   {  6, 14,   50, FLAT, MONS_TITAN },
   {  6, 14,   50, FLAT, MONS_CAUSTIC_SHRIKE },
+  {  6, 14,   25, FLAT, MONS_IRON_GIANT },
   { 10, 14,   10, FLAT, MONS_ANCIENT_LICH },
   { 0,0,0,FLAT,MONS_0 }
 };
@@ -1279,7 +1258,6 @@ static const pop_entry pop_water_depths[] =
   {  1,  6,   600, FLAT, MONS_WATER_ELEMENTAL },
   {  1,  6,    45, FLAT, MONS_MERFOLK_IMPALER },
   {  1,  6,    45, FLAT, MONS_MERFOLK_JAVELINEER },
-  {  1,  6,   100, FLAT, MONS_OCTOPODE_CRUSHER },
   {  1,  6,   200, FALL, MONS_NO_MONSTER },
   { 0,0,0,FLAT,MONS_0 }
 };
@@ -1388,7 +1366,7 @@ static const pop_entry pop_lava_snake[] =
   {  1,   4,  200, FLAT, MONS_LAVA_SNAKE },
   {  1,   4,  200, FLAT, MONS_SALAMANDER },
   {  0,   6,  85,  SEMI, MONS_SALAMANDER_MYSTIC },
-  {  2,   4,  55,  RISE, MONS_SALAMANDER_FIREBRAND },
+  {  2,   4,  55,  RISE, MONS_SALAMANDER_STORMCALLER },
   { 0,0,0,FLAT,MONS_0 }
 };
 
@@ -1400,7 +1378,7 @@ static const pop_entry pop_lava_depths[] =
   {  1,  6,   11, FALL, MONS_MOLTEN_GARGOYLE },
   {  1,  6,  100, FLAT, MONS_SALAMANDER },
   {  1,  8,   85, SEMI, MONS_SALAMANDER_MYSTIC },
-  {  3,  6,   55, RISE, MONS_SALAMANDER_FIREBRAND },
+  {  3,  6,   55, RISE, MONS_SALAMANDER_STORMCALLER },
   {  1,  6,  400, FLAT, MONS_NO_MONSTER },
   { 0,0,0,FLAT,MONS_0 }
 };
@@ -1410,7 +1388,7 @@ static const pop_entry pop_lava_hell[] =
   {  1,  8,   300, FALL, MONS_FIRE_ELEMENTAL },
   {  1,  6,    25, FALL, MONS_MOLTEN_GARGOYLE },
   {  1,  7,    25, FLAT, MONS_SMOKE_DEMON },
-  {  1,  7,    75, FLAT, MONS_SALAMANDER_FIREBRAND },
+  {  1,  7,    75, FLAT, MONS_SALAMANDER_STORMCALLER },
   {  1,  7,   100, FLAT, MONS_NO_MONSTER },
   { 0,0,0,FLAT,MONS_0 }
 };
