@@ -59,7 +59,6 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_DEATH_KNIGHT,
       {
-       { SPELL_HAUNT, 10, MON_SPELL_PRIEST },
        { SPELL_AGONY, 15, MON_SPELL_PRIEST },
        { SPELL_INJURY_MIRROR, 20, MON_SPELL_PRIEST },
       }
@@ -75,13 +74,13 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_HELLION,
       {
-       { SPELL_HELLFIRE_BURST, 57, MON_SPELL_DEMONIC },
+       { SPELL_CALL_DOWN_DAMNATION, 57, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_VAMPIRE,
       {
-       { SPELL_VAMPIRIC_DRAINING, 28, MON_SPELL_WIZARD },
+       { SPELL_VAMPIRIC_DRAINING, 50, MON_SPELL_WIZARD },
        { SPELL_CONFUSE, 14, MON_SPELL_WIZARD },
        { SPELL_INVISIBILITY, 14, MON_SPELL_WIZARD },
       }
@@ -93,7 +92,7 @@ static const mon_spellbook mspell_list[] =
        { SPELL_PARALYSE, 12, MON_SPELL_WIZARD },
        { SPELL_HASTE, 12, MON_SPELL_WIZARD  },
        { SPELL_INVISIBILITY, 12, MON_SPELL_WIZARD },
-       { SPELL_VAMPIRIC_DRAINING, 12, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
+       { SPELL_VAMPIRIC_DRAINING, 50, MON_SPELL_WIZARD },
       }
     },
 
@@ -102,14 +101,14 @@ static const mon_spellbook mspell_list[] =
        { SPELL_BOLT_OF_DRAINING, 10, MON_SPELL_WIZARD },
        { SPELL_SUMMON_UNDEAD, 10, MON_SPELL_WIZARD },
        { SPELL_INVISIBILITY, 20, MON_SPELL_WIZARD },
-       { SPELL_VAMPIRIC_DRAINING, 10, MON_SPELL_WIZARD },
+       { SPELL_VAMPIRIC_DRAINING, 50, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_EFREET,
       {
-       { SPELL_BOLT_OF_FIRE, 29, MON_SPELL_DEMONIC },
-       { SPELL_FIREBALL, 29, MON_SPELL_DEMONIC },
+       { SPELL_BOLT_OF_FIRE, 29, MON_SPELL_MAGICAL },
+       { SPELL_FIREBALL, 29, MON_SPELL_MAGICAL },
       }
     },
 
@@ -127,12 +126,6 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_BRAIN_WORM,
-      {
-       { SPELL_BRAIN_FEED, 55, MON_SPELL_MAGICAL },
-      }
-    },
-
     {  MST_GIANT_ORANGE_BRAIN,
       {
        { SPELL_BRAIN_FEED, 10, MON_SPELL_MAGICAL },
@@ -145,9 +138,9 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_RAKSHASA,
       {
-       { SPELL_ISKENDERUNS_MYSTIC_BLAST, 20, MON_SPELL_DEMONIC },
-       { SPELL_PHANTOM_MIRROR, 20, MON_SPELL_DEMONIC  },
-       { SPELL_BLINK, 10, MON_SPELL_DEMONIC },
+       { SPELL_ISKENDERUNS_MYSTIC_BLAST, 20, MON_SPELL_MAGICAL },
+       { SPELL_PHANTOM_MIRROR, 20, MON_SPELL_MAGICAL  },
+       { SPELL_BLINK, 10, MON_SPELL_MAGICAL },
       }
     },
 
@@ -291,38 +284,38 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_FIEND,
       {
-       { SPELL_HELLFIRE, 34, MON_SPELL_DEMONIC },
-       { SPELL_SYMBOL_OF_TORMENT, 17, MON_SPELL_DEMONIC },
+       { SPELL_HURL_DAMNATION, 34, MON_SPELL_MAGICAL },
+       { SPELL_SYMBOL_OF_TORMENT, 17, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_HELL_SENTINEL,
       {
-       { SPELL_HELLFIRE, 28, MON_SPELL_DEMONIC },
-       { SPELL_IRON_SHOT, 14, MON_SPELL_DEMONIC },
+       { SPELL_HURL_DAMNATION, 28, MON_SPELL_MAGICAL },
+       { SPELL_IRON_SHOT, 14, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_ICE_FIEND,
       {
-       { SPELL_BOLT_OF_COLD, 46, MON_SPELL_DEMONIC },
-       { SPELL_SYMBOL_OF_TORMENT, 23, MON_SPELL_DEMONIC },
+       { SPELL_BOLT_OF_COLD, 46, MON_SPELL_MAGICAL },
+       { SPELL_SYMBOL_OF_TORMENT, 23, MON_SPELL_MAGICAL },
       }
     },
 
-    {  MST_SHADOW_FIEND,
+    {  MST_TZITZIMITL,
       {
-       { SPELL_BOLT_OF_COLD, 17, MON_SPELL_DEMONIC },
-       { SPELL_BOLT_OF_DRAINING, 17, MON_SPELL_DEMONIC },
-       { SPELL_SYMBOL_OF_TORMENT, 17, MON_SPELL_DEMONIC },
-       { SPELL_DISPEL_UNDEAD, 17, MON_SPELL_DEMONIC },
+       { SPELL_BOLT_OF_COLD, 15, MON_SPELL_MAGICAL },
+       { SPELL_BOLT_OF_DRAINING, 15, MON_SPELL_MAGICAL },
+       { SPELL_SYMBOL_OF_TORMENT, 25, MON_SPELL_MAGICAL },
+       { SPELL_DISPEL_UNDEAD, 25, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_TORMENTOR,
       {
-       { SPELL_PAIN, 28, MON_SPELL_DEMONIC },
-       { SPELL_SYMBOL_OF_TORMENT, 29, MON_SPELL_DEMONIC },
+       { SPELL_PAIN, 28, MON_SPELL_MAGICAL },
+       { SPELL_SYMBOL_OF_TORMENT, 29, MON_SPELL_MAGICAL },
       }
     },
 
@@ -335,72 +328,72 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_WHITE_IMP,
       {
-       { SPELL_THROW_FROST, 52, MON_SPELL_DEMONIC },
+       { SPELL_THROW_FROST, 52, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_YNOXINUL,
       {
-       { SPELL_IRON_SHOT, 19, MON_SPELL_DEMONIC },
-       { SPELL_SUMMON_UFETUBUS, 38, MON_SPELL_DEMONIC  },
+       { SPELL_IRON_SHOT, 19, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_UFETUBUS, 38, MON_SPELL_MAGICAL  },
       }
     },
 
     {  MST_NEQOXEC,
       {
-       { SPELL_MALMUTATE, 19, MON_SPELL_DEMONIC },
-       { SPELL_BRAIN_FEED, 19, MON_SPELL_DEMONIC },
-       { SPELL_SUMMON_MINOR_DEMON, 19, MON_SPELL_DEMONIC },
+       { SPELL_MALMUTATE, 19, MON_SPELL_MAGICAL },
+       { SPELL_BRAIN_FEED, 19, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_MINOR_DEMON, 19, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_HELLWING,
       {
-       { SPELL_CIGOTUVIS_EMBRACE, 28, MON_SPELL_DEMONIC },
+       { SPELL_CIGOTUVIS_EMBRACE, 28, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_SMOKE_DEMON,
       {
-       { SPELL_STICKY_FLAME_RANGE, 19, MON_SPELL_DEMONIC },
-       { SPELL_STEAM_BALL, 19, MON_SPELL_DEMONIC },
-       { SPELL_SMITING, 19, MON_SPELL_DEMONIC },
+       { SPELL_STICKY_FLAME_RANGE, 19, MON_SPELL_MAGICAL },
+       { SPELL_STEAM_BALL, 19, MON_SPELL_MAGICAL },
+       { SPELL_SMITING, 19, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_CACODEMON,
       {
-       { SPELL_ENERGY_BOLT, 13, MON_SPELL_DEMONIC },
-       { SPELL_SLOW, 13, MON_SPELL_DEMONIC },
-       { SPELL_CONFUSE, 13, MON_SPELL_DEMONIC },
-       { SPELL_MALMUTATE, 13, MON_SPELL_DEMONIC },
-       { SPELL_DIG, 13, MON_SPELL_DEMONIC },
+       { SPELL_ENERGY_BOLT, 13, MON_SPELL_MAGICAL },
+       { SPELL_SLOW, 13, MON_SPELL_MAGICAL },
+       { SPELL_CONFUSE, 13, MON_SPELL_MAGICAL },
+       { SPELL_MALMUTATE, 13, MON_SPELL_MAGICAL },
+       { SPELL_DIG, 13, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_GREEN_DEATH,
       {
-       { SPELL_POISON_ARROW, 21, MON_SPELL_DEMONIC },
-       { SPELL_POISONOUS_CLOUD, 21, MON_SPELL_DEMONIC },
-       { SPELL_VENOM_BOLT, 21, MON_SPELL_DEMONIC },
+       { SPELL_POISON_ARROW, 21, MON_SPELL_MAGICAL },
+       { SPELL_POISONOUS_CLOUD, 21, MON_SPELL_MAGICAL },
+       { SPELL_VENOM_BOLT, 21, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_BALRUG,
       {
-       { SPELL_BOLT_OF_FIRE, 16, MON_SPELL_DEMONIC },
-       { SPELL_FIREBALL, 16, MON_SPELL_DEMONIC },
-       { SPELL_STICKY_FLAME_RANGE, 16, MON_SPELL_DEMONIC },
-       { SPELL_SMITING, 16, MON_SPELL_DEMONIC },
+       { SPELL_BOLT_OF_FIRE, 16, MON_SPELL_MAGICAL },
+       { SPELL_FIREBALL, 16, MON_SPELL_MAGICAL },
+       { SPELL_STICKY_FLAME_RANGE, 16, MON_SPELL_MAGICAL },
+       { SPELL_SMITING, 16, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_BLIZZARD_DEMON,
       {
-       { SPELL_LIGHTNING_BOLT, 16, MON_SPELL_DEMONIC },
-       { SPELL_FREEZING_CLOUD, 16, MON_SPELL_DEMONIC },
-       { SPELL_AIRSTRIKE, 16, MON_SPELL_DEMONIC },
-       { SPELL_BOLT_OF_COLD, 16, MON_SPELL_DEMONIC },
+       { SPELL_LIGHTNING_BOLT, 16, MON_SPELL_MAGICAL },
+       { SPELL_FREEZING_CLOUD, 16, MON_SPELL_MAGICAL },
+       { SPELL_AIRSTRIKE, 16, MON_SPELL_MAGICAL },
+       { SPELL_BOLT_OF_COLD, 16, MON_SPELL_MAGICAL },
       }
     },
 
@@ -423,37 +416,12 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_DEEP_ELF_SUMMONER,
-      {
-       { SPELL_BLINK, 15, MON_SPELL_WIZARD },
-       { SPELL_SUMMON_VERMIN, 45, MON_SPELL_WIZARD  },
-      }
-    },
-
-    {  MST_DEEP_ELF_CONJURER,
-      {
-       { SPELL_BOLT_OF_FIRE, 15, MON_SPELL_WIZARD },
-       { SPELL_BOLT_OF_COLD, 15, MON_SPELL_WIZARD },
-       { SPELL_LIGHTNING_BOLT, 15, MON_SPELL_WIZARD },
-       { SPELL_BOLT_OF_DRAINING, 15, MON_SPELL_WIZARD },
-      }
-    },
-
-    {  MST_DEEP_ELF_PRIEST,
-      {
-       { SPELL_PAIN, 14, MON_SPELL_PRIEST },
-       { SPELL_MALIGN_OFFERING, 14, MON_SPELL_PRIEST },
-       { SPELL_SMITING, 14, MON_SPELL_PRIEST },
-       { SPELL_TWISTED_RESURRECTION, 14, MON_SPELL_PRIEST },
-      }
-    },
-
     {  MST_DEEP_ELF_HIGH_PRIEST,
       {
-       { SPELL_SUMMON_DEMON, 12, MON_SPELL_PRIEST },
-       { SPELL_HELLFIRE_BURST, 12, MON_SPELL_PRIEST },
-       { SPELL_MALIGN_OFFERING, 12, MON_SPELL_PRIEST },
-       { SPELL_SMITING, 12, MON_SPELL_PRIEST },
+       { SPELL_AURA_OF_BRILLIANCE, 25, MON_SPELL_PRIEST },
+       { SPELL_CALL_DOWN_DAMNATION, 12, MON_SPELL_PRIEST },
+       { SPELL_MALIGN_OFFERING, 18, MON_SPELL_PRIEST },
+       { SPELL_SMITING, 18, MON_SPELL_PRIEST },
        { SPELL_TWISTED_RESURRECTION, 12, MON_SPELL_PRIEST },
       }
     },
@@ -466,7 +434,7 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_DEEP_ELF_ANNIHILATOR,
+    {  MST_ANNIHILATOR,
       {
        { SPELL_LIGHTNING_BOLT, 11, MON_SPELL_WIZARD },
        { SPELL_LEHUDIBS_CRYSTAL_SPEAR, 11, MON_SPELL_WIZARD },
@@ -478,11 +446,10 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_DEEP_ELF_SORCERER,
       {
-       { SPELL_CORROSIVE_BOLT, 11, MON_SPELL_WIZARD },
+       { SPELL_CORROSIVE_BOLT, 18, MON_SPELL_WIZARD },
        { SPELL_BANISHMENT, 11, MON_SPELL_WIZARD },
        { SPELL_HASTE, 22, MON_SPELL_WIZARD },
-       { SPELL_SUMMON_DEMON, 11, MON_SPELL_WIZARD },
-       { SPELL_HELLFIRE, 11, MON_SPELL_WIZARD },
+       { SPELL_HURL_DAMNATION, 11, MON_SPELL_WIZARD },
       }
     },
 
@@ -541,13 +508,13 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_ANGEL,
       {
-       { SPELL_MINOR_HEALING, 62, MON_SPELL_DEMONIC },
+       { SPELL_MINOR_HEALING, 62, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_DAEVA,
       {
-       { SPELL_SMITING, 64, MON_SPELL_DEMONIC },
+       { SPELL_SMITING, 64, MON_SPELL_MAGICAL },
       }
     },
 
@@ -593,13 +560,13 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_SHADOW_IMP,
       {
-       { SPELL_PAIN, 17, MON_SPELL_DEMONIC },
+       { SPELL_PAIN, 17, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_HELL_HOG,
       {
-       { SPELL_STICKY_FLAME, 61, MON_SPELL_NATURAL },
+       { SPELL_FIREBALL, 60, MON_SPELL_NATURAL | MON_SPELL_BREATH },
       }
     },
 
@@ -620,7 +587,7 @@ static const mon_spellbook mspell_list[] =
       {
        { SPELL_SERPENT_OF_HELL_BREATH, 35, MON_SPELL_NATURAL | MON_SPELL_BREATH
                                             | MON_SPELL_NOISY },
-       { SPELL_SUMMON_DRAGON, 35, MON_SPELL_DEMONIC },
+       { SPELL_SUMMON_DRAGON, 35, MON_SPELL_MAGICAL },
       }
     },
 
@@ -670,11 +637,11 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_AZRAEL,
       {
-       { SPELL_BOLT_OF_FIRE, 13, MON_SPELL_DEMONIC },
-       { SPELL_STICKY_FLAME_RANGE, 13, MON_SPELL_DEMONIC },
-       { SPELL_FIREBALL, 13, MON_SPELL_DEMONIC },
-       { SPELL_HELLFIRE, 13, MON_SPELL_DEMONIC },
-       { SPELL_HELLFIRE_BURST, 13, MON_SPELL_DEMONIC | MON_SPELL_EMERGENCY },
+       { SPELL_BOLT_OF_FIRE, 13, MON_SPELL_MAGICAL },
+       { SPELL_STICKY_FLAME_RANGE, 13, MON_SPELL_MAGICAL },
+       { SPELL_FIREBALL, 13, MON_SPELL_MAGICAL },
+       { SPELL_HURL_DAMNATION, 13, MON_SPELL_MAGICAL },
+       { SPELL_CALL_DOWN_DAMNATION, 13, MON_SPELL_MAGICAL | MON_SPELL_EMERGENCY },
       }
     },
 
@@ -683,14 +650,15 @@ static const mon_spellbook mspell_list[] =
        { SPELL_BOLT_OF_FIRE, 13, MON_SPELL_WIZARD },
        { SPELL_BOLT_OF_MAGMA, 13, MON_SPELL_WIZARD },
        { SPELL_FIREBALL, 13, MON_SPELL_WIZARD },
-       { SPELL_HELLFIRE, 13, MON_SPELL_WIZARD },
-       { SPELL_HELLFIRE_BURST, 13, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
+       { SPELL_HURL_DAMNATION, 13, MON_SPELL_WIZARD },
+       { SPELL_CALL_DOWN_DAMNATION, 13, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
       }
     },
 
     {  MST_DRAC_CALLER,
       {
-       { SPELL_SUMMON_DRAKES, 66, MON_SPELL_WIZARD },
+       { SPELL_SUMMON_DRAKES, 55, MON_SPELL_WIZARD },
+       { SPELL_SUMMON_DRAGON, 10, MON_SPELL_WIZARD },
       }
     },
 
@@ -738,7 +706,7 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_ALLIGATOR,
       {
-       { SPELL_SWIFTNESS, 62, MON_SPELL_NATURAL },
+       { SPELL_SPRINT, 31, MON_SPELL_NATURAL },
       }
     },
 
@@ -850,7 +818,6 @@ static const mon_spellbook mspell_list[] =
        { SPELL_SUMMON_ICE_BEAST, 20, MON_SPELL_WIZARD },
        { SPELL_BLINK, 10, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
        { SPELL_OZOCUBUS_ARMOUR, 10, MON_SPELL_WIZARD },
-       { SPELL_CONDENSATION_SHIELD, 10, MON_SPELL_WIZARD },
       }
     },
 
@@ -858,7 +825,7 @@ static const mon_spellbook mspell_list[] =
       {
        { SPELL_AIRSTRIKE, 23, MON_SPELL_WIZARD },
        { SPELL_SLOW, 12, MON_SPELL_WIZARD },
-       { SPELL_SWIFTNESS, 12, MON_SPELL_WIZARD },
+       { SPELL_SPRINT, 12, MON_SPELL_WIZARD },
        { SPELL_SUMMON_SMALL_MAMMAL, 12, MON_SPELL_WIZARD },
        { SPELL_CANTRIP, 12, MON_SPELL_WIZARD },
       }
@@ -867,7 +834,7 @@ static const mon_spellbook mspell_list[] =
     {  MST_MAURICE,
       {
        { SPELL_INVISIBILITY, 14, MON_SPELL_WIZARD  },
-       { SPELL_SWIFTNESS, 14, MON_SPELL_WIZARD },
+       { SPELL_SPRINT, 14, MON_SPELL_WIZARD },
        { SPELL_BLINK, 14, MON_SPELL_WIZARD },
        { SPELL_TELEPORT_SELF, 14, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
       }
@@ -876,79 +843,83 @@ static const mon_spellbook mspell_list[] =
     // demon lords
     {  MST_GERYON,
       {
-       { SPELL_SUMMON_HELL_BEAST, 65, MON_SPELL_DEMONIC | MON_SPELL_NO_SILENT },
+       { SPELL_SUMMON_HELL_BEAST, 65, MON_SPELL_MAGICAL | MON_SPELL_NO_SILENT },
       }
     },
 
     {  MST_DISPATER,
       {
-       { SPELL_SUMMON_GREATER_DEMON, 26, MON_SPELL_DEMONIC },
-       { SPELL_LEHUDIBS_CRYSTAL_SPEAR, 13, MON_SPELL_DEMONIC },
-       { SPELL_IRON_SHOT, 13, MON_SPELL_DEMONIC },
-       { SPELL_HELLFIRE, 13, MON_SPELL_DEMONIC },
+       { SPELL_SUMMON_GREATER_DEMON, 26, MON_SPELL_MAGICAL },
+       { SPELL_LEHUDIBS_CRYSTAL_SPEAR, 13, MON_SPELL_MAGICAL },
+       { SPELL_IRON_SHOT, 13, MON_SPELL_MAGICAL },
+       { SPELL_HURL_DAMNATION, 13, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_ASMODEUS,
       {
-       { SPELL_BOLT_OF_FIRE, 22, MON_SPELL_DEMONIC },
-       { SPELL_HELLFIRE, 22, MON_SPELL_DEMONIC },
-       { SPELL_FIRE_SUMMON, 22, MON_SPELL_DEMONIC },
+       { SPELL_BOLT_OF_FIRE, 22, MON_SPELL_MAGICAL },
+       { SPELL_HURL_DAMNATION, 22, MON_SPELL_MAGICAL },
+       { SPELL_FIRE_SUMMON, 22, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_ERESHKIGAL,
       {
-       { SPELL_BOLT_OF_COLD, 11, MON_SPELL_DEMONIC },
-       { SPELL_SILENCE, 11, MON_SPELL_DEMONIC },
-       { SPELL_SUMMON_GREATER_DEMON, 11, MON_SPELL_DEMONIC },
-       { SPELL_SYMBOL_OF_TORMENT, 11, MON_SPELL_DEMONIC },
-       { SPELL_PARALYSE, 11, MON_SPELL_DEMONIC },
-       { SPELL_MAJOR_HEALING, 11, MON_SPELL_DEMONIC | MON_SPELL_EMERGENCY },
+       { SPELL_BOLT_OF_COLD, 11, MON_SPELL_MAGICAL },
+       { SPELL_SILENCE, 11, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_GREATER_DEMON, 11, MON_SPELL_MAGICAL },
+       { SPELL_SYMBOL_OF_TORMENT, 11, MON_SPELL_MAGICAL },
+       { SPELL_PARALYSE, 11, MON_SPELL_MAGICAL },
+       { SPELL_MAJOR_HEALING, 11, MON_SPELL_MAGICAL | MON_SPELL_EMERGENCY },
       }
     },
 
     {  MST_ANTAEUS,
       {
-       { SPELL_LIGHTNING_BOLT, 24, MON_SPELL_DEMONIC },
-       { SPELL_FLASH_FREEZE, 48, MON_SPELL_DEMONIC },
+       { SPELL_LIGHTNING_BOLT, 24, MON_SPELL_MAGICAL },
+       { SPELL_FLASH_FREEZE, 48, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_MNOLEG,
       {
-       { SPELL_SUMMON_EYEBALLS, 13, MON_SPELL_DEMONIC },
-       { SPELL_MALIGN_GATEWAY, 27, MON_SPELL_DEMONIC },
-       { SPELL_SUMMON_HORRIBLE_THINGS, 27, MON_SPELL_DEMONIC },
+       { SPELL_DIG, 13, MON_SPELL_MAGICAL },
+       { SPELL_RANDOM_BOLT, 13, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_EYEBALLS, 13, MON_SPELL_MAGICAL },
+       { SPELL_MALIGN_GATEWAY, 27, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_HORRIBLE_THINGS, 27, MON_SPELL_MAGICAL },
+       { SPELL_CALL_OF_CHAOS, 27, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_LOM_LOBON,
       {
-       { SPELL_GLACIATE, 30, MON_SPELL_DEMONIC },
-       { SPELL_CONJURE_BALL_LIGHTNING, 30, MON_SPELL_DEMONIC },
-       { SPELL_MAJOR_HEALING, 30, MON_SPELL_DEMONIC },
-       { SPELL_TORNADO, 60, MON_SPELL_DEMONIC },
-       { SPELL_BLINK_RANGE, 30, MON_SPELL_DEMONIC },
+       { SPELL_GLACIATE, 30, MON_SPELL_MAGICAL },
+       { SPELL_CONJURE_BALL_LIGHTNING, 30, MON_SPELL_MAGICAL },
+       { SPELL_MAJOR_HEALING, 30, MON_SPELL_MAGICAL },
+       { SPELL_TORNADO, 60, MON_SPELL_MAGICAL },
+       { SPELL_BLINK_RANGE, 30, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_CEREBOV,
       {
-       { SPELL_FIRE_STORM, 11, MON_SPELL_DEMONIC },
-       { SPELL_IRON_SHOT, 11, MON_SPELL_DEMONIC },
-       { SPELL_HASTE, 36, MON_SPELL_DEMONIC  },
-       { SPELL_SUMMON_GREATER_DEMON, 11, MON_SPELL_DEMONIC },
+       { SPELL_FIRE_STORM, 11, MON_SPELL_MAGICAL },
+       { SPELL_IRON_SHOT, 11, MON_SPELL_MAGICAL },
+       { SPELL_HASTE, 36, MON_SPELL_MAGICAL  },
+       { SPELL_SUMMON_GREATER_DEMON, 11, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_GLOORX_VLOQ,
       {
-       { SPELL_POISON_ARROW, 20, MON_SPELL_DEMONIC },
-       { SPELL_MIASMA_BREATH, 20, MON_SPELL_DEMONIC },
-       { SPELL_SYMBOL_OF_TORMENT, 20, MON_SPELL_DEMONIC },
-       { SPELL_BOLT_OF_DRAINING, 20, MON_SPELL_DEMONIC },
-       { SPELL_DISPEL_UNDEAD, 20, MON_SPELL_DEMONIC },
+       { SPELL_POISON_ARROW, 20, MON_SPELL_MAGICAL },
+       { SPELL_MIASMA_BREATH, 20, MON_SPELL_MAGICAL },
+       { SPELL_SYMBOL_OF_TORMENT, 20, MON_SPELL_MAGICAL },
+       { SPELL_DISPEL_UNDEAD, 20, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_EXECUTIONERS, 40, MON_SPELL_MAGICAL },
+       { SPELL_BLACK_MARK, 20, MON_SPELL_MAGICAL },
       }
     },
 
@@ -987,16 +958,16 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_EXECUTIONER,
       {
-       { SPELL_PAIN, 21, MON_SPELL_DEMONIC },
-       { SPELL_HASTE, 41, MON_SPELL_DEMONIC },
+       { SPELL_PAIN, 21, MON_SPELL_MAGICAL },
+       { SPELL_HASTE, 41, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_IGNACIO,
       {
-       { SPELL_AGONY, 17, MON_SPELL_DEMONIC },
-       { SPELL_PAIN, 17, MON_SPELL_DEMONIC },
-       { SPELL_HASTE, 34, MON_SPELL_DEMONIC },
+       { SPELL_AGONY, 17, MON_SPELL_MAGICAL },
+       { SPELL_PAIN, 17, MON_SPELL_MAGICAL },
+       { SPELL_HASTE, 34, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1009,11 +980,11 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_MARA,
       {
-       { SPELL_BLINK, 29, MON_SPELL_DEMONIC },
-       { SPELL_BOLT_OF_FIRE, 14, MON_SPELL_DEMONIC },
-       { SPELL_FAKE_MARA_SUMMON, 14, MON_SPELL_DEMONIC  },
-       { SPELL_SUMMON_ILLUSION, 14, MON_SPELL_DEMONIC },
-       { SPELL_PAIN, 14, MON_SPELL_DEMONIC },
+       { SPELL_BLINK, 29, MON_SPELL_MAGICAL },
+       { SPELL_BOLT_OF_FIRE, 14, MON_SPELL_MAGICAL },
+       { SPELL_FAKE_MARA_SUMMON, 14, MON_SPELL_MAGICAL  },
+       { SPELL_SUMMON_ILLUSION, 14, MON_SPELL_MAGICAL },
+       { SPELL_PAIN, 14, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1081,9 +1052,9 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_GRINDER,
       {
-       { SPELL_PAIN, 19, MON_SPELL_DEMONIC },
-       { SPELL_PARALYSE, 19, MON_SPELL_DEMONIC },
-       { SPELL_BLINK, 19, MON_SPELL_DEMONIC },
+       { SPELL_PAIN, 19, MON_SPELL_MAGICAL },
+       { SPELL_PARALYSE, 19, MON_SPELL_MAGICAL },
+       { SPELL_BLINK, 19, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1097,8 +1068,8 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_IRON_GIANT,
       {
-       { SPELL_IRON_SHOT, 36, MON_SPELL_MAGICAL },
-       { SPELL_IRON_ELEMENTALS, 36, MON_SPELL_MAGICAL },
+       { SPELL_IRON_SHOT, 40, MON_SPELL_WIZARD },
+       { SPELL_THROW, 80, MON_SPELL_NATURAL },
       }
     },
 
@@ -1141,8 +1112,8 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_OPHAN,
       {
-       { SPELL_BOLT_OF_FIRE, 32, MON_SPELL_DEMONIC },
-       { SPELL_HOLY_FLAMES, 32, MON_SPELL_DEMONIC },
+       { SPELL_BOLT_OF_FIRE, 32, MON_SPELL_MAGICAL },
+       { SPELL_HOLY_FLAMES, 32, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1158,7 +1129,7 @@ static const mon_spellbook mspell_list[] =
        { SPELL_LEHUDIBS_CRYSTAL_SPEAR, 17, MON_SPELL_WIZARD },
        { SPELL_MESMERISE, 17, MON_SPELL_WIZARD },
        { SPELL_BLINK_CLOSE, 17, MON_SPELL_WIZARD },
-       { SPELL_VAMPIRIC_DRAINING, 17, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
+       { SPELL_VAMPIRIC_DRAINING, 50, MON_SPELL_WIZARD },
       }
     },
 
@@ -1183,8 +1154,8 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_SHADOW_DEMON,
       {
-       { SPELL_SHADOW_CREATURES, 30, MON_SPELL_DEMONIC },
-       { SPELL_SUMMON_DEMON, 30, MON_SPELL_DEMONIC },
+       { SPELL_SHADOW_CREATURES, 30, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_DEMON, 30, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1211,24 +1182,23 @@ static const mon_spellbook mspell_list[] =
        { SPELL_SUMMON_MINOR_DEMON, 14, MON_SPELL_WIZARD },
        { SPELL_SUMMON_DEMON, 14, MON_SPELL_WIZARD },
        { SPELL_HASTE, 14, MON_SPELL_WIZARD },
-       { SPELL_HELLFIRE, 14, MON_SPELL_WIZARD },
+       { SPELL_HURL_DAMNATION, 14, MON_SPELL_WIZARD },
        { SPELL_BLINK_AWAY, 14, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_CLOUD_MAGE,
       {
-       { SPELL_MEPHITIC_CLOUD, 12, MON_SPELL_WIZARD },
-       { SPELL_FREEZING_CLOUD, 12, MON_SPELL_WIZARD },
-       { SPELL_POISONOUS_CLOUD, 12, MON_SPELL_WIZARD },
-       { SPELL_AIRSTRIKE, 12, MON_SPELL_WIZARD },
-       { SPELL_BLINK_RANGE, 23, MON_SPELL_WIZARD },
+       { SPELL_CLOUD_CONE, 40, MON_SPELL_WIZARD },
+       { SPELL_AIRSTRIKE, 30, MON_SPELL_WIZARD },
+       { SPELL_CONTROL_WINDS, 30, MON_SPELL_WIZARD },
+       { SPELL_BLINK_RANGE, 20, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_SOUL_EATER,
       {
-       { SPELL_DRAIN_LIFE, 30, MON_SPELL_DEMONIC },
+       { SPELL_DRAIN_LIFE, 30, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1259,7 +1229,6 @@ static const mon_spellbook mspell_list[] =
        { SPELL_MAGIC_DART, 13, MON_SPELL_WIZARD },
        { SPELL_SLOW, 13, MON_SPELL_WIZARD },
        { SPELL_CALL_IMP, 13, MON_SPELL_WIZARD },
-       { SPELL_CONJURE_FLAME, 13, MON_SPELL_WIZARD },
       }
     },
 
@@ -1295,7 +1264,7 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_VAULT_SENTINEL,
       {
-       { SPELL_SIGNAL_HORN, 50, MON_SPELL_NATURAL | MON_SPELL_NO_SILENT
+       { SPELL_WARNING_CRY, 50, MON_SPELL_NATURAL | MON_SPELL_NO_SILENT
                                 | MON_SPELL_BREATH },
        { SPELL_SENTINEL_MARK, 58, MON_SPELL_WIZARD },
       }
@@ -1317,9 +1286,9 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_TEST_SPAWNER,
       {
-       { SPELL_SHADOW_CREATURES, 100, MON_SPELL_DEMONIC },
-       { SPELL_PLANEREND, 67, MON_SPELL_DEMONIC },
-       { SPELL_PHANTOM_MIRROR, 33, MON_SPELL_DEMONIC },
+       { SPELL_SHADOW_CREATURES, 100, MON_SPELL_MAGICAL },
+       { SPELL_PLANEREND, 67, MON_SPELL_MAGICAL },
+       { SPELL_PHANTOM_MIRROR, 33, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1340,13 +1309,6 @@ static const mon_spellbook mspell_list[] =
     },
 
     {  MST_ANCIENT_CHAMPION_III,
-      {
-       { SPELL_VENOM_BOLT, 21, MON_SPELL_WIZARD },
-       { SPELL_HAUNT, 21, MON_SPELL_WIZARD },
-      }
-    },
-
-    {  MST_ANCIENT_CHAMPION_IV,
       {
        { SPELL_ISKENDERUNS_MYSTIC_BLAST, 21, MON_SPELL_WIZARD },
        { SPELL_SLOW, 21, MON_SPELL_WIZARD },
@@ -1489,56 +1451,61 @@ static const mon_spellbook mspell_list[] =
     {  MST_DRACONIAN_ZEALOT,
       {
        { SPELL_SUMMON_DEMON, 11, MON_SPELL_PRIEST },
-       { SPELL_HELLFIRE_BURST, 11, MON_SPELL_PRIEST },
+       { SPELL_CALL_DOWN_DAMNATION, 11, MON_SPELL_PRIEST },
        { SPELL_SMITING, 11, MON_SPELL_PRIEST },
        { SPELL_MINOR_HEALING, 22, MON_SPELL_PRIEST },
       }
     },
 
-    // deep elf ie
     {  MST_DEEP_ELF_MAGE_I,
       {
-       { SPELL_FREEZE, 22, MON_SPELL_WIZARD },
-       { SPELL_THROW_ICICLE, 22, MON_SPELL_WIZARD },
-       { SPELL_SUMMON_ICE_BEAST, 11, MON_SPELL_WIZARD },
+       { SPELL_BOLT_OF_FIRE, 15, MON_SPELL_WIZARD },
+       { SPELL_STICKY_FLAME_RANGE, 15, MON_SPELL_WIZARD },
+       { SPELL_FIRE_ELEMENTALS, 15, MON_SPELL_WIZARD },
+       { SPELL_BLINK, 15, MON_SPELL_WIZARD },
       }
     },
 
-    // deep elf ee
     {  MST_DEEP_ELF_MAGE_II,
       {
-       { SPELL_BOLT_OF_MAGMA, 19, MON_SPELL_WIZARD },
-       { SPELL_STONE_ARROW, 37, MON_SPELL_WIZARD },
+       { SPELL_BOLT_OF_COLD, 15, MON_SPELL_WIZARD },
+       { SPELL_THROW_ICICLE, 15, MON_SPELL_WIZARD },
+       { SPELL_SUMMON_ICE_BEAST, 15, MON_SPELL_WIZARD },
+       { SPELL_BLINK, 15, MON_SPELL_WIZARD },
       }
     },
 
-    // deep elf wz
     {  MST_DEEP_ELF_MAGE_III,
       {
-       { SPELL_ISKENDERUNS_MYSTIC_BLAST, 11, MON_SPELL_WIZARD },
-       { SPELL_SLOW, 11, MON_SPELL_WIZARD },
-       { SPELL_VENOM_BOLT, 11, MON_SPELL_WIZARD },
-       { SPELL_BLINK, 22, MON_SPELL_WIZARD },
+       { SPELL_LIGHTNING_BOLT, 40, MON_SPELL_WIZARD },
+       { SPELL_BLINK, 20, MON_SPELL_WIZARD },
       }
     },
 
-    // deep elf --fe
     {  MST_DEEP_ELF_MAGE_IV,
       {
-       { SPELL_FLAME_TONGUE, 11, MON_SPELL_WIZARD },
-       { SPELL_STICKY_FLAME_RANGE, 11, MON_SPELL_WIZARD },
-       { SPELL_FIREBALL, 22, MON_SPELL_WIZARD },
-       { SPELL_THROW_FLAME, 11, MON_SPELL_WIZARD },
+       { SPELL_BOLT_OF_DRAINING, 15, MON_SPELL_WIZARD },
+       { SPELL_SUMMON_DEMON, 15, MON_SPELL_WIZARD },
+       { SPELL_SUMMON_VERMIN, 15, MON_SPELL_WIZARD },
+       { SPELL_BLINK, 15, MON_SPELL_WIZARD },
       }
     },
 
-    // deep elf cj
     {  MST_DEEP_ELF_MAGE_V,
       {
-       { SPELL_MAGIC_DART, 11, MON_SPELL_WIZARD },
-       { SPELL_FORCE_LANCE, 11, MON_SPELL_WIZARD },
-       { SPELL_BATTLESPHERE, 22, MON_SPELL_WIZARD  },
-       { SPELL_ISKENDERUNS_MYSTIC_BLAST, 11, MON_SPELL_WIZARD },
+       { SPELL_BOLT_OF_MAGMA, 15, MON_SPELL_WIZARD },
+       { SPELL_STONE_ARROW, 15, MON_SPELL_WIZARD },
+       { SPELL_EARTH_ELEMENTALS, 15, MON_SPELL_WIZARD },
+       { SPELL_BLINK, 15, MON_SPELL_WIZARD },
+      }
+    },
+
+    {  MST_DEEP_ELF_MAGE_VI,
+      {
+       { SPELL_MAGIC_DART, 12, MON_SPELL_WIZARD },
+       { SPELL_FORCE_LANCE, 12, MON_SPELL_WIZARD },
+       { SPELL_BATTLESPHERE, 24, MON_SPELL_WIZARD  },
+       { SPELL_ISKENDERUNS_MYSTIC_BLAST, 12, MON_SPELL_WIZARD },
       }
     },
 
@@ -1552,7 +1519,13 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_RAIJU,
       {
-       { SPELL_BLINKBOLT, 57, MON_SPELL_MAGICAL },
+       { SPELL_BLINKBOLT, 40, MON_SPELL_MAGICAL },
+      }
+    },
+
+    {  MST_SPARK_WASP,
+      {
+       { SPELL_BLINKBOLT, 40, MON_SPELL_MAGICAL | MON_SPELL_LONG_RANGE },
       }
     },
 
@@ -1629,7 +1602,6 @@ static const mon_spellbook mspell_list[] =
        { SPELL_ISKENDERUNS_MYSTIC_BLAST, 12, MON_SPELL_WIZARD },
        { SPELL_BOLT_OF_MAGMA, 12, MON_SPELL_WIZARD },
        { SPELL_HASTE_OTHER, 24, MON_SPELL_WIZARD },
-       { SPELL_IGNITE_POISON_SINGLE, 12, MON_SPELL_WIZARD },
       }
     },
 
@@ -1654,8 +1626,8 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_DEMONSPAWN_CHAOS_CHAMPION,
       {
-       { SPELL_RANDOM_BOLT, 16, MON_SPELL_PRIEST },
-       { SPELL_CHAOTIC_MIRROR, 16, MON_SPELL_PRIEST },
+       { SPELL_RANDOM_BOLT, 32, MON_SPELL_PRIEST },
+       { SPELL_CALL_OF_CHAOS, 32, MON_SPELL_PRIEST },
       }
     },
 
@@ -1714,13 +1686,6 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_OCTOPODE_CRUSHER,
-      {
-       { SPELL_IRON_SHOT, 26, MON_SPELL_WIZARD },
-       { SPELL_TENTACLE_THROW, 80, MON_SPELL_NATURAL },
-      }
-    },
-
     {  MST_JOSEPHINE,
       {
        { SPELL_GHOSTLY_FIREBALL, 24, MON_SPELL_WIZARD },
@@ -1731,8 +1696,8 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_OBSIDIAN_STATUE,
       {
-       { SPELL_SUMMON_MINOR_DEMON, 50, MON_SPELL_DEMONIC },
-       { SPELL_SUMMON_DEMON, 50, MON_SPELL_DEMONIC },
+       { SPELL_SUMMON_MINOR_DEMON, 50, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_DEMON, 50, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1888,16 +1853,6 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_DRACONIAN_ANNIHILATOR,
-      {
-       { SPELL_LIGHTNING_BOLT, 11, MON_SPELL_WIZARD },
-       { SPELL_LEHUDIBS_CRYSTAL_SPEAR, 11, MON_SPELL_WIZARD },
-       { SPELL_BLINK, 22, MON_SPELL_WIZARD },
-       { SPELL_IRON_SHOT, 11, MON_SPELL_WIZARD },
-       { SPELL_POISON_ARROW, 11, MON_SPELL_WIZARD },
-      }
-    },
-
     {  MST_BATTLECRY,
       {
        { SPELL_BATTLECRY, 100, MON_SPELL_NATURAL | MON_SPELL_INSTANT
@@ -1905,6 +1860,13 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_ORC_KNIGHT,
+      {
+       { SPELL_BATTLECRY, 50, MON_SPELL_NATURAL | MON_SPELL_INSTANT
+                              | MON_SPELL_NOISY | MON_SPELL_NO_SILENT },
+      }
+    },
+
     {  MST_ROBIN,
       {
         { SPELL_BATTLECRY, 50, MON_SPELL_NATURAL | MON_SPELL_INSTANT
@@ -1990,7 +1952,7 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_GIANT_EYEBALL,
       {
-       { SPELL_PARALYSIS_GAZE, 100, MON_SPELL_MAGICAL | MON_SPELL_INSTANT },
+       { SPELL_PARALYSIS_GAZE, 80, MON_SPELL_MAGICAL | MON_SPELL_INSTANT },
       }
     },
 
@@ -2015,7 +1977,7 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_ANUBIS_GUARD,
       {
-       { SPELL_HUNTING_CRY, 56, MON_SPELL_NATURAL | MON_SPELL_NOISY
+       { SPELL_WARNING_CRY, 56, MON_SPELL_NATURAL | MON_SPELL_NOISY
                                 | MON_SPELL_NO_SILENT | MON_SPELL_BREATH },
        { SPELL_BOLT_OF_DRAINING, 56, MON_SPELL_NATURAL | MON_SPELL_BREATH },
        { SPELL_DISPEL_UNDEAD, 44, MON_SPELL_PRIEST },
@@ -2024,34 +1986,23 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_DEEP_ELF_KNIGHT_I,
       {
-       { SPELL_DAZZLING_SPRAY, 24, MON_SPELL_WIZARD },
-       { SPELL_CONJURE_FLAME, 12, MON_SPELL_WIZARD },
+       { SPELL_THROW_ICICLE, 24, MON_SPELL_WIZARD },
+       { SPELL_HASTE, 12, MON_SPELL_WIZARD },
        { SPELL_INVISIBILITY, 12, MON_SPELL_WIZARD },
-       { SPELL_SWIFTNESS, 12, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_DEEP_ELF_KNIGHT_II,
-      {
-       { SPELL_THROW_ICICLE, 24, MON_SPELL_WIZARD },
-       { SPELL_HASTE, 12, MON_SPELL_WIZARD },
-       { SPELL_INVISIBILITY, 12, MON_SPELL_WIZARD },
-       { SPELL_CONDENSATION_SHIELD, 12, MON_SPELL_WIZARD },
-      }
-    },
-
-    {  MST_DEEP_ELF_KNIGHT_III,
       {
        { SPELL_STONE_ARROW, 24, MON_SPELL_WIZARD },
        { SPELL_ISKENDERUNS_MYSTIC_BLAST, 12, MON_SPELL_WIZARD },
        { SPELL_HASTE, 12, MON_SPELL_WIZARD },
-       { SPELL_SHROUD_OF_GOLUBRIA, 12, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_SERAPH,
       {
-       { SPELL_HUNTING_CRY, 50, MON_SPELL_NATURAL | MON_SPELL_NOISY
+       { SPELL_WARNING_CRY, 50, MON_SPELL_NATURAL | MON_SPELL_NOISY
                                 | MON_SPELL_NO_SILENT | MON_SPELL_BREATH },
        { SPELL_SUMMON_HOLIES, 50, MON_SPELL_PRIEST },
        { SPELL_INJURY_BOND, 50, MON_SPELL_PRIEST },
@@ -2076,15 +2027,13 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_SALAMANDER_STORMCALLER,
       {
-       { SPELL_CONJURE_FLAME, 30, MON_SPELL_WIZARD },
-       { SPELL_STICKY_FLAME_RANGE, 45, MON_SPELL_WIZARD },
-       { SPELL_CHANT_FIRE_STORM, 30, MON_SPELL_WIZARD },
+       { SPELL_FIRE_STORM, 35, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_ENTROPY_WEAVER,
       {
-       { SPELL_CHANT_WORD_OF_ENTROPY, 50, MON_SPELL_WIZARD },
+       { SPELL_ENTROPIC_WEAVE, 50, MON_SPELL_WIZARD },
       }
     },
 
@@ -2094,4 +2043,102 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_DEATHCAP,
+      {
+       { SPELL_DRAIN_LIFE, 30, MON_SPELL_MAGICAL },
+      }
+    },
+
+    {  MST_DOOM_HOUND,
+      {
+       { SPELL_DOOM_HOWL, 30, MON_SPELL_NATURAL },
+      }
+    },
+
+    {  MST_DEEP_ELF_ELEMENTALIST,
+      {
+       { SPELL_AWAKEN_EARTH, 44, MON_SPELL_WIZARD },
+       { SPELL_FIREBALL, 11, MON_SPELL_WIZARD },
+       { SPELL_FREEZING_CLOUD, 11, MON_SPELL_WIZARD },
+       { SPELL_REPEL_MISSILES, 11, MON_SPELL_WIZARD },
+       { SPELL_HASTE, 11, MON_SPELL_WIZARD },
+      }
+    },
+
+    {  MST_DEEP_ELF_ARCHER,
+      {
+       { SPELL_BLINK_AWAY, 36, MON_SPELL_WIZARD | MON_SPELL_SHORT_RANGE },
+       { SPELL_SLOW, 12, MON_SPELL_WIZARD },
+       { SPELL_CONFUSE, 12, MON_SPELL_WIZARD },
+       { SPELL_REPEL_MISSILES, 12, MON_SPELL_WIZARD },
+      }
+    },
+
+    { MST_DART_SLUG,
+      {
+        { SPELL_SLUG_DART, 40, MON_SPELL_NATURAL },
+      }
+    },
+
+    { MST_HOWLER_MONKEY,
+      {
+        { SPELL_WARNING_CRY, 40, MON_SPELL_NATURAL | MON_SPELL_BREATH
+                                 | MON_SPELL_NO_SILENT },
+      }
+    },
+
+    { MST_RIME_DRAKE,
+      {
+        { SPELL_FLASH_FREEZE, 62, MON_SPELL_NATURAL | MON_SPELL_BREATH },
+      }
+    },
+
+    {  MST_LICH_I,
+      {
+       { SPELL_BOLT_OF_FIRE, 12, MON_SPELL_WIZARD },
+       { SPELL_IRON_SHOT, 12, MON_SPELL_WIZARD },
+       { SPELL_SUMMON_GREATER_DEMON, 12, MON_SPELL_WIZARD },
+       { SPELL_CONFUSE, 12, MON_SPELL_WIZARD },
+       { SPELL_INVISIBILITY, 12, MON_SPELL_WIZARD },
+      }
+    },
+
+    {  MST_LICH_II,
+      {
+       { SPELL_BOLT_OF_COLD, 12, MON_SPELL_WIZARD },
+       { SPELL_FORCE_LANCE, 12, MON_SPELL_WIZARD },
+       { SPELL_SUMMON_GREATER_DEMON, 12, MON_SPELL_WIZARD },
+       { SPELL_SLOW, 12, MON_SPELL_WIZARD },
+       { SPELL_INVISIBILITY, 12, MON_SPELL_WIZARD },
+      }
+    },
+
+    {  MST_LICH_III,
+      {
+       { SPELL_LIGHTNING_BOLT, 18, MON_SPELL_WIZARD },
+       { SPELL_IOOD, 12, MON_SPELL_WIZARD },
+       { SPELL_PARALYSE, 18, MON_SPELL_WIZARD },
+       { SPELL_HASTE, 12, MON_SPELL_WIZARD },
+      }
+    },
+
+    {  MST_LICH_IV,
+      {
+       { SPELL_CORROSIVE_BOLT, 18, MON_SPELL_WIZARD },
+       { SPELL_LEHUDIBS_CRYSTAL_SPEAR, 12, MON_SPELL_WIZARD },
+       { SPELL_PETRIFY, 18, MON_SPELL_WIZARD },
+       { SPELL_HASTE, 12, MON_SPELL_WIZARD },
+      }
+    },
+
+    {  MST_LICH_V,
+      {
+       { SPELL_BOLT_OF_DRAINING, 12, MON_SPELL_WIZARD },
+       { SPELL_POISON_ARROW, 12, MON_SPELL_WIZARD },
+       { SPELL_HAUNT, 12, MON_SPELL_WIZARD },
+       { SPELL_BANISHMENT, 12, MON_SPELL_WIZARD },
+       { SPELL_HASTE, 12, MON_SPELL_WIZARD },
+      }
+    },
+
 };
