@@ -16,6 +16,11 @@ const int KRAKEN_TENTACLE_RANGE = 3;
 
 #define FAKE_BLINK_KEY "fake_blink"
 
+/// has a given hound already used up its howl?
+#define DOOM_HOUND_HOWLED_KEY "doom_hound_howled"
+
+#define DROPPER_MID_KEY "dropper_mid"
+
 typedef map<enchant_type, mon_enchant> mon_enchant_list;
 
 struct monsterentry;
@@ -68,8 +73,6 @@ public:
         int prism_charge;      ///< Turns this prism has existed
         int battlecharge;      ///< Charges of battlesphere
         int move_spurt;        ///< Sixfirhy/jiangshi/kraken black magic
-        int swift_cooldown;    ///< When alligator last casted Swift
-        monster_type orc_type; ///< Orc type of Nergalle's spectral orc.
         mid_t tentacle_connect;///< mid of monster this tentacle is
                                //   connected to: for segments, this is the
                                //   tentacle; for tentacles, the head.
@@ -141,7 +144,7 @@ public:
     kill_category kill_alignment() const override;
 
     int  foe_distance() const;
-    bool needs_berserk(bool check_spells = true) const;
+    bool needs_berserk(bool check_spells = true, bool ignore_distance = false) const;
 
     // Has a hydra-like variable number of attacks based on num_heads.
     bool has_hydra_multi_attack() const;
@@ -255,10 +258,8 @@ public:
                           bool base = false) const override;
     brand_type  damage_brand(int which_attack = -1) override;
     int         damage_type(int which_attack = -1) override;
-    random_var  attack_delay(const item_def *weapon,
-                             const item_def *projectile = nullptr,
-                             bool random = true, bool scaled = true,
-                             bool /*shield*/ = true) const override;
+    random_var  attack_delay(const item_def *projectile = nullptr,
+                             bool rescale = true) const override;
     int         has_claws(bool allow_tran = true) const override;
 
     int wearing(equipment_type slot, int type, bool calc_unid = true) const
@@ -279,7 +280,8 @@ public:
     item_def *missiles() const;
     item_def *shield() const override;
 
-    hands_reqd_type hands_reqd(const item_def &item) const override;
+    hands_reqd_type hands_reqd(const item_def &item,
+                               bool base = false) const override;
 
     bool      can_wield(const item_def &item,
                         bool ignore_curse = false,
@@ -341,7 +343,8 @@ public:
     bool malmutate(const string &/*reason*/) override;
     void corrupt();
     bool polymorph(int pow) override;
-    void banish(actor *agent, const string &who = "") override;
+    void banish(actor *agent, const string &who = "", const int power = 0,
+                bool force = false) override;
     void expose_to_element(beam_type element, int strength = 0,
                            bool slow_cold_blood = true) override;
 
@@ -359,7 +362,7 @@ public:
     bool is_artificial(bool temp = true) const override;
     bool is_unbreathing() const override;
     bool is_insubstantial() const override;
-    bool res_hellfire() const override;
+    bool res_damnation() const override;
     int res_fire() const override;
     int res_steam() const override;
     int res_cold() const override;
@@ -375,7 +378,7 @@ public:
     bool res_wind() const override;
     bool res_petrify(bool /*temp*/ = true) const override;
     int res_constrict() const override;
-    int res_magic() const override;
+    int res_magic(bool calc_unid = true) const override;
     bool no_tele(bool calc_unid = true, bool permit_id = true,
                  bool blink = false) const override;
     bool res_corr(bool calc_unid = true, bool items = true) const override;
@@ -388,7 +391,7 @@ public:
     bool is_banished() const override;
     bool is_web_immune() const override;
     bool invisible() const override;
-    bool can_see_invisible() const override;
+    bool can_see_invisible(bool calc_unid = true) const override;
     bool visible_to(const actor *looker) const override;
     bool near_foe() const;
     reach_type reach_range() const override;
@@ -476,7 +479,7 @@ public:
              string aux = "",
              bool cleanup_dead = true,
              bool attacker_effects = true) override;
-    bool heal(int amount, bool max_too = false) override;
+    bool heal(int amount) override;
     void blame_damage(const actor *attacker, int amount);
     void blink() override;
     void teleport(bool right_now = false,
@@ -571,6 +574,7 @@ private:
     bool pickup_launcher(item_def &launcher, bool msg, bool force = false);
     bool pickup_melee_weapon(item_def &item, bool msg);
     bool pickup_weapon(item_def &item, bool msg, bool force);
+    bool pickup_rod(item_def &item, bool msg, bool force);
     bool pickup_armour(item_def &item, bool msg, bool force);
     bool pickup_jewellery(item_def &item, bool msg, bool force);
     bool pickup_misc(item_def &item, bool msg, bool force);
@@ -603,7 +607,7 @@ private:
                               coord_def &chosen,
                               int &nvalid) const;
     bool search_spells(function<bool (spell_type)> func) const;
-    bool is_cloud_safe(const coord_def &place);
+    bool is_cloud_safe(const coord_def &place) const;
 };
 
 #endif
