@@ -1117,19 +1117,12 @@ static void _construct_backgrounds_menu(const newgame_def& ng,
     // Add entries for any job groups with at least one playable background.
     for (job_group& group : jobs_order)
     {
-        bool skip_group = false;
-        if (ng.species != SP_UNKNOWN)
+        if (ng.species == SP_UNKNOWN
+            || any_of(begin(group.jobs), end(group.jobs), [&ng](job_type job)
+                      { return job_allowed(ng.species, job) != CC_BANNED; }))
         {
-            skip_group = true;
-            for (job_type &job : group.jobs)
-                if (job_allowed(ng.species, job) > CC_BANNED)
-                {
-                    skip_group = false;
-                    break;
-                }
-        }
-        if (!skip_group)
             group.attach(ng, defaults, menu, letter);
+        }
     }
 
     // Add all the special button entries
