@@ -101,8 +101,11 @@ char_choice_restriction weapon_restriction(weapon_type wpn,
         return CC_RESTRICTED;
     }
 
-    if (wpn == WPN_QUARTERSTAFF && ng.job != JOB_GLADIATOR)
+    if (wpn == WPN_QUARTERSTAFF && ng.job != JOB_GLADIATOR
+        && !(ng.job == JOB_FIGHTER && ng.species == SP_FORMICID))
+    {
         return CC_BANNED;
+    }
 
     // Javelins are always good, tomahawks not so much.
     if (wpn == WPN_THROWN)
