@@ -247,7 +247,7 @@ void update_item_at(const coord_def &gp, bool detected)
     else
     {
         if (detected)
-            StashTrack.add_stash(gp.x, gp.y);
+            StashTrack.add_stash(gp);
 
         const vector<item_def> stash = item_list_in_stash(gp);
         if (stash.empty())
@@ -260,9 +260,8 @@ void update_item_at(const coord_def &gp, bool detected)
     env.map_knowledge(gp).set_item(get_item_info(eitem), more_items);
 }
 
-static void _update_cloud(int cloudno)
+static void _update_cloud(cloud_struct& cloud)
 {
-    cloud_struct& cloud = env.cloud[cloudno];
     const coord_def gp = cloud.pos;
 
     unsigned short ch = 0;
@@ -288,7 +287,7 @@ static void _update_cloud(int cloudno)
     else if (dur > 3)
         dur = 3;
 
-    cloud_info ci(cloud.type, get_cloud_colour(cloudno), dur, ch, gp,
+    cloud_info ci(cloud.type, get_cloud_colour(cloud), dur, ch, gp,
                   cloud.killer);
     env.map_knowledge(gp).set_cloud(ci);
 }
@@ -414,7 +413,7 @@ static void _handle_unseen_mons(monster* mons, uint32_t hash_ind)
     // Fall back to a random position adjacent to the unseen position.
     // This can only happen if the monster just became unseen.
     vector <coord_def> adj_unseen;
-    for (adjacent_iterator ai(mons->unseen_pos, false); ai; ai++)
+    for (adjacent_iterator ai(mons->unseen_pos, false); ai; ++ai)
     {
         if (_valid_invisible_spot(*ai, mons))
             adj_unseen.push_back(*ai);
@@ -465,13 +464,16 @@ static void _update_monster(monster* mons)
     if (!you.turn_is_over)
         mons->went_unseen_this_turn = false;
 
+    // Being submerged is not the same as invisibility.
+    if (mons->submerged())
+        return;
+
     // Ripple effect?
     // Should match directn.cc's _mon_exposed
     if (grd(gp) == DNGN_SHALLOW_WATER
             && !mons->airborne()
-            && env.cgrid(gp) == EMPTY_CLOUD
-        || is_opaque_cloud(env.cgrid(gp))
-            && !mons->submerged()
+            && !cloud_at(gp)
+        || cloud_at(gp) && is_opaque_cloud(cloud_at(gp)->type)
             && !mons->is_insubstantial())
     {
         _mark_invisible_at(gp);
@@ -479,10 +481,6 @@ static void _update_monster(monster* mons)
         return;
     }
 
-    // Being submerged is not the same as invisibility.
-    if (mons->submerged())
-        return;
-
     int range = player_monster_detect_radius();
     if (mons->constricted_by == MID_PLAYER
         || (range > 0 && (you.pos() - mons->pos()).rdist() <= range))
@@ -535,14 +533,8 @@ void show_update_at(const coord_def &gp, layers_type layers)
         }
 
         if (layers & LAYER_CLOUDS)
-        {
-            const int cloud = env.cgrid(gp);
-            if (cloud != EMPTY_CLOUD && env.cloud[cloud].type != CLOUD_NONE
-                && env.cloud[cloud].pos == gp)
-            {
-                _update_cloud(cloud);
-            }
-        }
+            if (cloud_struct* cloud = cloud_at(gp))
+                _update_cloud(*cloud);
 
         if (layers & LAYER_ITEMS)
             update_item_at(gp);
@@ -582,9 +574,7 @@ void show_init(layers_type layers)
         env.map_knowledge(loc).flags &= ~MAP_INVISIBLE_UPDATE;
 }
 
-// Emphasis may change while off-level (precisely, after
-// taking stairs and saving the level, when we reach
-// the next level). This catches up.
+// Emphasis may change while off-level. This catches up.
 // It should be equivalent to looping over the whole map
 // and setting MAP_EMPHASIZE for any coordinate with
 // emphasise(p) == true, but we optimise a bit.
