@@ -10,7 +10,7 @@ class dist;
 spret_type cast_delayed_fireball(bool fail);
 void setup_fire_storm(const actor *source, int pow, bolt &beam);
 spret_type cast_fire_storm(int pow, bolt &beam, bool fail);
-bool cast_hellfire_burst(int pow, bolt &beam);
+bool cast_smitey_damnation(int pow, bolt &beam);
 spret_type cast_chain_spell(spell_type spell_cast, int pow,
                             const actor *caster, bool fail = false);
 
@@ -27,7 +27,6 @@ spret_type cast_shatter(int pow, bool fail);
 spret_type cast_irradiate(int powc, actor* who, bool fail);
 bool ignite_poison_affects(const actor* act);
 spret_type cast_ignite_poison(actor *agent, int pow, bool fail, bool mon_tracer = false);
-void local_ignite_poison(coord_def pos, int pow, actor* agent);
 int discharge_monsters(coord_def where, int pow, actor *agent);
 spret_type cast_discharge(int pow, bool fail);
 bool setup_fragmentation_beam(bolt &beam, int pow, const actor *caster,
