@@ -20,6 +20,9 @@ int englaciate(coord_def where, int pow, actor *agent)
     if (!victim || victim == agent)
         return 0;
 
+    if (agent->is_monster() && mons_aligned(agent, victim))
+        return 0; // don't let monsters hit friendlies
+
     monster* mons = victim->as_monster();
 
     if (victim->res_cold() > 0
