@@ -14,6 +14,7 @@
 #include "butcher.h" // butcher_corpse
 #include "coordit.h" // radius_iterator
 #include "godconduct.h"
+#include "godpassive.h"
 #include "hints.h"
 #include "items.h" // stack_iterator
 #include "libutil.h"
@@ -21,6 +22,7 @@
 #include "message.h"
 #include "output.h"
 #include "religion.h"
+#include "showsymb.h"
 #include "spl-transloc.h"
 #include "spl-util.h"
 #include "transform.h"
@@ -32,7 +34,7 @@ int allowed_deaths_door_hp()
 {
     int hp = calc_spell_power(SPELL_DEATHS_DOOR, true) / 10;
 
-    if (in_good_standing(GOD_KIKUBAAQUDGHA))
+    if (have_passive(passive_t::deaths_door_hp_boost))
         hp += you.piety / 15;
 
     return max(hp, 1);
@@ -81,7 +83,7 @@ spret_type ice_armour(int pow, bool fail)
         return SPRET_ABORT;
     }
 
-    if (you.duration[DUR_STONESKIN] || you.form == TRAN_STATUE)
+    if (you.form == TRAN_STATUE)
     {
         mpr("The film of ice won't work on stone.");
         return SPRET_ABORT;
@@ -108,8 +110,7 @@ spret_type ice_armour(int pow, bool fail)
         mpr("Your corpse armour falls away.");
     }
 
-    you.increase_duration(DUR_ICY_ARMOUR, 20 + random2(pow) + random2(pow), 50,
-                          nullptr);
+    you.increase_duration(DUR_ICY_ARMOUR, random_range(40, 50), 50);
     you.props[ICY_ARMOUR_KEY] = pow;
     you.redraw_armour_class = true;
 
@@ -148,7 +149,7 @@ int harvest_corpses(const actor &harvester, bool dry_run)
                 bolt beam;
                 beam.source = *ri;
                 beam.target = harvester.pos();
-                beam.glyph = dchar_glyph(DCHAR_FIRED_CHUNK);
+                beam.glyph = get_item_glyph(item).ch;
                 beam.colour = item.get_colour();
                 beam.range = LOS_RADIUS;
                 beam.aimed_at_spot = true;
@@ -178,7 +179,7 @@ int harvest_corpses(const actor &harvester, bool dry_run)
  */
 spret_type corpse_armour(int pow, bool fail)
 {
-    if (you.duration[DUR_STONESKIN] || you.form == TRAN_STATUE)
+    if (you.form == TRAN_STATUE)
     {
         mpr("The corpses won't embrace your stony flesh.");
         return SPRET_ABORT;
