@@ -15,7 +15,7 @@
 size_t strlcpy(char *dst, const char *src, size_t n);
 #endif
 
-string lowercase_string(const string s);
+string lowercase_string(const string &s);
 string &lowercase(string &s);
 string &uppercase(string &s);
 string uppercase_string(string s);
