@@ -5,6 +5,8 @@
 
 #include "AppHdr.h"
 
+#include "syscalls.h"
+
 #ifdef TARGET_OS_WINDOWS
 # ifdef TARGET_COMPILER_VC
 #  include <direct.h>
@@ -23,9 +25,23 @@
 
 #include "files.h"
 #include "random.h"
-#include "syscalls.h"
 #include "unicode.h"
 
+#ifdef __ANDROID__
+#include <errno.h>
+
+#include <android/asset_manager.h>
+#include <android/asset_manager_jni.h>
+#include <jni.h>
+
+extern "C"
+{
+    extern JNIEnv *Android_JNI_GetEnv(); // sigh
+}
+
+AAssetManager *_android_asset_manager = nullptr; // XXX
+#endif
+
 bool lock_file(int fd, bool write, bool wait)
 {
 #ifdef TARGET_OS_WINDOWS
@@ -135,7 +151,7 @@ int fdatasync(int fd)
     if (!FlushFileBuffers(h))
     {
         /* Translate some Windows errors into rough approximations of Unix
-         * errors.  MSDN is useless as usual - in this case it doesn't
+         * errors. MSDN is useless as usual - in this case it doesn't
          * document the full range of errors.
          */
         switch (GetLastError())
@@ -155,6 +171,7 @@ int fdatasync(int fd)
 }
 # endif
 
+# ifndef CRAWL_HAVE_MKSTEMP
 int mkstemp(char *dummy)
 {
     HANDLE fh;
@@ -167,16 +184,17 @@ int mkstemp(char *dummy)
         for (int i = 0; i < 6; i++)
             filename[len + i] = 'a' + random2(26);
         filename[len + 6] = 0;
-        fh = CreateFileW(filename, GENERIC_READ | GENERIC_WRITE, 0, NULL,
+        fh = CreateFileW(filename, GENERIC_READ | GENERIC_WRITE, 0, nullptr,
                          CREATE_NEW,
                          FILE_FLAG_DELETE_ON_CLOSE | FILE_ATTRIBUTE_TEMPORARY,
-                         NULL);
+                         nullptr);
         if (fh != INVALID_HANDLE_VALUE)
             return _open_osfhandle((intptr_t)fh, 0);
     }
 
     die("can't create temporary file in %%TMPDIR%%");
 }
+# endif
 
 #else
 // non-Windows
@@ -191,9 +209,9 @@ int fdatasync(int fd)
     // but ignore flush requests.  fsync() should never return before the disk
     // claims the flush completed, but this is not the case on OS X.
     //
-    // Except, this is the case for internal drives only.  For "external" ones,
+    // Except, this is the case for internal drives only. For "external" ones,
     // F_FULLFSYNC is said to fail (at least on some versions of OS X), while
-    // fsync() actually works.  Thus, we need to try both.
+    // fsync() actually works. Thus, we need to try both.
     return fcntl(fd, F_FULLFSYNC, 0) && fsync(fd);
 #  else
     return fsync(fd);
@@ -226,11 +244,39 @@ void usleep(unsigned long time)
     timer.tv_sec  = (time / 1000000L);
     timer.tv_usec = (time % 1000000L);
 
-    select(0, NULL, NULL, NULL, &timer);
+    select(0, nullptr, nullptr, nullptr, &timer);
 }
 # endif
 #endif
 
+#ifdef __ANDROID__
+AAssetManager *_android_get_asset_manager()
+{
+    JNIEnv *env = Android_JNI_GetEnv();
+    jclass sdlClass = env->FindClass("org/libsdl/app/SDLActivity");
+
+    if (!sdlClass)
+        return nullptr;
+
+    jmethodID mid =
+        env->GetStaticMethodID(sdlClass, "getContext",
+                               "()Landroid/content/Context;");
+    jobject context = env->CallStaticObjectMethod(sdlClass, mid);
+
+    if (!context)
+        return nullptr;
+
+    mid = env->GetMethodID(env->GetObjectClass(context), "getAssets",
+                           "()Landroid/content/res/AssetManager;");
+    jobject assets = env->CallObjectMethod(context, mid);
+
+    if (!assets)
+        return nullptr;
+
+    return AAssetManager_fromJava(env, assets);
+}
+#endif
+
 bool file_exists(const string &name)
 {
 #ifdef TARGET_OS_WINDOWS
@@ -238,12 +284,48 @@ bool file_exists(const string &name)
     return lAttr != INVALID_FILE_ATTRIBUTES
            && !(lAttr & FILE_ATTRIBUTE_DIRECTORY);
 #else
+#ifdef __ANDROID__
+    if (name.find(ANDROID_ASSETS) == 0)
+    {
+        if (!_android_asset_manager)
+            _android_asset_manager = _android_get_asset_manager();
+
+        ASSERT(_android_asset_manager);
+
+        AAsset* asset = AAssetManager_open(_android_asset_manager,
+                                           name.substr(strlen(ANDROID_ASSETS)
+                                                       + 1)
+                                               .c_str(),
+                                           AASSET_MODE_UNKNOWN);
+        if (asset)
+        {
+            AAsset_close(asset);
+            return true;
+        }
+        return false;
+    }
+#endif
     struct stat st;
     const int err = ::stat(OUTS(name), &st);
     return !err && S_ISREG(st.st_mode);
 #endif
 }
 
+#ifdef __ANDROID__
+/**
+ * Remove an ANDROID_ASSETS prefix and strip any trailing slashes
+ * from a directory name.
+ */
+static string _android_strip_dir_slash(const string &in)
+{
+    string out = in.substr(strlen(ANDROID_ASSETS) + 1);
+    if (out.back() == '/')
+        out = out.substr(0, out.length() - 1);
+
+    return out;
+}
+#endif
+
 // Low-tech existence check.
 bool dir_exists(const string &dir)
 {
@@ -251,7 +333,27 @@ bool dir_exists(const string &dir)
     DWORD lAttr = GetFileAttributesW(OUTW(dir));
     return lAttr != INVALID_FILE_ATTRIBUTES
            && (lAttr & FILE_ATTRIBUTE_DIRECTORY);
-#elif defined(HAVE_STAT)
+#else
+#ifdef __ANDROID__
+    if (dir.find(ANDROID_ASSETS) == 0)
+    {
+        if (!_android_asset_manager)
+            _android_asset_manager = _android_get_asset_manager();
+
+        ASSERT(_android_asset_manager);
+
+        AAssetDir* adir = AAssetManager_openDir(_android_asset_manager,
+                                                _android_strip_dir_slash(dir)
+                                                    .c_str());
+        if (adir)
+        {
+            AAssetDir_close(adir);
+            return true;
+        }
+        return false;
+    }
+#endif
+#ifdef HAVE_STAT
     struct stat st;
     const int err = ::stat(OUTS(dir), &st);
     return !err && S_ISDIR(st.st_mode);
@@ -263,6 +365,7 @@ bool dir_exists(const string &dir)
 
     return exists;
 #endif
+#endif
 }
 
 static inline bool _is_good_filename(const string &s)
@@ -293,7 +396,29 @@ vector<string> get_dir_files(const string &dirname)
         FindClose(hFind);
     }
 #else
+#ifdef __ANDROID__
+    if (dirname.find(ANDROID_ASSETS) == 0)
+    {
+        if (!_android_asset_manager)
+            _android_asset_manager = _android_get_asset_manager();
 
+        ASSERT(_android_asset_manager);
+
+        AAssetDir* adir =
+            AAssetManager_openDir(_android_asset_manager,
+                                  _android_strip_dir_slash(dirname).c_str());
+
+        if (!adir)
+            return files;
+
+        const char *file;
+        while ((file = AAssetDir_getNextFileName(adir)) != nullptr)
+            files.emplace_back(file);
+
+        AAssetDir_close(adir);
+        return files;
+    }
+#endif
     DIR *dir = opendir(OUTS(dirname));
     if (!dir)
         return files;
@@ -329,12 +454,63 @@ int unlink_u(const char *pathname)
 #endif
 }
 
+#ifdef __ANDROID__
+/**
+ * This implementation of handling Android fopens to Android assets
+ * appears to originate from here:
+ * http://www.50ply.com/blog/2013/01/19/
+ *   loading-compressed-android-assets-with-file-pointer/
+ */
+
+static int _android_read(void* cookie, char* buf, int size)
+{
+    return AAsset_read((AAsset*)cookie, buf, size);
+}
+
+static int _android_write(void* cookie, const char* buf, int size)
+{
+    return EACCES; // can't provide write access to the apk
+}
+
+static fpos_t _android_seek(void* cookie, fpos_t offset, int whence)
+{
+    return AAsset_seek((AAsset*)cookie, offset, whence);
+}
+
+static int _android_close(void* cookie)
+{
+    AAsset_close((AAsset*)cookie);
+    return 0;
+}
+#endif
+
 FILE *fopen_u(const char *path, const char *mode)
 {
 #ifdef TARGET_OS_WINDOWS
     // Why it wants the mode string as double-byte is beyond me.
     return _wfopen(OUTW(path), OUTW(mode));
 #else
+#ifdef __ANDROID__
+    if (strstr(path, ANDROID_ASSETS) == path)
+    {
+        if (!mode || mode[0] == 'w')
+            return nullptr;
+
+        if (!_android_asset_manager)
+            _android_asset_manager = _android_get_asset_manager();
+
+        ASSERT(_android_asset_manager);
+
+        AAsset* asset = AAssetManager_open(_android_asset_manager,
+                                           path + strlen(ANDROID_ASSETS) + 1,
+                                           AASSET_MODE_RANDOM);
+        if (!asset)
+            return nullptr;
+
+        return funopen(asset, _android_read, _android_write, _android_seek,
+                       _android_close);
+    }
+#endif
     return fopen(OUTS(path), mode);
 #endif
 }
