@@ -12,6 +12,7 @@ enum aff_type // sign and non-zeroness matters
     // If you want to extend this to pass the probability somehow, feel free to,
     // just keep AFF_YES the minimal "bright" value.
     AFF_LANDING,     // Valid shadow step landing site
+    AFF_MULTIPLE,    // Passes through multiple times
 };
 
 class targetter
@@ -31,6 +32,7 @@ public:
 
     virtual aff_type is_affected(coord_def loc) = 0;
     virtual bool has_additional_sites(coord_def a);
+    virtual bool affects_monster(const monster_info& mon);
 protected:
     bool anyone_there(coord_def loc);
 };
@@ -45,15 +47,25 @@ public:
     bool valid_aim(coord_def a) override;
     bool can_affect_outside_range() override;
     virtual aff_type is_affected(coord_def loc) override;
+    virtual bool affects_monster(const monster_info& mon) override;
 protected:
     vector<coord_def> path_taken; // Path beam took.
+    void set_explosion_aim(bolt tempbeam);
+    void set_explosion_target(bolt &tempbeam);
+    int min_expl_rad, max_expl_rad;
 private:
     bool penetrates_targets;
     int range;
-    int min_expl_rad, max_expl_rad;
     explosion_map exp_map_min, exp_map_max;
 };
 
+class targetter_unravelling : public targetter_beam
+{
+public:
+    targetter_unravelling(const actor *act, int range, int pow);
+    bool set_aim(coord_def a) override;
+};
+
 class targetter_imb : public targetter_beam
 {
 public:
@@ -260,15 +272,4 @@ private:
     size_t num_beams;
     int range;
 };
-
-class targetter_list : public targetter
-{
-public:
-    targetter_list(vector<coord_def> targets, coord_def center);
-    aff_type is_affected(coord_def loc) override;
-    bool valid_aim(coord_def a) override;
-private:
-    vector<coord_def> targets;
-};
-
 #endif
