@@ -19,7 +19,6 @@
 #include "religion.h"
 #include "spl-cast.h"
 #include "terrain.h"
-#include "tiledef-dngn.h"
 #include "tiledef-icons.h"
 #include "tilepick.h"
 #include "viewgeom.h"
@@ -163,8 +162,6 @@ void CommandRegion::pack_buffers()
             if (i >= m_items.size())
                 break;
 
-            m_buf.add_dngn_tile(TILE_ITEM_SLOT, x, y);
-
             InventoryTile &item = m_items[i++];
             if (item.flag & TILEI_FLAG_INVALID)
                 m_buf.add_icons_tile(TILEI_MESH, x, y);
