@@ -164,6 +164,7 @@ function ($, view_data, main, tileinfo_player, icons, dngn, enums,
                 this.render_glyph(x, y, map_cell);
 
                 this.render_cursors(cx, cy, x, y);
+                this.draw_ray(x, y, cell);
                 return;
             }
 
@@ -545,6 +546,25 @@ function ($, view_data, main, tileinfo_player, icons, dngn, enums,
             }
         },
 
+        draw_ray: function(x, y, cell)
+        {
+            var bg = cell.bg;
+            var bg_idx = cell.bg.value;
+            var renderer = this;
+
+            if (bg_idx > dngn.DNGN_UNSEEN)
+            {
+                if (bg.RAY)
+                    this.draw_dngn(dngn.RAY, x, y);
+                else if (bg.RAY_OOR)
+                    this.draw_dngn(dngn.RAY_OUT_OF_RANGE, x, y);
+                else if (bg.LANDING)
+                    this.draw_dngn(dngn.LANDING, x, y);
+                else if (bg.RAY_MULTI)
+                    this.draw_dngn(dngn.RAY_MULTI, x, y);
+            }
+        },
+
         draw_background: function(x, y, cell)
         {
             var bg = cell.bg;
@@ -674,15 +694,9 @@ function ($, view_data, main, tileinfo_player, icons, dngn, enums,
                     else if (bg.TRAV_EXCL)
                         this.draw_dngn(dngn.TRAVEL_EXCLUSION_BG, x, y);
                 }
-
-                if (bg.RAY)
-                    this.draw_dngn(dngn.RAY, x, y);
-                else if (bg.RAY_OOR)
-                    this.draw_dngn(dngn.RAY_OUT_OF_RANGE, x, y);
-                else if (bg.LANDING)
-                    this.draw_dngn(dngn.LANDING, x, y);
-
             }
+
+            this.draw_ray(x, y, cell);
         },
 
         draw_foreground: function(x, y, map_cell)
@@ -742,6 +756,7 @@ function ($, view_data, main, tileinfo_player, icons, dngn, enums,
             else if (options.get("tile_display_mode") == "hybrid")
             {
                 this.render_glyph(x, y, map_cell, true);
+                this.draw_ray(x, y, cell);
             }
 
             if (fg.NET)
@@ -868,7 +883,7 @@ function ($, view_data, main, tileinfo_player, icons, dngn, enums,
             if (fg.DEATHS_DOOR)
             {
                 this.draw_icon(icons.DEATHS_DOOR, x, y, -status_shift, 0);
-                status_shift += 6;
+                status_shift += 10;
             }
             if (fg.RECALL)
             {
