@@ -126,7 +126,7 @@ function ($, comm, client, enums, dungeon_renderer, cr, util, options) {
         }
         else
         {
-            for (var i = menu.first_present; i < menu.last_present; ++i)
+            for (var i = menu.first_present; i <= menu.last_present; ++i)
             {
                 var item = menu.items[i];
                 if (!item) continue;
@@ -500,7 +500,19 @@ function ($, comm, client, enums, dungeon_renderer, cr, util, options) {
     {
         $.extend(menu, data);
 
+        if (menu.total_items < menu.items.length)
+        {
+            for (var i = menu.items.length; i >= menu.total_items; --i)
+                delete menu.items[i];
+            menu.items.length = menu.total_items;
+            var container = $("ol");
+            container.empty();
+            $.each(menu.items, function(i, item) {
+                container.append(item.elem);
+            });
+        }
         update_title();
+        $("#menu_more").html(util.formatted_string_to_html(menu.more));
 
         client.center_element($("#menu"));
     }
@@ -561,6 +573,8 @@ function ($, comm, client, enums, dungeon_renderer, cr, util, options) {
             scroll_bottom_to_item(menu.last_visible, true);
         else
             scroll_to_item(menu.first_visible, true);
+        // scrolling might not call this, but still need to show/hide more
+        menu_scroll_handler();
     }
 
     function menu_scroll_handler()
@@ -568,12 +582,10 @@ function ($, comm, client, enums, dungeon_renderer, cr, util, options) {
         var contents = $("#menu_contents");
         update_visible_indices();
         schedule_server_scroll();
-        if (menu.last_visible >= menu.items.length - 1)
+        if (menu.last_visible >= menu.items.length - 1
+            && !(menu.flags & enums.menu_flag.ALWAYS_SHOW_MORE))
         {
-            if (!(menu.flags & enums.menu_flag.ALWAYS_SHOW_MORE))
-            {
-                $("#menu_more").css("visibility", "hidden");
-            }
+            $("#menu_more").css("visibility", "hidden");
         }
         else
         {
@@ -707,7 +719,7 @@ function ($, comm, client, enums, dungeon_renderer, cr, util, options) {
             $("#menu").css("font-family", family);
         }
 
-        client.center_element($("#menu"));
+        handle_size_change();
     });
 
     $(document).off("game_init.menu")
