@@ -24,6 +24,7 @@
 #include "place.h"
 #include "prompt.h"
 #include "religion.h"
+#include "spl-goditem.h" // detect_items
 #include "stairs.h"
 #include "state.h"
 #include "stringutil.h"
@@ -82,7 +83,7 @@ void wizard_place_stairs(bool down)
         return;
 
     mprf("Creating %sstairs.", down ? "down" : "up");
-    dungeon_terrain_changed(you.pos(), stairs, false);
+    dungeon_terrain_changed(you.pos(), stairs);
 }
 
 void wizard_level_travel(bool down)
@@ -249,7 +250,7 @@ bool wizard_create_feature(const coord_def& pos)
     env.tile_flv(pos).special = 0;
     env.grid_colours(pos) = 0;
     const dungeon_feature_type old_feat = grd(pos);
-    dungeon_terrain_changed(pos, feat, false);
+    dungeon_terrain_changed(pos, feat, false, false, false, true);
     // Update gate tiles, if existing.
     if (feat_is_door(old_feat) || feat_is_door(feat))
     {
@@ -359,30 +360,15 @@ void wizard_map_level()
 
     mpr("Mapping level.");
     magic_mapping(1000, 100, true, true);
-}
-
-static int find_trap_slot()
-{
-    for (int i = 0; i < MAX_TRAPS; ++i)
-        if (env.trap[i].type == TRAP_UNASSIGNED)
-            return i;
-
-    return -1;
+    detect_items(1000);
 }
 
 bool debug_make_trap(const coord_def& pos)
 {
     char requested_trap[80];
-    int trap_slot  = find_trap_slot();
     trap_type trap = TRAP_UNASSIGNED;
     int gridch     = grd(pos);
 
-    if (trap_slot == -1)
-    {
-        mpr("Sorry, this level can't take any more traps.");
-        return false;
-    }
-
     if (gridch != DNGN_FLOOR)
     {
         mpr("You need to be on a floor square to make a trap.");
@@ -446,21 +432,16 @@ bool debug_make_trap(const coord_def& pos)
         }
     }
 
-    bool success = place_specific_trap(you.pos(), trap);
-    if (success)
-    {
-        mprf("Created %s, marked it undiscovered.",
-             (trap == TRAP_RANDOM)
-                ? "a random trap"
-                : env.trap[env.tgrid(you.pos())].name(DESC_A).c_str());
-    }
-    else
-        mpr("Could not create trap - too many traps on level.");
+    place_specific_trap(you.pos(), trap);
+    mprf("Created %s, marked it undiscovered.",
+         (trap == TRAP_RANDOM)
+            ? "a random trap"
+            : trap_at(you.pos())->name(DESC_A).c_str());
 
     if (trap == TRAP_SHAFT && !is_valid_shaft_level())
         mpr("NOTE: Shaft traps aren't valid on this level.");
 
-    return success;
+    return true;
 }
 
 bool debug_make_shop(const coord_def& pos)
@@ -471,22 +452,6 @@ bool debug_make_shop(const coord_def& pos)
         return false;
     }
 
-    bool have_shop_slots = false;
-    for (int i = 0; i < MAX_SHOPS; ++i)
-    {
-        if (env.shop[i].type == SHOP_UNASSIGNED)
-        {
-            have_shop_slots = true;
-            break;
-        }
-    }
-
-    if (!have_shop_slots)
-    {
-        mpr("There are too many shops on this level.");
-        return false;
-    }
-
     char requested_shop[80];
     msgwin_get_line("What kind of shop? ",
                     requested_shop, sizeof(requested_shop));
@@ -506,7 +471,6 @@ bool debug_make_shop(const coord_def& pos)
     }
 
     place_spec_shop(pos, new_shop_type);
-    link_items();
     mpr("Done.");
     return true;
 }
