@@ -34,6 +34,7 @@
 #include "output.h"
 #include "player-equip.h"
 #include "prompt.h"
+#include "randbook.h"
 #include "religion.h"
 #include "skills.h"
 #include "spl-book.h"
@@ -89,11 +90,6 @@ void wizard_create_spec_object_by_name()
     }
 }
 
-//---------------------------------------------------------------
-//
-// create_spec_object
-//
-//---------------------------------------------------------------
 void wizard_create_spec_object()
 {
     char           specs[80];
@@ -265,7 +261,7 @@ static void _tweak_randart(item_def &item)
 #endif
         choice_to_prop.push_back(i);
         if (choice_num % 8 == 0 && choice_num != 0)
-            *(prompt.rend()) = '\n'; // Replace the space
+            prompt.back() = '\n'; // Replace the space
 
         char choice;
         char buf[80];
@@ -324,7 +320,7 @@ static void _tweak_randart(item_def &item)
         break;
 
     case ARTP_VAL_POS:
-     {
+    {
         mprf(MSGCH_PROMPT, "%s was %d.", artp_name(prop), props[prop]);
         const int val = prompt_for_int("New value? ", true);
 
@@ -337,15 +333,15 @@ static void _tweak_randart(item_def &item)
         artefact_set_property(item, static_cast<artefact_prop_type>(prop),
                              val);
         break;
-      }
+    }
     case ARTP_VAL_ANY:
-      {
+    {
         mprf(MSGCH_PROMPT, "%s was %d.", artp_name(prop), props[prop]);
         const int val = prompt_for_int("New value? ", false);
         artefact_set_property(item, static_cast<artefact_prop_type>(prop),
                              val);
         break;
-      }
+    }
     }
 }
 
@@ -476,8 +472,8 @@ static bool _make_book_randart(item_def &book)
 
     if (type == 'l')
         return make_book_level_randart(book);
-    else
-        return make_book_theme_randart(book);
+    build_themed_book(book);
+    return true;
 }
 
 void wizard_value_artefact()
@@ -585,7 +581,7 @@ void wizard_make_object_randart()
             return;
         }
 
-        item.special = 0;
+        item.unrand_idx = 0;
         item.flags  &= ~ISFLAG_RANDART;
         item.props.clear();
     }
@@ -619,10 +615,10 @@ void wizard_make_object_randart()
     }
 
     // Remove curse flag from item, unless worshipping Ashenzari.
-    if (you_worship(GOD_ASHENZARI))
+    if (have_passive(passive_t::want_curses))
         do_curse_item(item, true);
     else
-        do_uncurse_item(item, false);
+        do_uncurse_item(item);
 
     // If it was equipped, requip the item.
     if (eq != EQ_NONE)
@@ -691,17 +687,8 @@ void wizard_unidentify_pack()
     // (For use with the "give monster an item" wizard targeting
     // command.)
     for (monster_near_iterator mon(&you); mon; ++mon)
-    {
-        for (int j = 0; j < NUM_MONSTER_SLOTS; ++j)
-        {
-            if (mon->inv[j] == NON_ITEM)
-                continue;
-
-            item_def &item = mitm[mon->inv[j]];
-            if (item.defined())
-                _forget_item(item);
-        }
-    }
+        for (mon_inv_iterator ii(**mon); ii; ++ii)
+            _forget_item(*ii);
 }
 
 void wizard_list_items()
@@ -733,11 +720,6 @@ void wizard_list_items()
     }
 }
 
-//---------------------------------------------------------------
-//
-// debug_item_statistics
-//
-//---------------------------------------------------------------
 static void _debug_acquirement_stats(FILE *ostat)
 {
     int p = get_mitm_slot(11);
@@ -784,6 +766,7 @@ static void _debug_acquirement_stats(FILE *ostat)
     short max_plus   = -127;
     int total_plus   = 0;
     int num_arts     = 0;
+    int randbook_spells = 0;
 
     int subtype_quants[256];
     int ego_quants[NUM_SPECIAL_WEAPONS];
@@ -824,6 +807,7 @@ static void _debug_acquirement_stats(FILE *ostat)
             num_arts++;
             if (type == OBJ_BOOKS)
             {
+                randbook_spells += spells_in_book(item).size();
                 if (item.sub_type == BOOK_RANDART_THEME)
                 {
                     const int disc1 = item.plus & 0xFF;
@@ -1007,8 +991,10 @@ static void _debug_acquirement_stats(FILE *ostat)
             "draining",
             "speed",
             "vorpal",
+#if TAG_MAJOR_VERSION == 34
             "flame",
             "frost",
+#endif
             "vampirism",
             "pain",
             "antimagic",
@@ -1136,6 +1122,9 @@ static void _debug_acquirement_stats(FILE *ostat)
                             100.0 * (float) ego_quants[i] / (float) num_arts);
                 }
             }
+
+            fprintf(ostat, "Avg. spells per randbook: %4.3f",
+                    (float)randbook_spells / num_arts);
         }
 
         // Also list skills for manuals.
@@ -1228,7 +1217,7 @@ static void _debug_rap_stats(FILE *ostat)
 
     // Start off with a non-artefact item.
     item.flags  &= ~ISFLAG_ARTEFACT_MASK;
-    item.special = 0;
+    item.unrand_idx = 0;
     item.props.clear();
 
     if (!make_item_randart(item))
@@ -1270,7 +1259,7 @@ static void _debug_rap_stats(FILE *ostat)
         // Generate proprt once and hand it off to randart_is_bad(),
         // so that randart_is_bad() doesn't generate it a second time.
         item.flags  &= ~ISFLAG_ARTEFACT_MASK;
-        item.special = 0;
+        item.unrand_idx = 0;
         item.props.clear();
         make_item_randart(item);
         artefact_properties(item, proprt);
@@ -1419,6 +1408,8 @@ static void _debug_rap_stats(FILE *ostat)
         "ARTP_CORRODE",
         "ARTP_DRAIN",
         "ARTP_CONFUSE",
+        "ARTP_FRAGILE",
+        "ARTP_SHIELDING",
     };
     COMPILE_CHECK(ARRAYSZ(rap_names) == ARTP_NUM_PROPERTIES);
 
