@@ -8,9 +8,11 @@ struct zap_info
 {
     zap_type ztype;
     const char* name;
-    int power_cap;
-    dam_deducer* damage;
-    tohit_deducer* tohit;       // Enchantments have power modifier here
+    int player_power_cap;
+    dam_deducer* player_damage;
+    tohit_deducer* player_tohit;       // Enchantments have power modifier here
+    dam_deducer* monster_damage;
+    tohit_deducer* monster_tohit;      // Enchantments have power modifier here
     colour_t colour;
     bool is_enchantment;
     beam_type flavour;
@@ -31,6 +33,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<2, 4, 1, 10>,
     new tohit_calculator<8, 1, 10>,
+    new dicedef_calculator<3, 5, 1, 40>,
+    new tohit_calculator<25, 1, 40>,
     RED,
     false,
     BEAM_FIRE,
@@ -47,6 +51,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<2, 4, 1, 10>,
     new tohit_calculator<8, 1, 10>,
+    new dicedef_calculator<3, 5, 1, 40>,
+    new tohit_calculator<25, 1, 40>,
     WHITE,
     false,
     BEAM_COLD,
@@ -63,6 +69,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     new tohit_calculator<0, 3, 2>,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_SLOW,
@@ -79,6 +87,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     new tohit_calculator<AUTOMATIC_HIT>,
+    nullptr,
+    nullptr,
     GREEN,
     false,
     BEAM_MEPHITIC,
@@ -95,6 +105,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_HASTE,
@@ -111,6 +123,8 @@ static const zap_info zap_data[] =
     25,
     new dicedef_calculator<1, 3, 1, 5>,
     new tohit_calculator<AUTOMATIC_HIT>,
+    new dicedef_calculator<3, 4, 1, 100>,
+    new tohit_calculator<AUTOMATIC_HIT>,
     LIGHTMAGENTA,
     false,
     BEAM_MMISSILE,
@@ -127,6 +141,8 @@ static const zap_info zap_data[] =
     100,
     new dicedef_calculator<1, 7, 1, 3>,
     nullptr,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_HEALING,
@@ -143,6 +159,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_PARALYSIS,
@@ -159,6 +177,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<6, 18, 2, 3>,
     new tohit_calculator<10, 1, 25>,
+    new dicedef_calculator<3, 8, 1, 11>,
+    new tohit_calculator<17, 1, 25>,
     RED,
     false,
     BEAM_FIRE,
@@ -175,6 +195,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<6, 18, 2, 3>,
     new tohit_calculator<10, 1, 25>,
+    new dicedef_calculator<3, 8, 1, 11>,
+    new tohit_calculator<17, 1, 25>,
     WHITE,
     false,
     BEAM_COLD,
@@ -185,12 +207,14 @@ static const zap_info zap_data[] =
     6
 },
 
-{
+{ // Used only by phial of floods
     ZAP_PRIMAL_WAVE,
-    "great wave of water",
+    "flood of elemental water",
     200,
     new calcdice_calculator<4, 14, 3, 5>,
     new tohit_calculator<10, 1, 25>,
+    nullptr,
+    nullptr,
     LIGHTBLUE,
     false,
     BEAM_WATER,
@@ -207,6 +231,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_CONFUSION,
@@ -222,7 +248,9 @@ static const zap_info zap_data[] =
     "",
     100,
     nullptr,
-    new tohit_calculator<0, 3, 1>,
+    new tohit_calculator<0, 3, 2>,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_TUKIMAS_DANCE,
@@ -239,6 +267,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_INVISIBILITY,
@@ -255,6 +285,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_DIGGING,
@@ -271,6 +303,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<3, 10, 1, 2>,
     new tohit_calculator<40>,
+    new dicedef_calculator<3, 7, 1, 10>,
+    new tohit_calculator<40>,
     RED,
     false,
     BEAM_FIRE,
@@ -287,6 +321,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     new tohit_calculator<0, 3, 2>,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_TELEPORT,
@@ -303,6 +339,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<1, 11, 3, 5>,
     new tohit_calculator<7, 1, 40>,
+    new dicedef_calculator<3, 10, 1, 17>,
+    new tohit_calculator<16, 1, 40>,
     LIGHTCYAN,
     false,
     BEAM_ELECTRICITY,
@@ -319,6 +357,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_POLYMORPH,
@@ -335,6 +375,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<4, 16, 3, 5>,
     new tohit_calculator<8, 1, 20>,
+    new dicedef_calculator<3, 6, 1, 13>,
+    new tohit_calculator<19, 1, 20>,
     LIGHTGREEN,
     false,
     BEAM_POISON,
@@ -351,6 +393,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<4, 15, 3, 5>,
     new tohit_calculator<8, 1, 20>,
+    new dicedef_calculator<3, 9, 1, 13>,
+    new tohit_calculator<16, 1, 35>,
     DARKGREY,
     false,
     BEAM_NEG,
@@ -362,11 +406,13 @@ static const zap_info zap_data[] =
 },
 
 {
-    ZAP_LEHUDIBS_CRYSTAL_SPEAR,
+    ZAP_LEHUDIBS_CRYSTAL_SPEAR,      // was splinters
     "crystal spear",
     200,
     new calcdice_calculator<10, 23, 1, 1>,
     new tohit_calculator<10, 1, 15>,
+    new dicedef_calculator<3, 16, 1, 10>,
+    new tohit_calculator<22, 1, 20>,
     WHITE,
     false,
     BEAM_MMISSILE,
@@ -383,6 +429,8 @@ static const zap_info zap_data[] =
     1000,
     new calcdice_calculator<10, 40, 1, 1>,
     new tohit_calculator<1>,
+    new calcdice_calculator<12, 40, 3, 2>,
+    new tohit_calculator<1>,
     YELLOW,
     false,
     BEAM_ENERGY,
@@ -399,6 +447,8 @@ static const zap_info zap_data[] =
     100,
     new calcdice_calculator<2, 12, 1, 3>,
     new tohit_calculator<10, 1, 7>,
+    new dicedef_calculator<3, 7, 1, 14>,
+    new tohit_calculator<20, 1, 20>,
     LIGHTMAGENTA,
     false,
     BEAM_MMISSILE,
@@ -415,6 +465,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_ENSLAVE,
@@ -429,8 +481,10 @@ static const zap_info zap_data[] =
     ZAP_PAIN,
     "",
     100,
-    new dicedef_calculator<1, 4, 1,5>,
+    new dicedef_calculator<1, 4, 1, 5>,
     new tohit_calculator<0, 7, 2>,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_PAIN,
@@ -447,6 +501,8 @@ static const zap_info zap_data[] =
     100,
     new dicedef_calculator<2, 3, 1, 12>,
     new tohit_calculator<AUTOMATIC_HIT>,
+    new dicedef_calculator<3, 3, 1, 50>,
+    new tohit_calculator<AUTOMATIC_HIT>,
     RED,
     false,
     BEAM_FIRE,
@@ -463,6 +519,8 @@ static const zap_info zap_data[] =
     100,
     new dicedef_calculator<2, 3, 1, 12>,
     new tohit_calculator<AUTOMATIC_HIT>,
+    new dicedef_calculator<3, 3, 1, 50>,
+    new tohit_calculator<18, 1, 15>,
     RED,
     false,
     BEAM_FIRE,
@@ -479,6 +537,8 @@ static const zap_info zap_data[] =
     100,
     new calcdice_calculator<3, 20, 3, 4>,
     new tohit_calculator<0, 3, 2>,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_DISPEL_UNDEAD,
@@ -492,9 +552,11 @@ static const zap_info zap_data[] =
 {
     ZAP_BANISHMENT,
     "",
-    100,
+    150,
     nullptr,
     nullptr,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_BANISH,
@@ -511,6 +573,8 @@ static const zap_info zap_data[] =
     25,
     new dicedef_calculator<1, 3, 1, 5>,
     new tohit_calculator<8, 1, 5>,
+    new dicedef_calculator<1, 6, 1, 25>,
+    new tohit_calculator<60, 0, 1>,
     GREEN,
     false,
     BEAM_POISON,
@@ -522,14 +586,16 @@ static const zap_info zap_data[] =
 },
 
 {
-    ZAP_HELLFIRE,
-    "hellfire",
+    ZAP_DAMNATION,
+    "damnation",
     200,
     new calcdice_calculator<3, 8, 3, 5>,
     new tohit_calculator<20, 1, 10>,
+    nullptr,
+    nullptr,
     LIGHTRED,
     false,
-    BEAM_HELLFIRE,
+    BEAM_DAMNATION,
     DCHAR_FIRED_ZAP,
     true,
     false,
@@ -543,6 +609,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<9, 15, 3, 4>,
     new tohit_calculator<7, 1, 15>,
+    new dicedef_calculator<3, 8, 1, 9>,
+    new tohit_calculator<20, 1, 25>,
     LIGHTCYAN,
     false,
     BEAM_MMISSILE,
@@ -559,6 +627,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 5, 1, 8>,
     new tohit_calculator<8, 1, 10>,
+    new dicedef_calculator<3, 5, 1, 10>,
+    new tohit_calculator<14, 1, 35>,
     LIGHTGREY,
     false,
     BEAM_MMISSILE,
@@ -575,6 +645,8 @@ static const zap_info zap_data[] =
     25,
     new dicedef_calculator<1, 3, 1, 4>,
     new tohit_calculator<8, 1, 7>,
+    new dicedef_calculator<1, 8, 1, 20>,
+    new tohit_calculator<17, 1, 20>,
     LIGHTCYAN,
     false,
     BEAM_ELECTRICITY,             // beams & reflects
@@ -591,6 +663,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<0, 13, 4, 5>,
     new tohit_calculator<40>,
+    new dicedef_calculator<3, 7, 1, 9>,
+    new tohit_calculator<40>,
     LIGHTBLUE,
     false,
     BEAM_ELECTRICITY,
@@ -607,6 +681,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<1, 4, 1, 2>,
     new tohit_calculator<5, 1, 6>,
+    nullptr,
+    nullptr,
     GREEN,
     false,
     BEAM_POISON,
@@ -623,6 +699,8 @@ static const zap_info zap_data[] =
     10000,
     new dicedef_calculator<AUTOMATIC_HIT, 1, 0, 1>,
     new tohit_calculator<AUTOMATIC_HIT>,
+    nullptr,
+    nullptr,
     WHITE,
     false,
     BEAM_MMISSILE,
@@ -640,6 +718,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 4, 1, 3>,
     new tohit_calculator<8, 1, 6>,
+    nullptr,
+    nullptr,
     RED,
     false,
     BEAM_FIRE,
@@ -656,6 +736,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 4, 1, 3>,
     new tohit_calculator<8, 1, 6>,
+    nullptr,
+    nullptr,
     WHITE,
     false,
     BEAM_COLD,
@@ -672,6 +754,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 4, 1, 3>,
     new tohit_calculator<7, 1, 6>,
+    nullptr,
+    nullptr,
     YELLOW,
     false,
     BEAM_ACID,
@@ -688,6 +772,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 2, 1, 6>,
     new tohit_calculator<6, 1, 6>,
+    nullptr,
+    nullptr,
     GREEN,
     false,
     BEAM_POISON,
@@ -704,6 +790,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 3, 1, 3>,
     new tohit_calculator<5, 1, 6>,
+    nullptr,
+    nullptr,
     BLUE,
     false,
     BEAM_MMISSILE,
@@ -720,6 +808,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_ENSLAVE_SOUL,
@@ -736,6 +826,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     new tohit_calculator<0, 5, 1>,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_PAIN,
@@ -752,6 +844,8 @@ static const zap_info zap_data[] =
     100,
     new calcdice_calculator<3, 15, 3, 4>,
     new tohit_calculator<0, 5, 2>,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_DISINTEGRATION,
@@ -768,6 +862,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 4, 1, 5>,
     new tohit_calculator<10, 1, 10>,
+    nullptr,
+    nullptr,
     LIGHTGREY,
     false,
     BEAM_STEAM,
@@ -784,6 +880,8 @@ static const zap_info zap_data[] =
     100,
     new calcdice_calculator<3, 10, 1, 2>,
     new tohit_calculator<9, 1, 12>,
+    new dicedef_calculator<3, 8, 1, 11>,
+    new tohit_calculator<17, 1, 25>,
     WHITE,
     false,
     BEAM_ICE,
@@ -800,6 +898,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     new tohit_calculator<0, 3, 2>,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLUE,
     true,
     BEAM_CORONA,
@@ -816,6 +916,8 @@ static const zap_info zap_data[] =
     100, // power is capped to 50 in spl-zap.cc:spell_zap_power.
     nullptr,
     nullptr,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_HIBERNATION,
@@ -832,6 +934,8 @@ static const zap_info zap_data[] =
     25,
     new dicedef_calculator<1, 8, 1, 4>,
     new tohit_calculator<11, 1, 6>,
+    new dicedef_calculator<3, 3, 1, 12>,
+    new tohit_calculator<7, 1, 6>,
     RED,
     false,
     BEAM_FIRE,
@@ -848,6 +952,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 4, 1, 3>,
     new tohit_calculator<13, 1, 10>,
+    nullptr,
+    nullptr,
     BROWN,
     false,
     BEAM_FRAG,
@@ -864,6 +970,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<2, 4, 1, 3>,
     new tohit_calculator<13, 1, 10>,
+    nullptr,
+    nullptr,
     BROWN,
     false,
     BEAM_FRAG,
@@ -880,6 +988,8 @@ static const zap_info zap_data[] =
     25,
     new dicedef_calculator<1, 8, 1, 4>,
     new tohit_calculator<8, 1, 5>,
+    nullptr,
+    nullptr,
     BROWN,
     false,
     BEAM_FRAG,
@@ -896,6 +1006,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<4, 16, 2, 3>,
     new tohit_calculator<8, 1, 25>,
+    new dicedef_calculator<3, 8, 1, 11>,
+    new tohit_calculator<17, 1, 25>,
     RED,
     false,
     BEAM_LAVA,
@@ -912,6 +1024,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<4, 15, 1, 1>,
     new tohit_calculator<5, 1, 10>,
+    new dicedef_calculator<3, 7, 1, 12>,
+    new tohit_calculator<20, 1, 25>,
     LIGHTGREEN,
     false,
     BEAM_POISON_ARROW,             // extra damage
@@ -928,6 +1042,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_PETRIFY,
@@ -944,6 +1060,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    nullptr,
     RED,
     true,
     BEAM_PORKALATOR,
@@ -960,6 +1078,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     nullptr,
+    nullptr,
+    new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
     BEAM_SLEEP,
@@ -976,6 +1096,8 @@ static const zap_info zap_data[] =
     200,
     nullptr,
     new tohit_calculator<AUTOMATIC_HIT>,
+    nullptr,
+    nullptr,
     WHITE,
     false,
     BEAM_DEVASTATION,
@@ -993,6 +1115,8 @@ static const zap_info zap_data[] =
     100,
     new dicedef_calculator<2, 3, 1, 12>,
     new tohit_calculator<11, 1, 10>,
+    new dicedef_calculator<3, 3, 1, 50>,
+    new tohit_calculator<18, 1, 15>,
     RED,
     false,
     BEAM_FIRE,
@@ -1009,6 +1133,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 2, 1, 6>,
     new tohit_calculator<6, 1, 6>,
+    nullptr,
+    nullptr,
     GREEN,
     false,
     BEAM_MEPHITIC,
@@ -1025,6 +1151,8 @@ static const zap_info zap_data[] =
     100,
     nullptr,
     new tohit_calculator<0, 3, 1>,
+    nullptr,
+    nullptr,
     BLACK,
     true,
     BEAM_INNER_FLAME,
@@ -1041,6 +1169,8 @@ static const zap_info zap_data[] =
     50,
     new calcdice_calculator<2, 8, 1, 4>,
     new tohit_calculator<9, 1, 7>,
+    new dicedef_calculator<3, 5, 1, 17>,
+    new tohit_calculator<16, 1, 22>,
     LIGHTMAGENTA,
     false,
     BEAM_MMISSILE,
@@ -1057,6 +1187,8 @@ static const zap_info zap_data[] =
     100,
     new dicedef_calculator<2, 6, 1, 6>,
     new tohit_calculator<10, 1, 7>,
+    new dicedef_calculator<3, 6, 1, 15>,
+    new tohit_calculator<20, 1, 20>,
     CYAN,
     false,
     BEAM_MMISSILE,
@@ -1073,6 +1205,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<2, 3, 1, 13>,
     new tohit_calculator<10, 1, 9>,
+    nullptr,
+    nullptr,
     MAGENTA,
     false,
     BEAM_MMISSILE,
@@ -1089,6 +1223,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<3, 3, 1, 12>,
     new tohit_calculator<11, 1, 8>,
+    nullptr,
+    nullptr,
     LIGHTMAGENTA,
     false,
     BEAM_MMISSILE,
@@ -1105,6 +1241,8 @@ static const zap_info zap_data[] =
     50,
     new dicedef_calculator<4, 3, 1, 12>,
     new tohit_calculator<12, 1, 7>,
+    nullptr,
+    nullptr,
     WHITE,
     false,
     BEAM_MMISSILE,
@@ -1121,6 +1259,8 @@ static const zap_info zap_data[] =
     200,
     nullptr,
     new tohit_calculator<17, 1, 25>,
+    new dicedef_calculator<1, 0, 0, 1>, // deals damage through explosions
+    new tohit_calculator<17, 1, 25>,
     RED,
     false,
     BEAM_MISSILE,  // To avoid printing needless messages for non-damaging hits
@@ -1137,6 +1277,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<6, 18, 2, 3>,
     new tohit_calculator<10, 1, 25>,
+    nullptr,
+    nullptr,
     GREEN,
     false,
     BEAM_CRYSTAL,
@@ -1153,6 +1295,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<6, 15, 2, 3>,
     new tohit_calculator<10, 1, 25>,
+    nullptr,
+    nullptr,
     BLUE,
     false,
     BEAM_MMISSILE,
@@ -1167,8 +1311,10 @@ static const zap_info zap_data[] =
     ZAP_CORROSIVE_BOLT,
     "bolt of acid",
     200,
-    new calcdice_calculator<1, 11, 3, 5>,
+    new calcdice_calculator<4, 11, 3, 5>,
     new tohit_calculator<10, 1, 25>,
+    new dicedef_calculator<3, 9, 1, 17>,
+    new tohit_calculator<17, 1, 25>,
     YELLOW,
     false,
     BEAM_ACID,
@@ -1185,6 +1331,8 @@ static const zap_info zap_data[] =
     200,
     new dicedef_calculator<AUTOMATIC_HIT, 1, 0, 1>,
     new tohit_calculator<AUTOMATIC_HIT>,
+    nullptr,
+    nullptr,
     WHITE,
     false,
     BEAM_BOUNCY_TRACER,
@@ -1201,6 +1349,8 @@ static const zap_info zap_data[] =
     200,
     new calcdice_calculator<9, 8, 3, 8>,
     new tohit_calculator<7, 1, 15>,
+    nullptr,
+    nullptr,
     CYAN,
     false,
     BEAM_FRAG,
@@ -1211,4 +1361,57 @@ static const zap_info zap_data[] =
     6
 },
 
+{
+    ZAP_UNRAVELLING,
+    "unravelling",
+    200,
+    nullptr,
+    new tohit_calculator<0, 1, 1>,
+    nullptr,
+    nullptr,
+    ETC_MUTAGENIC,
+    true,
+    BEAM_UNRAVELLING,
+    NUM_DCHAR_TYPES,
+    false,
+    false,
+    false,
+    0 // dubious
+},
+
+{
+    ZAP_ICEBLAST,
+    "iceblast",
+    200,
+    new calcdice_calculator<3, 14, 3, 5>,
+    new tohit_calculator<40>,
+    nullptr,
+    nullptr,
+    WHITE,
+    false,
+    BEAM_ICE,
+    DCHAR_FIRED_MISSILE,
+    false,
+    false,
+    true,
+    0 // Noise comes from explosion
+},
+
+{
+    ZAP_SLUG_DART,
+    "slug dart",
+    25,
+    nullptr,
+    nullptr,
+    new dicedef_calculator<2, 4, 1, 25>,
+    new tohit_calculator<14, 1, 35>,
+    CYAN, // match slug's own colour
+    false,
+    BEAM_MMISSILE,
+    DCHAR_FIRED_MISSILE,
+    true,
+    false,
+    false,
+    1
+},
 };
